@@ -46,7 +46,6 @@ clean_parameters <- function(x, ...) {
 }
 
 
-
 #' @export
 clean_parameters.default <- function(x, group = "", ...) {
   pars <- find_parameters(x,
@@ -124,7 +123,6 @@ clean_parameters.default <- function(x, group = "", ...) {
 }
 
 
-
 #' @export
 clean_parameters.emmGrid <- function(x, ...) {
   pars <- find_parameters(x, flatten = FALSE)
@@ -187,7 +185,6 @@ clean_parameters.BFBayesFactor <- function(x, ...) {
 }
 
 
-
 #' @export
 clean_parameters.wbm <- function(x, ...) {
   pars <- find_parameters(x,
@@ -295,7 +292,6 @@ clean_parameters.lavaan <- function(x, ...) {
 }
 
 
-
 #' @export
 clean_parameters.blavaan <- function(x, ...) {
   params <- get_parameters(x, summary = TRUE)
@@ -308,7 +304,6 @@ clean_parameters.blavaan <- function(x, ...) {
 }
 
 
-
 #' @export
 clean_parameters.brmsfit <- function(x, ...) {
   pars <- find_parameters(x,
@@ -350,7 +345,6 @@ clean_parameters.stanreg <- function(x, ...) {
 }
 
 
-
 #' @export
 clean_parameters.bamlss <- function(x, ...) {
   pars <- find_parameters(x, effects = "all", component = "all", flatten = FALSE)
@@ -363,7 +357,6 @@ clean_parameters.bamlss <- function(x, ...) {
 }
 
 
-
 #' @export
 clean_parameters.stanmvreg <- function(x, ...) {
   pars <- find_parameters(x, effects = "all", component = "all", flatten = FALSE)
@@ -424,7 +417,6 @@ clean_parameters.mlm <- function(x, ...) {
 }
 
 
-
 # helper -------------------------
 
 
@@ -485,7 +477,6 @@ clean_parameters.mlm <- function(x, ...) {
 }
 
 
-
 .clean_brms_params <- function(out, is_mv, ...) {
   dots <- list(...)
   out$Cleaned_Parameter <- out$Parameter
@@ -497,22 +488,22 @@ clean_parameters.mlm <- function(x, ...) {
 
     resp_pattern <- sprintf("_%s_(.*)", resp)
     for (i in resp_pattern) {
-      out$Cleaned_Parameter <- gsub(pattern = i, "_\\1", out$Cleaned_Parameter, perl = TRUE)
+      out$Cleaned_Parameter <- gsub(pattern = i, "_\\1", out$Cleaned_Parameter)
     }
 
     resp_pattern <- sprintf("__%s(.*)", resp)
     for (i in resp_pattern) {
-      out$Cleaned_Parameter <- gsub(pattern = i, "\\1", out$Cleaned_Parameter, perl = TRUE)
+      out$Cleaned_Parameter <- gsub(pattern = i, "\\1", out$Cleaned_Parameter)
     }
 
     resp_pattern <- sprintf("__zi_%s(.*)", resp)
     for (i in resp_pattern) {
-      out$Cleaned_Parameter <- gsub(pattern = i, "\\1", out$Cleaned_Parameter, perl = TRUE)
+      out$Cleaned_Parameter <- gsub(pattern = i, "\\1", out$Cleaned_Parameter)
     }
 
     resp_pattern <- sprintf("(sigma)(_%s)", resp)
     for (i in resp_pattern) {
-      out$Cleaned_Parameter <- gsub(pattern = i, "\\1", out$Cleaned_Parameter, perl = TRUE)
+      out$Cleaned_Parameter <- gsub(pattern = i, "\\1", out$Cleaned_Parameter)
     }
   }
 
@@ -526,20 +517,20 @@ clean_parameters.mlm <- function(x, ...) {
   # clean fixed effects, conditional and zero-inflated
 
   out$Cleaned_Parameter <- gsub(pattern = "^b_(?!zi_)(.*)\\.(\\d)\\.$", "\\1[\\2]", out$Cleaned_Parameter, perl = TRUE)
-  out$Cleaned_Parameter <- gsub(pattern = "^b_zi_(.*)\\.(\\d)\\.$", "\\1[\\2]", out$Cleaned_Parameter, perl = TRUE)
+  out$Cleaned_Parameter <- gsub(pattern = "^b_zi_(.*)\\.(\\d)\\.$", "\\1[\\2]", out$Cleaned_Parameter)
   out$Cleaned_Parameter <- gsub(pattern = "^(b_|bs_|bsp_|bcs_)(?!zi_)(.*)", "\\2", out$Cleaned_Parameter, perl = TRUE)
-  out$Cleaned_Parameter <- gsub(pattern = "^(b_zi_|bs_zi_|bsp_zi_|bcs_zi_)(.*)", "\\2", out$Cleaned_Parameter, perl = TRUE)
+  out$Cleaned_Parameter <- gsub(pattern = "^(b_zi_|bs_zi_|bsp_zi_|bcs_zi_)(.*)", "\\2", out$Cleaned_Parameter) # nolint
 
   # correlation and sd
 
   cor_sd <- grepl("(sd_|cor_)(.*)", out$Cleaned_Parameter)
   if (any(cor_sd)) {
-    out$Cleaned_Parameter[cor_sd] <- gsub("^(sd_|cor_)(.*?)__(.*)", "\\3", out$Parameter[cor_sd], perl = TRUE)
-    out$Group[cor_sd] <- paste("SD/Cor:", gsub("^(sd_|cor_)(.*?)__(.*)", "\\2", out$Parameter[cor_sd], perl = TRUE))
+    out$Cleaned_Parameter[cor_sd] <- gsub("^(sd_|cor_)(.*?)__(.*)", "\\3", out$Parameter[cor_sd])
+    out$Group[cor_sd] <- paste("SD/Cor:", gsub("^(sd_|cor_)(.*?)__(.*)", "\\2", out$Parameter[cor_sd]))
     # replace "__" by "~"
     cor_only <- startsWith(out$Parameter[cor_sd], "cor_")
     if (any(cor_only)) {
-      out$Cleaned_Parameter[which(cor_sd)[cor_only]] <- sub("__", " ~ ", out$Cleaned_Parameter[which(cor_sd)[cor_only]], fixed = TRUE)
+      out$Cleaned_Parameter[which(cor_sd)[cor_only]] <- sub("__", " ~ ", out$Cleaned_Parameter[which(cor_sd)[cor_only]], fixed = TRUE) # nolint
     }
   }
 
@@ -585,7 +576,7 @@ clean_parameters.mlm <- function(x, ...) {
 
   simplex <- startsWith(out$Cleaned_Parameter, "simo_")
   if (length(simplex)) {
-    out$Cleaned_Parameter[simplex] <- gsub("^(simo_|simo_mo)(.*)\\[(\\d)\\]$", "\\2[\\3]", out$Cleaned_Parameter[simplex])
+    out$Cleaned_Parameter[simplex] <- gsub("^(simo_|simo_mo)(.*)\\[(\\d)\\]$", "\\2[\\3]", out$Cleaned_Parameter[simplex]) # nolint
     out$Component[simplex] <- "simplex"
   }
 
@@ -620,7 +611,6 @@ clean_parameters.mlm <- function(x, ...) {
 }
 
 
-
 .clean_stanreg_params <- function(out, ...) {
   out$Cleaned_Parameter <- out$Parameter
   dots <- list(...)
@@ -645,14 +635,14 @@ clean_parameters.mlm <- function(x, ...) {
   cor_sd <- startsWith(out$Cleaned_Parameter, "Sigma[")
 
   if (any(cor_sd)) {
-    parm1 <- gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\2", out$Parameter[cor_sd], perl = TRUE)
-    parm2 <- gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\3", out$Parameter[cor_sd], perl = TRUE)
+    parm1 <- gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\2", out$Parameter[cor_sd])
+    parm2 <- gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\3", out$Parameter[cor_sd])
     out$Cleaned_Parameter[which(cor_sd)] <- parm1
     rand_cor <- parm1 != parm2
     if (any(rand_cor)) {
       out$Cleaned_Parameter[which(cor_sd)[rand_cor]] <- paste0(parm1[rand_cor], " ~ ", parm2[rand_cor])
     }
-    out$Group[cor_sd] <- paste("SD/Cor:", gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\1", out$Parameter[cor_sd], perl = TRUE))
+    out$Group[cor_sd] <- paste("Var/Cov:", gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\1", out$Parameter[cor_sd]))
   }
 
 
@@ -669,9 +659,9 @@ clean_parameters.mlm <- function(x, ...) {
       out$Group[rand_effects] <- r_grps
       out$Level[rand_effects] <- r_levels
       # fix labelling of SD and correlation component
-      sd_cor <- grepl("SD/Cor:", out$Group, fixed = TRUE)
+      sd_cor <- grepl("Var/Cov:", out$Group, fixed = TRUE)
       if (any(sd_cor)) {
-        out$Group[sd_cor] <- gsub("SD/Cor: (.*)", "\\1", out$Group[sd_cor])
+        out$Group[sd_cor] <- gsub("Var/Cov: (.*)", "\\1", out$Group[sd_cor])
       }
     } else {
       re_grp_level <- gsub("b\\[(.*) (.*):(.*)\\]", "\\2", out$Cleaned_Parameter[rand_effects])
@@ -696,7 +686,6 @@ clean_parameters.mlm <- function(x, ...) {
 }
 
 
-
 .clean_bfbayesfactor_params <- function(out) {
   pars <- do.call(rbind, strsplit(out$Parameter, "-", fixed = TRUE))
 
@@ -731,7 +720,6 @@ clean_parameters.mlm <- function(x, ...) {
 }
 
 
-
 .clean_bamlss_params <- function(out) {
   out$Cleaned_Parameter <- out$Parameter
   out$Cleaned_Parameter <- gsub("^(mu\\.p\\.|pi\\.p\\.)(.*)", "\\2", out$Cleaned_Parameter)
@@ -746,7 +734,6 @@ clean_parameters.mlm <- function(x, ...) {
 }
 
 
-
 .remove_empty_columns_from_pars <- function(x) {
   if (object_has_names(x, "Response") && all(is.na(x$Response))) {
     pos <- which(colnames(x) == "Response")
