@@ -1,4 +1,11 @@
-#' Data frame and Tables Pretty Formatting
+#' @title Data frame and Tables Pretty Formatting
+#' @name export_table
+#'
+#' @description Function to export data frames into tables, which can be printed
+#' to the console, or displayed in markdown or HTML format (and thereby, exported
+#' to other formats like Word or PDF). The table width is automatically adjusted
+#' to fit into the width of the display device (e.g., width of console). Use
+#' the `table_width` argument to control this behaviour.
 #'
 #' @param x A data frame. May also be a list of data frames, to export multiple
 #'   data frames into multiple tables.
@@ -20,20 +27,18 @@
 #'   new text line under the table. If `x` is a list of data frames, `footer`
 #'   may be a list of table captions, one for each table.
 #' @param align Column alignment. For markdown-formatted tables, the default
-#'   `align = NULL` will right-align numeric columns, while all other
-#'   columns will be left-aligned. If `format = "html"`, the default is
-#'   left-align first column and center all remaining. May be a string to
-#'   indicate alignment rules for the complete table, like `"left"`,
-#'   `"right"`, `"center"` or `"firstleft"` (to left-align first
-#'   column, center remaining); or maybe a string with abbreviated alignment
-#'   characters, where the length of the string must equal the number of columns,
-#'   for instance, `align = "lccrl"` would left-align the first column, center
-#'   the second and third, right-align column four and left-align the fifth
-#'   column. For HTML-tables, may be one of `"center"`, `"left"` or
-#'   `"right"`.
-#' @param group_by Name of column in `x` that indicates grouping for tables.
-#'   Only applies when `format = "html"`. `group_by` is passed down
-#'   to `gt::gt(groupname_col = group_by)`.
+#'   `align = NULL` will right-align numeric columns, while all other columns
+#'   will be left-aligned. If `format = "html"`, the default is left-align first
+#'   column and center all remaining. May be a string to indicate alignment
+#'   rules for the complete table, like `"left"`, `"right"`, `"center"` or
+#'   `"firstleft"` (to left-align first column, center remaining); or a string
+#'   with abbreviated alignment characters, where the length of the string must
+#'   equal the number of columns. For instance, `align = "lccrl"` would
+#'   left-align the first column, center the second and third, right-align
+#'   column four and left-align the fifth column.
+#' @param by Name of column in `x` that indicates grouping for tables.
+#'   Only applies when `format = "html"`. `by` is passed down to
+#'   `gt::gt(groupname_col = by)`.
 #' @param width Refers to the width of columns (with numeric values). Can be
 #'   either `NULL`, a number or a named numeric vector. If `NULL`, the width for
 #'   each column is adjusted to the minimum required width. If a number, columns
@@ -41,25 +46,41 @@
 #'   a named numeric vector, value names are matched against column names, and
 #'   for each match, the specified width is used (see 'Examples'). Only applies
 #'   to text-format (see `format`).
-#' @param table_width Numeric, or `"auto"`, indicating the width of the complete
-#'   table. If `table_width = "auto"` and the table is wider than the current
-#'   width (i.e. line length) of the console (or any other source for textual
-#'   output, like markdown files), the table is split into two parts. Else,
-#'   if `table_width` is numeric and table rows are larger than `table_width`,
-#'   the table is split into two parts.
+#' @param table_width Numeric,`"auto"`, `NULL` or `Inf`, indicating the width of
+#'   the complete table.
+#'   - If `table_width = "auto"` (default) and the table is wider than the
+#'   current width (i.e. line length) of the console (or any other source for
+#'   textual output, like markdown files), the table is split into multiple
+#'   parts.
+#'   - Else, if `table_width` is numeric and table rows are larger than
+#'   `table_width`, the table is split into multiple parts. For each new table,
+#'   the first column is repeated for better orientation.
+#'   - Use `NULL` or `Inf` to turn off automatic splitting of the table.
+#'   - `options(easystats_table_width = <value>)` can be used to set a default
+#'   width for tables.
+#' @param remove_duplicates Logical, if `TRUE` and table is split into multiple
+#'   parts, duplicated ("empty") rows will be removed. If `FALSE`, empty rows
+#'   will be preserved. Only applies when `table_width` is *not* `NULL` (or
+#'   `Inf`) *and* table is split into multiple parts.
 #' @param ... Currently not used.
 #' @inheritParams format_value
 #' @inheritParams get_data
 #'
-#' @note The values for `caption`, `subtitle` and `footer`
-#'   can also be provided as attributes of `x`, e.g. if `caption = NULL`
-#'   and `x` has attribute `table_caption`, the value for this
-#'   attribute will be used as table caption. `table_subtitle` is the
-#'   attribute for `subtitle`, and `table_footer` for `footer`.
+#' @note The values for `caption`, `subtitle` and `footer` can also be provided
+#' as attributes of `x`, e.g. if `caption = NULL` and `x` has attribute
+#' `table_caption`, the value for this attribute will be used as table caption.
+#' `table_subtitle` is the attribute for `subtitle`, and `table_footer` for
+#' `footer`.
 #'
 #' @inherit format_table seealso
 #'
-#' @return A data frame in character format.
+#' @return If `format = "text"` (or `NULL`), a formatted character string is
+#' returned. `format = "markdown"` (or `"md"`) returns a character string of
+#' class `knitr_kable`, which renders nicely in markdown files. `format = "html"`
+#' returns an `gt` object (created by the **gt** package), which - by default -
+#' is displayed in the IDE's viewer pane or default browser. This object can
+#' be further modified with the various gt-functions.
+#'
 #' @examples
 #' export_table(head(iris))
 #' export_table(head(iris), cross = "+")
@@ -68,7 +89,7 @@
 #' # split longer tables
 #' export_table(head(iris), table_width = 30)
 #'
-#' \dontrun{
+#' \donttest{
 #' # colored footers
 #' data(iris)
 #' x <- as.data.frame(iris[1:5, ])
@@ -116,9 +137,10 @@ export_table <- function(x,
                          subtitle = NULL,
                          footer = NULL,
                          align = NULL,
-                         group_by = NULL,
+                         by = NULL,
                          zap_small = FALSE,
-                         table_width = NULL,
+                         table_width = "auto",
+                         remove_duplicates = FALSE,
                          verbose = TRUE,
                          ...) {
   # check args
@@ -131,10 +153,10 @@ export_table <- function(x,
     format <- "markdown"
   }
 
-  # sanity check
+  # validation check
   if (is.null(x) || (is.data.frame(x) && nrow(x) == 0) || is_empty_object(x)) {
     if (isTRUE(verbose)) {
-      message(paste0("Can't export table to ", format, ", data frame is empty."))
+      format_alert("Can't export table to ", format, ", data frame is empty.")
     }
     return(NULL)
   }
@@ -153,9 +175,6 @@ export_table <- function(x,
     }))
   }
 
-  ## TODO: check if we need to move this code before the above if-statement?
-  ## attributes might get lost after do.call()
-
   # check for indention
   indent_groups <- attributes(x)$indent_groups
   indent_rows <- attributes(x)$indent_rows
@@ -194,12 +213,14 @@ export_table <- function(x,
       subtitle = subtitle,
       footer = footer,
       align = align,
-      group_by = group_by,
+      group_by = by,
       zap_small = zap_small,
       empty_line = empty_line,
       indent_groups = indent_groups,
       indent_rows = indent_rows,
-      table_width = table_width
+      table_width = table_width,
+      remove_duplicated_lines = remove_duplicates,
+      verbose = verbose
     )
   } else if (is.list(x)) {
     # table from list of data frames -----------------------------------------
@@ -266,12 +287,14 @@ export_table <- function(x,
         subtitle = attributes(i)$table_subtitle,
         footer = t_footer,
         align = align,
-        group_by = group_by,
+        group_by = by,
         zap_small = zap_small,
         empty_line = empty_line,
         indent_groups = indent_groups,
         indent_rows = indent_rows,
-        table_width = table_width
+        table_width = table_width,
+        remove_duplicated_lines = remove_duplicates,
+        verbose = verbose
       )
     })
 
@@ -307,7 +330,6 @@ export_table <- function(x,
 }
 
 
-
 # methods -----------------------------------
 
 #' @export
@@ -317,7 +339,6 @@ print.insight_table <- function(x, ...) {
 }
 
 
-
 # small helper ----------------------
 
 # check whether "table_caption" or its alias "table_title" is used as attribute
@@ -330,8 +351,6 @@ print.insight_table <- function(x, ...) {
 }
 
 
-
-
 # work horse: create matrix of raw table layout --------------------
 
 .export_table <- function(x,
@@ -352,8 +371,10 @@ print.insight_table <- function(x, ...) {
                           empty_line = NULL,
                           indent_groups = NULL,
                           indent_rows = NULL,
-                          table_width = NULL) {
-  df <- as.data.frame(x)
+                          table_width = NULL,
+                          remove_duplicated_lines = FALSE,
+                          verbose = TRUE) {
+  tabledata <- as.data.frame(x)
 
   # check width argument, for format value. cannot have
   # named vector of length > 1 here
@@ -363,30 +384,29 @@ print.insight_table <- function(x, ...) {
     col_width <- NULL
   }
 
-  # round all numerics
-  col_names <- names(df)
-  df <- as.data.frame(sapply(df, function(i) {
+  # round all numerics, and convert to character
+  col_names <- names(tabledata)
+  tabledata[] <- lapply(tabledata, function(i) {
     if (is.numeric(i)) {
-      format_value(i,
+      out <- format_value(i,
         digits = digits, protect_integers = protect_integers,
         missing = missing, width = col_width, zap_small = zap_small
       )
     } else {
-      i
+      out <- i
     }
-  }, simplify = FALSE), stringsAsFactors = FALSE)
+    as.character(out)
+  })
 
-
-  # Convert to character.
-  df <- as.data.frame(sapply(df, as.character, simplify = FALSE), stringsAsFactors = FALSE)
-  names(df) <- col_names
-  df[is.na(df)] <- as.character(missing)
+  # add back column names
+  names(tabledata) <- col_names
+  tabledata[is.na(tabledata)] <- as.character(missing)
 
 
   if (identical(format, "html")) {
     # html formatting starts here, needs less preparation of table matrix
     out <- .format_html_table(
-      df,
+      tabledata,
       caption = caption,
       subtitle = subtitle,
       footer = footer,
@@ -399,15 +419,15 @@ print.insight_table <- function(x, ...) {
     # text and markdown go here...
   } else {
     # Add colnames as first row to the data frame
-    df <- rbind(colnames(df), df)
+    tabledata <- rbind(colnames(tabledata), tabledata)
 
     # Initial alignment for complete data frame is right-alignment
-    aligned <- format(df, justify = "right")
+    aligned <- format(tabledata, justify = "right")
 
     # default alignment
-    col_align <- rep("right", ncol(df))
+    col_align <- rep("right", ncol(tabledata))
 
-    # first column definitely right alignment, fixed width
+    # first row definitely right alignment, fixed width
     first_row <- as.character(aligned[1, ])
     for (i in seq_along(first_row)) {
       aligned[1, i] <- format(
@@ -442,7 +462,9 @@ print.insight_table <- function(x, ...) {
         col_names = col_names,
         col_width = width,
         col_align = col_align,
-        table_width = table_width
+        table_width = table_width,
+        remove_duplicated_lines = remove_duplicated_lines,
+        verbose = verbose
       )
     } else if (format == "markdown") {
       # markdown is a bit different...
@@ -463,10 +485,6 @@ print.insight_table <- function(x, ...) {
 }
 
 
-
-
-
-
 # plain text formatting ------------------------
 
 
@@ -484,16 +502,19 @@ print.insight_table <- function(x, ...) {
                                 col_names = NULL,
                                 col_width = NULL,
                                 col_align = NULL,
-                                table_width = NULL) {
-  # align table, if requested. unlike the generic aligments that have
-  # been done previously, we now look for column-specific alignments
+                                table_width = NULL,
+                                remove_duplicated_lines = FALSE,
+                                verbose = TRUE) {
+  # align table, if requested. unlike the generic aligments that have been done
+  # previously, we now look for column-specific alignments. we furthermore save
+  # the alignments in "col_align", which we may need later when we set a fixed
+  # column width for specific columns across multiple tables, and have to
+  # re-align the columns again.
 
   if (!is.null(align) && length(align) == 1) {
     for (i in seq_len(ncol(final))) {
       align_char <- ""
-      if (align %in% c("left", "right", "center", "firstleft")) {
-        align_char <- ""
-      } else {
+      if (!align %in% c("left", "right", "center", "firstleft")) {
         align_char <- substr(align, i, i)
       }
 
@@ -528,7 +549,7 @@ print.insight_table <- function(x, ...) {
   }
 
 
-  # check for fixed column widths. usually, column widht is aligned to the
+  # check for fixed column widths. usually, column width is aligned to the
   # widest element in that column. for multiple tables, this may result in
   # columns which do not have the the same width across tables, despite
   # having the same "meaning" (e.g., zero-inflated models that have a table
@@ -548,17 +569,15 @@ print.insight_table <- function(x, ...) {
   }
 
 
-  # we can split very wide table into maximum three parts
-  # this is currently hardcoded, not flexible, so we cannot allow
-  # more than three parts of one wide table
-  final2 <- NULL
-  final3 <- NULL
+  # we can split very wide tables
+  final_extra <- NULL
+  overlength_warning <- FALSE
 
+  # check if user requested automatic width-adjustment of tables,
+  # or if a given width is required
+  table_width_adjustment <- identical(table_width, "auto") || (!is.null(table_width) && !is.infinite(table_width) && is.numeric(table_width)) # nolint
 
-  # check if user requested automatic width-adjustment of tables, or if a
-  # given width is required
-
-  if (identical(table_width, "auto") || (!is.null(table_width) && is.numeric(table_width))) {
+  if (table_width_adjustment) {
     # define the length of a table line. if specific table width is defined
     # (i.e. table_width is numeric), use that to define length of table lines.
     # else, if "auto", check the current width of the user console and use that
@@ -567,56 +586,99 @@ print.insight_table <- function(x, ...) {
     if (is.numeric(table_width)) {
       line_width <- table_width
     } else {
-      line_width <- options()$width
+      line_width <- getOption("easystats_table_width", getOption("width", 80))
     }
 
     # width of first table row of complete table. Currently, "final" is still
     # a matrix, so we need to paste the columns of the first row into a string
-    row_width <- nchar(paste0(final[1, ], collapse = sep), type = "width")
+    row_width <- nchar(paste(final[1, ], collapse = sep), type = "width")
 
     # possibly first split - all table columns longer than "line_width"
     # (i.e. first table row) go into a second string
     if (row_width > line_width) {
-      i <- 1
-      while (nchar(paste0(final[1, 1:i], collapse = sep), type = "width") < line_width) {
-        i <- i + 1
+      final_extra <- list(final)
+      e <- 1
+      while (nchar(paste(utils::tail(final_extra, 1)[[1]][1, ], collapse = sep), type = "width") > line_width && e <= length(final_extra)) { # nolint
+        .final_temp <- final_extra[[e]]
+
+        i <- 1
+        # determine how many columns fit into the first line
+        while (nchar(paste(.final_temp[1, 1:i], collapse = sep), type = "width") < line_width) {
+          i <- i + 1
+        }
+        # copy first column, and all columns that did not fit into the first line
+        # into the second table matrix
+        if (i < ncol(.final_temp)) {
+          if (i > 1) {
+            final_extra[[e]] <- .final_temp[, 1:(i - 1), drop = FALSE]
+          } else {
+            # if first column is very long, i = 1, and then indexing 1:(i-1)
+            # doesn't work. Just copy first column, and give a warning about
+            # overlengthy columns
+            final_extra[[e]] <- .final_temp[, 1, drop = FALSE]
+            overlength_warning <- TRUE
+          }
+          # check if only the first column was copied, and no other columns -
+          # if so, we will repeatedly only copy column one and move all other
+          # columns in the next table part (where this happens again)
+          # in this case, *don't* copy first column again
+          if (i > 2) {
+            # repeat first column in each table, for better orientation
+            copy_range <- c(1, i:ncol(.final_temp))
+          } else if (i == 2) {
+            # here we have a very wide first column, so don't repeat it -
+            # else, subsequent columns won't fit into table
+            copy_range <- i:ncol(.final_temp)
+          } else {
+            # here we have an overlengthy first column - make sure we don't
+            # process this column multiple times, so skip it here
+            copy_range <- 2:ncol(.final_temp)
+          }
+          final_extra[[e + 1]] <- .final_temp[, copy_range, drop = FALSE]
+        }
+        e <- e + 1
       }
-      if (i > 2 && i < ncol(final)) {
-        final2 <- final[, c(1, i:ncol(final))]
-        final <- final[, 1:(i - 1)]
+
+      final <- final_extra[[1]]
+      if (length(final_extra) > 1) {
+        final_extra <- final_extra[-1]
+      } else {
+        final_extra <- NULL
       }
     }
+  }
 
-    # width of first table row of remaing second table part
-    row_width <- nchar(paste0(final2[1, ], collapse = sep), type = "width")
-
-    # possibly second split - all table columns longer than "line_width"
-    # (i.e. first table row) go into a third string
-    if (row_width > line_width) {
-      i <- 1
-      while (nchar(paste0(final2[1, 1:i], collapse = sep), type = "width") < line_width) {
-        i <- i + 1
-      }
-      if (i > 2 && i < ncol(final2)) {
-        final3 <- final2[, c(1, i:ncol(final2))]
-        final2 <- final2[, 1:(i - 1)]
-      }
-    }
+  if (overlength_warning && verbose) {
+    format_warning("The table contains very wide columns that don't fit into the available display-width of the console. Splitting tables into multiple parts did not have the desired effect.") # nolint
   }
 
   # Transform table matrix into a string value that can be printed
-  rows <- .table_parts(c(), final, header, sep, cross, empty_line)
+  rows <- .table_parts(
+    rows = NULL,
+    final = final,
+    header = header,
+    sep = sep,
+    cross = cross,
+    empty_line = empty_line,
+    table_width_adjustment = table_width_adjustment,
+    remove_duplicated_lines = remove_duplicated_lines
+  )
 
-  # if we have over-lengthy tables that are split into two parts,
-  # print second table here
-  if (!is.null(final2)) {
-    rows <- .table_parts(paste0(rows, "\n"), final2, header, sep, cross, empty_line)
-  }
-
-  # if we have over-lengthy tables that are split into two parts,
-  # print second table here
-  if (!is.null(final3)) {
-    rows <- .table_parts(paste0(rows, "\n"), final3, header, sep, cross, empty_line)
+  # if we have over-lengthy tables that are split into parts,
+  # print extra table here
+  if (!is.null(final_extra)) {
+    for (fex in final_extra) {
+      rows <- .table_parts(
+        rows = paste0(rows, "\n"),
+        final = fex,
+        header = header,
+        sep = sep,
+        cross = cross,
+        empty_line = empty_line,
+        table_width_adjustment = table_width_adjustment,
+        remove_duplicated_lines = remove_duplicated_lines
+      )
+    }
   }
 
   # if caption is available, add a row with a headline
@@ -625,13 +687,11 @@ print.insight_table <- function(x, ...) {
     if (length(caption) == 2 && .is_valid_colour(caption[2])) {
       caption <- .colour(caption[2], caption[1])
     }
-    if (!is.null(subtitle)) {
-      # if we have a colour value, make coloured ansi-string
-      if (length(subtitle) == 2 && .is_valid_colour(subtitle[2])) {
-        subtitle <- .colour(subtitle[2], subtitle[1])
-      }
-    } else {
+    if (is.null(subtitle)) {
       subtitle <- ""
+    } else if (length(subtitle) == 2 && .is_valid_colour(subtitle[2])) {
+      # if we have a colour value, make coloured ansi-string
+      subtitle <- .colour(subtitle[2], subtitle[1])
     }
 
     # paste everything together and remove unnecessary double spaces
@@ -658,19 +718,25 @@ print.insight_table <- function(x, ...) {
 }
 
 
-
 # helper to prepare table body for text output ---------------------
 
-.table_parts <- function(rows, final, header, sep, cross, empty_line) {
+.table_parts <- function(rows,
+                         final,
+                         header,
+                         sep,
+                         cross,
+                         empty_line,
+                         table_width_adjustment,
+                         remove_duplicated_lines = FALSE) {
   # "final" is a matrix here. we now paste each row into a character string,
   # add separator chars etc.
   for (row in seq_len(nrow(final))) {
     # create a string for each row, where cells from original matrix are
     # separated by the separator char
-    final_row <- paste0(final[row, ], collapse = sep)
+    final_row <- paste(final[row, ], collapse = sep)
     # check if we have an empty row, and if so, fill with an
     # "empty line separator", if requested by user
-    if (!is.null(empty_line) && all(nchar(trim_ws(final[row, ]), type = "width") == 0)) {
+    if (!is.null(empty_line) && !any(nzchar(trim_ws(final[row, ])))) {
       # check whether user wants to have a "cross" char where vertical and
       # horizontal lines (from empty line separator) cross. But don't add
       # a "cross" when the empty line is the last row in the table...
@@ -678,29 +744,75 @@ print.insight_table <- function(x, ...) {
         # the empty line, which is just empty cells with separator char,
         # will now be replaced by the "empty line char", so we have a
         # clean separator line
-        paste0(rep_len(empty_line, nchar(final_row, type = "width")), collapse = ""),
+        paste(rep_len(empty_line, nchar(final_row, type = "width")), collapse = ""),
         cross, sep, final_row,
         is_last_row = row == nrow(final)
       )
-      rows <- paste0(rows, empty_line_with_cross, sep = "\n")
+      rows <- paste0(rows, empty_line_with_cross, "\n")
     } else {
-      rows <- paste0(rows, final_row, sep = "\n")
+      rows <- paste0(rows, final_row, "\n")
     }
 
     # After first row, we might have a separator row
-    if (row == 1) {
-      # check if we have any separator for the header row
-      if (!is.null(header)) {
-        # check whether user wants to have a "cross" char where vertical and
-        # horizontal lines (from header line) cross.
-        header_line <- .insert_cross(
-          paste0(rep_len(header, nchar(final_row, type = "width")), collapse = ""),
-          cross, sep, final_row,
-          is_last_row = row == nrow(final)
-        )
-        # add separator row after header line
-        rows <- paste0(rows, header_line, sep = "\n")
+    if (row == 1 && !is.null(header)) { # check if we have any separator for the header row
+      # check whether user wants to have a "cross" char where vertical and
+      # horizontal lines (from header line) cross.
+      header_line <- .insert_cross(
+        paste(rep_len(header, nchar(final_row, type = "width")), collapse = ""),
+        cross, sep, final_row,
+        is_last_row = row == nrow(final)
+      )
+      # add separator row after header line
+      rows <- paste0(rows, header_line, "\n")
+    }
+  }
+
+  # we table is split into multiple parts, we remove duplicated separator lines
+  if (table_width_adjustment) {
+    # split single character back into rows again
+    out <- unlist(strsplit(rows, "\\n"), use.names = FALSE)
+    # find out where we have consecutive duplicated rows
+    consecutive_dups <- which(out[-1] == out[-length(out)])
+    if (length(consecutive_dups)) {
+      # if second to last line is a separator line, *and* we usually also have
+      # a final line, remove that one
+      if (.is_separator_line(out[length(out) - 1], empty_line, cross, sep)) {
+        consecutive_dups <- unique(c(consecutive_dups, length(out) - 1))
       }
+      # copy consecutive duplicated rows into temporary object
+      tmp <- out[consecutive_dups]
+      # remove separator and cross signs
+      if (!is.null(empty_line) && nzchar(empty_line)) {
+        tmp <- gsub(empty_line, "", tmp, fixed = TRUE)
+      }
+      if (!is.null(cross) && nzchar(cross)) {
+        tmp <- gsub(cross, "", tmp, fixed = TRUE)
+      }
+      if (!is.null(sep) && nzchar(sep)) {
+        tmp <- gsub(sep, "", tmp, fixed = TRUE)
+      }
+      # now check which rows are empty (lines) AND consecutive duplicated
+      # remove those from "out"
+      remove_dups <- consecutive_dups[-nzchar(tmp)]
+      # if all consecutive duplicates were empty
+      if (!length(remove_dups)) {
+        remove_dups <- consecutive_dups
+      }
+      # remove duplicated lines, or make them "empty"?
+      if (remove_duplicated_lines) {
+        out <- out[-remove_dups]
+      } else if (!is.null(empty_line) && nzchar(empty_line)) {
+        # when consecutive duplicated rows are removed, the different table
+        # parts may have different height (number of rows). To avoid confusion,
+        # it is possible to preserve the height of each table part by setting
+        # remove_duplicates = FALSE
+        out[remove_dups] <- gsub(empty_line, " ", out[remove_dups], fixed = TRUE)
+        if (!is.null(sep) && nzchar(sep) && !is.null(cross) && nzchar(cross)) {
+          out[remove_dups] <- gsub(trim_ws(cross), trim_ws(sep), out[remove_dups], fixed = TRUE)
+        }
+      }
+      # collapse back into single string
+      rows <- paste0(paste(out, collapse = "\n"), "\n")
     }
   }
 
@@ -708,12 +820,26 @@ print.insight_table <- function(x, ...) {
 }
 
 
+.is_separator_line <- function(x, empty_line, cross, sep) {
+  if (!is.null(empty_line) && nzchar(empty_line)) {
+    x <- gsub(empty_line, "", x, fixed = TRUE)
+  }
+  if (!is.null(cross) && nzchar(cross)) {
+    x <- gsub(cross, "", x, fixed = TRUE)
+  }
+  if (!is.null(sep) && nzchar(sep)) {
+    x <- gsub(sep, "", x, fixed = TRUE)
+  }
+  !nzchar(x)
+}
+
+
 .insert_cross <- function(row, cross, sep, pattern, is_last_row) {
   # check if at places where row and column "lines" cross, we need a
   # special char. E.g., if columns are separated with "|" and header line
   # with "-", we might have a "+" to have properly "crossed lines"
   if (!is.null(cross) && !is_last_row) {
-    cross_position <- unlist(gregexpr(trim_ws(sep), pattern, fixed = TRUE))
+    cross_position <- unlist(gregexpr(trim_ws(sep), pattern, fixed = TRUE), use.names = FALSE)
     for (pp in cross_position) {
       substr(row, pp, pp) <- cross
     }
@@ -722,7 +848,6 @@ print.insight_table <- function(x, ...) {
 }
 
 
-
 # helper ----------------
 
 .paste_footers <- function(footer, rows) {
@@ -737,7 +862,6 @@ print.insight_table <- function(x, ...) {
 }
 
 
-
 .indent_groups <- function(final, indent_groups) {
   # check length of indent string
   whitespace <- sprintf("%*s", nchar(indent_groups, type = "width"), " ")
@@ -764,7 +888,6 @@ print.insight_table <- function(x, ...) {
 }
 
 
-
 .indent_rows <- function(final, indent_rows, whitespace = "  ") {
   # create index for those rows that should be indented
   # for text format, first row is column names, so we need a +1 here
@@ -790,7 +913,6 @@ print.insight_table <- function(x, ...) {
 }
 
 
-
 .indent_rows_html <- function(final, indent_rows, whitespace = "") {
   # create index for those rows that should be indented
   grp_rows <- indent_rows
@@ -798,10 +920,6 @@ print.insight_table <- function(x, ...) {
   # indent
   final[grp_rows, 1] <- paste0(whitespace, final[grp_rows, 1])
 
-  # find rows that should not be indented
-  non_grp_rows <- seq_len(nrow(final))
-  non_grp_rows <- non_grp_rows[!non_grp_rows %in% grp_rows]
-
   # remove indent token
   final[, 1] <- gsub("# ", "", final[, 1], fixed = TRUE)
 
@@ -809,8 +927,6 @@ print.insight_table <- function(x, ...) {
 }
 
 
-
-
 # markdown formatting -------------------
 
 .format_markdown_table <- function(final,
@@ -836,17 +952,13 @@ print.insight_table <- function(x, ...) {
   # go through all columns of the data frame
   for (i in 1:n_columns) {
     # create separator line for current column
-    line <- paste0(rep_len("-", column_width[i]), collapse = "")
+    tablecol <- paste0(rep_len("-", column_width[i]), collapse = "")
 
     # check if user-defined alignment is requested, and if so, extract
     # alignment direction and save to "align_char"
     align_char <- ""
-    if (!is.null(align)) {
-      if (align %in% c("left", "right", "center", "firstleft")) {
-        align_char <- ""
-      } else {
-        align_char <- substr(align, i, i)
-      }
+    if (!is.null(align) && !align %in% c("left", "right", "center", "firstleft")) {
+      align_char <- substr(align, i, i)
     }
 
     # auto-alignment?
@@ -854,31 +966,31 @@ print.insight_table <- function(x, ...) {
       # if so, check if string in column starts with
       # whitespace (indicating right-alignment) or not.
       if (grepl("^\\s", final[2, i])) {
-        line <- paste0(line, ":")
+        tablecol <- paste0(tablecol, ":")
         final[, i] <- format(final[, i], width = column_width[i] + 1, justify = "right")
       } else {
-        line <- paste0(":", line)
+        tablecol <- paste0(":", tablecol)
         final[, i] <- format(final[, i], width = column_width[i] + 1, justify = "left")
       }
 
-      # left alignment, or at least first line only left?
+      # left alignment, or at least first tablecol only left?
     } else if (align == "left" || (first_row_leftalign && i == 1) || align_char == "l") {
-      line <- paste0(":", line)
+      tablecol <- paste0(":", tablecol)
       final[, i] <- format(final[, i], width = column_width[i] + 1, justify = "left")
 
       # right-alignment
     } else if (align == "right" || align_char == "r") {
-      line <- paste0(line, ":")
+      tablecol <- paste0(tablecol, ":")
       final[, i] <- format(final[, i], width = column_width[i] + 1, justify = "right")
 
       # else, center
     } else {
-      line <- paste0(":", line, ":")
+      tablecol <- paste0(":", tablecol, ":")
       final[, i] <- format(final[, i], width = column_width[i] + 2, justify = "centre")
     }
 
     # finally, we have our header-line that indicates column alignments
-    header <- paste0(header, line, "|")
+    header <- paste0(header, tablecol, "|")
   }
 
   # indent groups?
@@ -923,8 +1035,6 @@ print.insight_table <- function(x, ...) {
 }
 
 
-
-
 # html formatting ---------------------------
 
 .format_html_table <- function(final,
@@ -935,7 +1045,6 @@ print.insight_table <- function(x, ...) {
                                group_by = NULL,
                                indent_groups = NULL,
                                indent_rows = NULL) {
-  # installed?
   check_if_installed("gt")
 
   if (is.null(align)) {
@@ -943,26 +1052,31 @@ print.insight_table <- function(x, ...) {
   }
 
   group_by_columns <- c(intersect(c("Group", "Response", "Effects", "Component"), names(final)), group_by)
-  if (!length(group_by_columns)) {
-    group_by_columns <- NULL
-  } else {
+  if (length(group_by_columns)) {
     # remove columns with only 1 unique value - this *should* be safe to
     # remove, but we may check if all printed sub titles look like intended
-
     for (i in group_by_columns) {
       if (n_unique(final[[i]]) <= 1) {
         final[[i]] <- NULL
       }
     }
+  } else {
+    group_by_columns <- NULL
   }
 
   # indent groups?
   if (!is.null(indent_rows) && any(grepl("# ", final[, 1], fixed = TRUE))) {
-    final <- .indent_rows_html(final, indent_rows)
+    highlight_rows <- grep("# ", final[, 1], fixed = TRUE)
+    final <- .indent_rows_html(final, indent_rows, "\U00A0\U00A0")
+  } else {
+    highlight_rows <- NULL
   }
 
+  # do we need to render <br>?
+  any_br <- any(vapply(final, function(i) any(grepl("<br>", i, fixed = TRUE)), logical(1)))
+  any_nbsp <- any(vapply(final, function(i) any(grepl("&nbsp;", i, fixed = TRUE)), logical(1)))
 
-  # sanity check - clean caption, subtitle and footer from ansi-colour codes,
+  # validation check - clean caption, subtitle and footer from ansi-colour codes,
   # which only work for text format... But if user occidentally provides colours
   # for HTML format as well, remove those colour codes, so they don't appear as
   # text in the table header and footer. Furthermore, in footers, we need to
@@ -991,7 +1105,7 @@ print.insight_table <- function(x, ...) {
   if (!is.null(footer)) {
     if (is.list(footer)) {
       footer <- lapply(footer, function(i) {
-        gsub("\n", "", i[1])
+        gsub("\n", "", i[1], fixed = TRUE)
       })
     } else {
       footer <- footer[1]
@@ -1004,25 +1118,42 @@ print.insight_table <- function(x, ...) {
   footer <- gt::tab_source_note(header, source_note = gt::html(footer))
   out <- gt::cols_align(footer, align = "center")
 
-  # align columns
-  if (!is.null(out[["_boxhead"]]) && !is.null(out[["_boxhead"]]$column_align)) {
-    if (align == "firstleft") {
-      out[["_boxhead"]]$column_align[1] <- "left"
-    } else {
-      col_align <- NULL
-      for (i in 1:nchar(align)) {
-        col_align <- c(
-          col_align,
-          switch(substr(align, i, i),
-            "l" = "left",
-            "r" = "right",
-            "center"
-          )
-        )
-      }
-      out[["_boxhead"]]$column_align <- col_align
+  # emphasize header of row groups?
+  if (!is.null(highlight_rows) && length(highlight_rows)) {
+    out <- gt::tab_style(
+      out,
+      style = gt::cell_text(style = "oblique"),
+      locations = gt::cells_body(columns = 1, rows = highlight_rows)
+    )
+  }
+
+  # emphasize row groups labels? when we have group_by_columns
+  if (!is.null(group_by_columns)) {
+    out <- gt::tab_style(
+      out,
+      style = gt::cell_text(style = "oblique"),
+      locations = gt::cells_row_groups()
+    )
+  }
+
+  # custom alignment of columns
+  if (align == "firstleft") {
+    out <- gt::cols_align(out, "left", 1)
+  } else {
+    for (i in 1:nchar(align)) {
+      col_align <- switch(substr(align, i, i),
+        l = "left",
+        r = "right",
+        "center"
+      )
+      out <- gt::cols_align(out, col_align, i)
     }
   }
 
+  # correctly render line breaks like <br>
+  if (any_br || any_nbsp) {
+    out <- gt::fmt_markdown(out)
+  }
+
   out
 }
