@@ -2,18 +2,17 @@
 #' @name find_parameters
 #'
 #' @description Returns the names of model parameters, like they typically
-#'     appear in the `summary()` output. For Bayesian models, the parameter
-#'     names equal the column names of the posterior samples after coercion
-#'     from `as.data.frame()`. See the documentation for your object's class:
-#'    \itemize{
-#'      \item{[Bayesian models][find_parameters.BGGM] (\pkg{rstanarm}, \pkg{brms}, \pkg{MCMCglmm}, ...)}
-#'      \item{[Generalized additive models][find_parameters.gamlss] (\pkg{mgcv}, \pkg{VGAM}, ...)}
-#'      \item{[Marginal effects models][find_parameters.betamfx] (\pkg{mfx})}
-#'      \item{[Estimated marginal means][find_parameters.emmGrid] (\pkg{emmeans})}
-#'      \item{[Mixed models][find_parameters.glmmTMB] (\pkg{lme4}, \pkg{glmmTMB}, \pkg{GLMMadaptive}, ...)}
-#'      \item{[Zero-inflated and hurdle models][find_parameters.zeroinfl] (\pkg{pscl}, ...)}
-#'      \item{[Models with special components][find_parameters.averaging] (\pkg{betareg}, \pkg{MuMIn}, ...)}
-#'    }
+#' appear in the `summary()` output. For Bayesian models, the parameter
+#' names equal the column names of the posterior samples after coercion
+#' from `as.data.frame()`. See the documentation for your object's class:
+#'
+#' - [Bayesian models][find_parameters.BGGM] (**rstanarm**, **brms**, **MCMCglmm**, ...)
+#' - [Generalized additive models][find_parameters.gamlss] (**mgcv**, **VGAM**, ...)
+#' - [Marginal effects models][find_parameters.betamfx] (**mfx**)
+#' - [Estimated marginal means][find_parameters.emmGrid] (**emmeans**)
+#' - [Mixed models][find_parameters.glmmTMB] (**lme4**, **glmmTMB**, **GLMMadaptive**, ...)
+#' - [Zero-inflated and hurdle models][find_parameters.zeroinfl] (**pscl**, ...)
+#' - [Models with special components][find_parameters.averaging] (**betareg**, **MuMIn**, ...)
 #'
 #' @param verbose Toggle messages and warnings.
 #' @param ... Currently not used.
@@ -21,6 +20,8 @@
 #'
 #' @inheritSection find_predictors Model components
 #'
+#' @inheritSection find_predictors Parameters, Variables, Predictors and Terms
+#'
 #' @return A list of parameter names. For simple models, only one list-element,
 #'    `conditional`, is returned.
 #'
@@ -34,7 +35,6 @@ find_parameters <- function(x, ...) {
 }
 
 
-
 # Default methods -------------------------------------------
 
 
@@ -57,7 +57,6 @@ find_parameters.default <- function(x, flatten = FALSE, verbose = TRUE, ...) {
     )
   }
 
-
   if (is.null(pars$conditional) || is.null(pars)) {
     if (isTRUE(verbose)) {
       format_warning(sprintf("Parameters can't be retrieved for objects of class `%s`.", class(x)[1]))
@@ -67,36 +66,32 @@ find_parameters.default <- function(x, flatten = FALSE, verbose = TRUE, ...) {
 
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
 }
 
 
-
 #' @export
 find_parameters.data.frame <- function(x, flatten = FALSE, ...) {
   format_error("A data frame is no valid object for this function.")
 }
 
 
-
 #' @export
 find_parameters.summary.lm <- function(x, flatten = FALSE, ...) {
   cf <- stats::coef(x)
   l <- list(conditional = text_remove_backticks(rownames(cf)))
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
 }
 
 
-
-
 # Ordinal -----------------------------------------------
 
 #' @export
@@ -105,14 +100,13 @@ find_parameters.polr <- function(x, flatten = FALSE, ...) {
   pars$conditional <- text_remove_backticks(pars$conditional)
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
 }
 
 
-
 #' @export
 find_parameters.clm2 <- function(x, flatten = FALSE, ...) {
   cf <- stats::coef(x)
@@ -132,7 +126,7 @@ find_parameters.clm2 <- function(x, flatten = FALSE, ...) {
   }
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
@@ -142,21 +136,19 @@ find_parameters.clm2 <- function(x, flatten = FALSE, ...) {
 find_parameters.clmm2 <- find_parameters.clm2
 
 
-
 #' @export
 find_parameters.bracl <- function(x, flatten = FALSE, ...) {
   pars <- list(conditional = names(stats::coef(x)))
   pars$conditional <- text_remove_backticks(pars$conditional)
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
 }
 
 
-
 #' @export
 find_parameters.multinom <- function(x, flatten = FALSE, ...) {
   params <- stats::coef(x)
@@ -171,22 +163,33 @@ find_parameters.multinom <- function(x, flatten = FALSE, ...) {
   pars$conditional <- text_remove_backticks(pars$conditional)
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
+  } else {
+    pars
+  }
+}
+
+#' @export
+find_parameters.brmultinom <- find_parameters.multinom
+
+#' @export
+find_parameters.multinom_weightit <- function(x, flatten = FALSE, ...) {
+  params <- stats::coef(x)
+  resp <- gsub("(.*)~(.*)", "\\1", names(params))
+  pars <- list(conditional = gsub("(.*)~(.*)", "\\2", names(params))[resp == resp[1]])
+
+  if (flatten) {
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
 }
 
 
-#' @export
-find_parameters.brmultinom <- find_parameters.multinom
-
-
 # SEM models ------------------------------------------------------
 
 #' @export
 find_parameters.blavaan <- function(x, flatten = FALSE, ...) {
-  # installed?
   check_if_installed("lavaan")
 
   param_tab <- lavaan::parameterEstimates(x)
@@ -194,7 +197,7 @@ find_parameters.blavaan <- function(x, flatten = FALSE, ...) {
 
   coef_labels <- names(lavaan::coef(x))
 
-  if ("group" %in% colnames(param_tab) && n_unique(param_tab$group) > 1) {
+  if ("group" %in% colnames(param_tab) && n_unique(param_tab$group) > 1L) {
     params <- paste0(params, " (group ", param_tab$group, ")")
     groups <- grepl("(.*)\\.g(.*)", coef_labels)
     coef_labels[!groups] <- paste0(coef_labels[!groups], " (group 1)")
@@ -226,7 +229,7 @@ find_parameters.blavaan <- function(x, flatten = FALSE, ...) {
   pars <- compact_list(lapply(pars, function(i) i$pars))
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
@@ -235,7 +238,6 @@ find_parameters.blavaan <- function(x, flatten = FALSE, ...) {
 
 #' @export
 find_parameters.lavaan <- function(x, flatten = FALSE, ...) {
-  # installed?
   check_if_installed("lavaan")
 
   pars <- get_parameters(x)
@@ -243,23 +245,18 @@ find_parameters.lavaan <- function(x, flatten = FALSE, ...) {
   pars <- split(pars$Parameter, pars$Component)
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
 }
 
 
-
-
 # Panel models ----------------------------------------
 
 #' @export
-find_parameters.pgmm <- function(x,
-                                 component = c("conditional", "all"),
-                                 flatten = FALSE,
-                                 ...) {
-  component <- match.arg(component)
+find_parameters.pgmm <- function(x, component = "conditional", flatten = FALSE, ...) {
+  component <- validate_argument(component, c("conditional", "all"))
   s <- summary(x, robust = FALSE)
 
   l <- list(
@@ -290,7 +287,7 @@ find_parameters.wbm <- function(x, flatten = FALSE, ...) {
   pars$conditional <- text_remove_backticks(pars$conditional)
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
@@ -310,6 +307,25 @@ find_parameters.rms <- find_parameters.default
 find_parameters.tobit <- find_parameters.default
 
 
+#' @export
+find_parameters.nestedLogit <- function(x, flatten = FALSE, verbose = TRUE, ...) {
+  pars <- tryCatch(
+    {
+      p <- text_remove_backticks(row.names(stats::coef(x)))
+      list(conditional = p)
+    },
+    error = function(x) {
+      NULL
+    }
+  )
+  if (flatten) {
+    unique(unlist(pars, use.names = FALSE))
+  } else {
+    pars
+  }
+}
+
+
 #' @export
 find_parameters.Rchoice <- function(x, flatten = FALSE, ...) {
   cf <- names(stats::coef(x))
@@ -319,7 +335,7 @@ find_parameters.Rchoice <- function(x, flatten = FALSE, ...) {
   out <- list(conditional = cf)
 
   if (flatten) {
-    unique(unlist(out))
+    unique(unlist(out, use.names = FALSE))
   } else {
     out
   }
@@ -332,7 +348,7 @@ find_parameters.btergm <- function(x, flatten = FALSE, ...) {
   out <- list(conditional = names(cf))
 
   if (flatten) {
-    unique(unlist(out))
+    unique(unlist(out, use.names = FALSE))
   } else {
     out
   }
@@ -345,7 +361,7 @@ find_parameters.crr <- function(x, flatten = FALSE, ...) {
   out <- list(conditional = names(cs))
 
   if (flatten) {
-    unique(unlist(out))
+    unique(unlist(out, use.names = FALSE))
   } else {
     out
   }
@@ -358,7 +374,7 @@ find_parameters.riskRegression <- function(x, flatten = FALSE, ...) {
   out <- list(conditional = as.vector(cs[, 1]))
 
   if (flatten) {
-    unique(unlist(out))
+    unique(unlist(out, use.names = FALSE))
   } else {
     out
   }
@@ -370,7 +386,7 @@ find_parameters.lmodel2 <- function(x, flatten = FALSE, ...) {
   out <- list(conditional = c("Intercept", "Slope"))
 
   if (flatten) {
-    unique(unlist(out))
+    unique(unlist(out, use.names = FALSE))
   } else {
     out
   }
@@ -382,7 +398,7 @@ find_parameters.ivFixed <- function(x, flatten = FALSE, ...) {
   out <- list(conditional = rownames(x$coefficients))
 
   if (flatten) {
-    unique(unlist(out))
+    unique(unlist(out, use.names = FALSE))
   } else {
     out
   }
@@ -394,7 +410,7 @@ find_parameters.ivprobit <- function(x, flatten = FALSE, ...) {
   out <- list(conditional = x$names)
 
   if (flatten) {
-    unique(unlist(out))
+    unique(unlist(out, use.names = FALSE))
   } else {
     out
   }
@@ -424,7 +440,7 @@ find_parameters.mediate <- function(x, flatten = FALSE, ...) {
     )
   }
   if (flatten) {
-    unique(unlist(out))
+    unique(unlist(out, use.names = FALSE))
   } else {
     out
   }
@@ -436,7 +452,7 @@ find_parameters.ridgelm <- function(x, flatten = FALSE, ...) {
   out <- list(conditional = names(x$coef))
 
   if (flatten) {
-    unique(unlist(out))
+    unique(unlist(out, use.names = FALSE))
   } else {
     out
   }
@@ -449,7 +465,7 @@ find_parameters.survreg <- function(x, flatten = FALSE, ...) {
   out <- list(conditional = rownames(s$table))
 
   if (flatten) {
-    unique(unlist(out))
+    unique(unlist(out, use.names = FALSE))
   } else {
     out
   }
@@ -458,14 +474,13 @@ find_parameters.survreg <- function(x, flatten = FALSE, ...) {
 
 #' @export
 find_parameters.mle2 <- function(x, flatten = FALSE, ...) {
-  # installed?
   check_if_installed("bbmle")
 
   s <- bbmle::summary(x)
   out <- list(conditional = rownames(s@coef))
 
   if (flatten) {
-    unique(unlist(out))
+    unique(unlist(out, use.names = FALSE))
   } else {
     out
   }
@@ -487,7 +502,7 @@ find_parameters.glht <- function(x, flatten = FALSE, ...) {
   l <- list(conditional = paste(names(s$test$coefficients), alt, x$rhs))
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -499,7 +514,7 @@ find_parameters.manova <- function(x, flatten = FALSE, ...) {
   out <- list(conditional = text_remove_backticks(rownames(stats::na.omit(stats::coef(x)))))
 
   if (flatten) {
-    unique(unlist(out))
+    unique(unlist(out, use.names = FALSE))
   } else {
     out
   }
@@ -509,13 +524,12 @@ find_parameters.manova <- function(x, flatten = FALSE, ...) {
 find_parameters.maov <- find_parameters.manova
 
 
-
 #' @export
 find_parameters.afex_aov <- function(x, flatten = FALSE, ...) {
-  if (!is.null(x$aov)) {
-    find_parameters(x$aov, flatten = flatten, ...)
-  } else {
+  if (is.null(x$aov)) {
     find_parameters(x$lm, flatten = flatten, ...)
+  } else {
+    find_parameters(x$aov, flatten = flatten, ...)
   }
 }
 
@@ -525,7 +539,7 @@ find_parameters.anova.rms <- function(x, flatten = FALSE, ...) {
   l <- list(conditional = text_remove_backticks(rownames(x)))
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -544,14 +558,13 @@ find_parameters.mlm <- function(x, flatten = FALSE, ...) {
   attr(out, "is_mv") <- TRUE
 
   if (flatten) {
-    unique(unlist(out))
+    unique(unlist(out, use.names = FALSE))
   } else {
     out
   }
 }
 
 
-
 #' @export
 find_parameters.mvord <- function(x, flatten = FALSE, ...) {
   junk <- utils::capture.output(s <- summary(x)) # nolint
@@ -564,14 +577,13 @@ find_parameters.mvord <- function(x, flatten = FALSE, ...) {
   attr(out, "is_mv") <- TRUE
 
   if (flatten) {
-    unique(unlist(out))
+    unique(unlist(out, use.names = FALSE))
   } else {
     out
   }
 }
 
 
-
 #' @export
 find_parameters.gbm <- function(x, flatten = FALSE, ...) {
   s <- summary(x, plotit = FALSE)
@@ -579,35 +591,33 @@ find_parameters.gbm <- function(x, flatten = FALSE, ...) {
   pars$conditional <- text_remove_backticks(pars$conditional)
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
 }
 
 
-
 #' @export
 find_parameters.BBreg <- function(x, flatten = FALSE, ...) {
   pars <- list(conditional = rownames(stats::coef(x)))
   pars$conditional <- text_remove_backticks(pars$conditional)
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
 }
 
 
-
 #' @export
 find_parameters.lrm <- function(x, flatten = FALSE, ...) {
   pars <- list(conditional = names(stats::coef(x)))
   pars$conditional <- text_remove_backticks(pars$conditional)
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
@@ -617,33 +627,31 @@ find_parameters.lrm <- function(x, flatten = FALSE, ...) {
 find_parameters.flexsurvreg <- find_parameters.lrm
 
 
-
 #' @export
 find_parameters.aovlist <- function(x, flatten = FALSE, ...) {
-  l <- list(conditional = unname(text_remove_backticks(unlist(lapply(stats::coef(x), names)))))
+  l <- list(conditional = text_remove_backticks(unlist(lapply(stats::coef(x), names), use.names = FALSE)))
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
 }
 
 
-
 #' @export
 find_parameters.rqs <- function(x, flatten = FALSE, ...) {
   sc <- suppressWarnings(summary(x))
 
-  if (all(unlist(lapply(sc, is.list)))) {
-    pars <- list(conditional = rownames(stats::coef(sc[[1]])))
-  } else {
+  if (!all(unlist(lapply(sc, is.list), use.names = FALSE))) {
     return(find_parameters.default(x, flatten = flatten, ...))
   }
+
+  pars <- list(conditional = rownames(stats::coef(sc[[1]])))
   pars$conditional <- text_remove_backticks(pars$conditional)
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
@@ -662,7 +670,7 @@ find_parameters.crq <- function(x, flatten = FALSE, ...) {
   pars$conditional <- text_remove_backticks(pars$conditional)
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
@@ -672,7 +680,6 @@ find_parameters.crq <- function(x, flatten = FALSE, ...) {
 find_parameters.crqs <- find_parameters.crq
 
 
-
 #' @export
 find_parameters.lqmm <- function(x, flatten = FALSE, ...) {
   cs <- stats::coef(x)
@@ -685,7 +692,7 @@ find_parameters.lqmm <- function(x, flatten = FALSE, ...) {
   pars$conditional <- text_remove_backticks(pars$conditional)
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
@@ -695,8 +702,6 @@ find_parameters.lqmm <- function(x, flatten = FALSE, ...) {
 find_parameters.lqm <- find_parameters.lqmm
 
 
-
-
 #' @export
 find_parameters.aareg <- function(x, flatten = FALSE, ...) {
   sc <- summary(x)
@@ -705,38 +710,31 @@ find_parameters.aareg <- function(x, flatten = FALSE, ...) {
   pars$conditional <- text_remove_backticks(pars$conditional)
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
 }
 
 
-
 #' @export
 find_parameters.rma <- function(x, flatten = FALSE, ...) {
-  tryCatch(
-    {
-      cf <- stats::coef(x)
-      pars <- list(conditional = names(cf))
+  .safe({
+    cf <- stats::coef(x)
+    pars <- list(conditional = names(cf))
 
-      pars$conditional[grepl("intrcpt", pars$conditional, fixed = TRUE)] <- "(Intercept)"
-      pars$conditional <- text_remove_backticks(pars$conditional)
+    pars$conditional[grepl("intrcpt", pars$conditional, fixed = TRUE)] <- "(Intercept)"
+    pars$conditional <- text_remove_backticks(pars$conditional)
 
-      if (flatten) {
-        unique(unlist(pars))
-      } else {
-        pars
-      }
-    },
-    error = function(x) {
-      NULL
+    if (flatten) {
+      unique(unlist(pars, use.names = FALSE))
+    } else {
+      pars
     }
-  )
+  })
 }
 
 
-
 #' @export
 find_parameters.meta_random <- function(x, flatten = FALSE, ...) {
   tryCatch(
@@ -746,7 +744,7 @@ find_parameters.meta_random <- function(x, flatten = FALSE, ...) {
       pars$conditional[pars$conditional == "d"] <- "(Intercept)"
 
       if (flatten) {
-        unique(unlist(pars))
+        unique(unlist(pars, use.names = FALSE))
       } else {
         pars
       }
@@ -757,7 +755,6 @@ find_parameters.meta_random <- function(x, flatten = FALSE, ...) {
   )
 }
 
-
 #' @export
 find_parameters.meta_fixed <- find_parameters.meta_random
 
@@ -765,7 +762,6 @@ find_parameters.meta_fixed <- find_parameters.meta_random
 find_parameters.meta_bma <- find_parameters.meta_random
 
 
-
 #' @export
 find_parameters.metaplus <- function(x, flatten = FALSE, ...) {
   pars <- list(conditional = rownames(x$results))
@@ -773,21 +769,20 @@ find_parameters.metaplus <- function(x, flatten = FALSE, ...) {
   pars$conditional <- text_remove_backticks(pars$conditional)
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
 }
 
 
-
 #' @export
 find_parameters.mipo <- function(x, flatten = FALSE, ...) {
-  pars <- list(conditional = as.vector(summary(x)$term))
+  pars <- list(conditional = unique(as.vector(summary(x)$term)))
   pars$conditional <- text_remove_backticks(pars$conditional)
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
@@ -799,25 +794,24 @@ find_parameters.mira <- function(x, flatten = FALSE, ...) {
   find_parameters(x$analyses[[1]], flatten = flatten, ...)
 }
 
+
 ## For questions or problems with this ask Fernando Miguez (femiguez@iastate.edu)
 #' @export
-find_parameters.nls <- function(x,
-                                component = c("all", "conditional", "nonlinear"),
-                                flatten = FALSE,
-                                ...) {
-  component <- match.arg(component)
-  f <- find_formula(x)
+find_parameters.nls <- function(x, component = "all", flatten = FALSE, ...) {
+  component <- validate_argument(component, c("all", "conditional", "nonlinear"))
+  f <- find_formula(x, verbose = FALSE)
   elements <- .get_elements(effects = "fixed", component = component)
   f <- .prepare_predictors(x, f, elements)
   pars <- .return_vars(f, x)
 
   if (flatten) {
-    unique(unlist(pars))
+    unique(unlist(pars, use.names = FALSE))
   } else {
     pars
   }
 }
 
+
 # helper ----------------------------
 
 .filter_parameters <- function(l, effects, component = "all", flatten, recursive = TRUE) {
@@ -835,7 +829,7 @@ find_parameters.nls <- function(x,
   l <- compact_list(l[elements])
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
