@@ -10,7 +10,7 @@
 #' format_pd(c(0.12, 1, 0.9999, 0.98, 0.995, 0.96), stars = TRUE)
 #' @export
 format_pd <- function(pd, stars = FALSE, stars_only = FALSE, name = "pd") {
-  text <- ifelse(pd >= 1, "= 100%***",
+  p_text <- ifelse(pd >= 1, "= 100%***",
     ifelse(pd > 0.999, paste0("= ", format_value(pd * 100), "%***"), # nolint
       ifelse(pd > 0.99, paste0("= ", format_value(pd * 100), "%**"), # nolint
         ifelse(pd > 0.97, paste0("= ", format_value(pd * 100), "%*"), # nolint
@@ -20,5 +20,5 @@ format_pd <- function(pd, stars = FALSE, stars_only = FALSE, name = "pd") {
     )
   )
 
-  .add_prefix_and_remove_stars(text, stars, stars_only, name)
+  .add_prefix_and_remove_stars(p_text, stars, stars_only, name)
 }
