@@ -32,13 +32,11 @@
 #'
 #' @return The data that was used to fit the model.
 #'
-#' @examples
-#' if (require("lme4")) {
-#'   data(cbpp, package = "lme4")
-#'   cbpp$trials <- cbpp$size - cbpp$incidence
-#'   m <- glm(cbind(incidence, trials) ~ period, data = cbpp, family = binomial)
-#'   head(get_data(m))
-#' }
+#' @examplesIf require("lme4", quietly = TRUE)
+#' data(cbpp, package = "lme4")
+#' cbpp$trials <- cbpp$size - cbpp$incidence
+#' m <- glm(cbind(incidence, trials) ~ period, data = cbpp, family = binomial)
+#' head(get_data(m))
 #' @export
 get_data <- function(x, ...) {
   UseMethod("get_data")
@@ -50,7 +48,8 @@ get_data <- function(x, ...) {
 # main workhorse, we try to recover data from environment as good as possible.
 # the dataset is subset if needed, and weights are added. only those columns
 # are returned that we actually find in the model...
-# data_name is useful when we have the name of the data frame object stored as a string (e.g., in brmsfit attr(x$data, "data_frame"))
+# data_name is useful when we have the name of the data frame object stored as
+# a string (e.g., in brmsfit attr(x$data, "data_frame"))
 .get_data_from_environment <- function(x,
                                        effects = "all",
                                        component = "all",
@@ -67,15 +66,30 @@ get_data <- function(x, ...) {
   }
 
   # handle arguments
-  effects <- match.arg(effects, choices = c("all", "fixed", "random"))
-  component <- match.arg(component, choices = c("all", "conditional", "zero_inflated", "zi", "smooth_terms", "dispersion"))
+  effects <- validate_argument(effects, c("all", "fixed", "random"))
+  component <- validate_argument(
+    component,
+    c("all", "conditional", "zero_inflated", "zi", "smooth_terms", "dispersion")
+  )
 
   # we want to add the variable for subsettig, too
   model_call <- get_call(x)
 
+  # for random effects, we still need all variables to be extracted
+  # in case we have missing data. E.g., if random effects variables have
+  # no missing data, but response or other fixed effects has, "get_random()"
+  # should only return non-missing data for the model - thus, missing cases
+  # in any fixed effects variable should be removed, even if non-missing in
+  # random effects variables (see #777)
+  if (effects == "random") {
+    selected_vars <- "all"
+  } else {
+    selected_vars <- effects
+  }
+
   # extract model variables, if possible
   vars <- try(
-    find_variables(x, effects = effects, component = component, flatten = TRUE, verbose = FALSE),
+    find_variables(x, effects = selected_vars, component = component, flatten = TRUE, verbose = FALSE),
     silent = TRUE
   )
 
@@ -100,7 +114,14 @@ get_data <- function(x, ...) {
   out <- tryCatch(
     {
       # recover data frame from environment
-      dat <- .recover_data_from_environment(x, data_name = data_name)
+      dat <- .recover_data_from_environment(x, data_name = data_name, verbose = verbose)
+      # for metafor, we need to add weights...
+      if (inherits(x, c("rma.uni", "rma"))) {
+        ## TODO: check if we need to do this for other meta-analysis packages, too
+        wdat <- data.frame(Weights = get_weights(x))
+        additional_variables <- c(additional_variables, "Weights")
+        dat <- tryCatch(cbind(dat, wdat), error = function(e) dat)
+      }
       # additional variables? Some models, like plm::plm(), have an "index"
       # slot in the model call with further variables
       if (!is.null(additional_variables) && !isTRUE(additional_variables)) {
@@ -108,7 +129,7 @@ get_data <- function(x, ...) {
       }
       # add response, only required if "find_variables()" does not already
       # return it (which is the case when component is "all" or "conditional")
-      if (effects %in% c("all", "fixed") && !component %in% c("all", "conditional")) {
+      if (!component %in% c("all", "conditional")) {
         vars <- c(vars, find_response(x, combine = FALSE))
       }
 
@@ -126,7 +147,8 @@ get_data <- function(x, ...) {
         vars <- c(vars, find_offset(x))
         # subset?
         if (!is.null(model_call$subset)) {
-          vars <- c(vars, all.vars(model_call$subset))
+          subset_vars <- .safe(all.vars(model_call$subset))
+          vars <- c(vars, subset_vars)
         }
         vars <- unique(vars)
         # if "additional_variables" is TRUE, keep *all* variables from original
@@ -136,18 +158,17 @@ get_data <- function(x, ...) {
         }
       }
 
-      # remove response for random effects
-      if (effects == "random") {
-        resp <- find_response(x, combine = FALSE)
-        dat <- dat[, setdiff(colnames(dat), resp), drop = FALSE]
-      }
-
       # complete cases only, as in model frames, need to filter attributes
       # only use model variables in complete.cases()
-      if (!is.null(vars)) {
-        cc <- stats::complete.cases(dat[, intersect(vars, colnames(dat))])
-      } else {
+      if (is.null(vars)) {
         cc <- stats::complete.cases(dat)
+      } else {
+        cc <- stats::complete.cases(dat[, intersect(vars, colnames(dat))])
+      }
+
+      # only preserve random effects
+      if (effects == "random") {
+        dat <- dat[find_random(x, split_nested = TRUE, flatten = TRUE)]
       }
 
       if (!all(cc)) {
@@ -194,63 +215,67 @@ get_data <- function(x, ...) {
 
 # return data from a data frame that is in the environment,
 # and subset the data, if necessary
-.recover_data_from_environment <- function(x, data_name = NULL) {
+.recover_data_from_environment <- function(x, data_name = NULL, verbose = FALSE) {
   model_call <- get_call(x)
 
   if (is.null(model_call[["data"]]) && is.character(data_name)) {
     model_call[["data"]] <- as.name(data_name)
   }
 
-  # first, try environment of formula, see #666
-  dat <- tryCatch(eval(model_call$data, envir = environment(model_call$formula)),
-    error = function(e) NULL
-  )
+  # special handling for fixest, see #767
+  if (inherits(x, "fixest")) {
+    # when called from inside function, fixest seems to have a different
+    # environment that requires recovering from parent-environment
+    dat <- .safe(eval(model_call$data, envir = parent.env(x$call_env)))
+  } else {
+    # first, try environment of formula, see #666. set enclos = NULL so eval()
+    # does not fall back to parent frame when the environment is NULL, since we
+    # want to try that after checking the formula
+    dat <- .safe(eval(model_call$data,
+      envir = environment(model_call$formula),
+      enclos = NULL
+    ))
+  }
 
   # second, try to extract formula directly
   if (is.null(dat)) {
-    dat <- tryCatch(eval(model_call$data, envir = environment(find_formula(x))),
-      error = function(e) NULL
-    )
+    dat <- .safe(eval(model_call$data,
+      envir = environment(find_formula(x, verbose = FALSE)$conditional),
+      enclos = NULL
+    ))
   }
 
-  # next try, parent frame
-  if (is.null(dat)) {
-    dat <- tryCatch(eval(model_call$data, envir = parent.frame()),
-      error = function(e) NULL
-    )
-  }
-
-  # sanity check- if data frame is named like a function, e.g.
+  # validation check- if data frame is named like a function, e.g.
   # rep <- data.frame(...), we now have a function instead of the data
   # we then need to reset "dat" to NULL and search in the global env
 
   if (!is.null(dat) && !is.data.frame(dat)) {
-    dat <- tryCatch(as.data.frame(dat), error = function(e) NULL)
+    dat <- .safe(as.data.frame(dat))
   }
 
   # third try, global env
   if (is.null(dat)) {
-    dat <- tryCatch(eval(model_call$data, envir = globalenv()),
-      error = function(e) NULL
-    )
+    dat <- .safe(eval(model_call$data, envir = globalenv()))
   }
 
   # last try, internal env
   if (is.null(dat)) {
-    dat <- tryCatch(eval(model_call$data, envir = parent.env(x$call_env)),
-      error = function(e) NULL
-    )
+    dat <- .safe(eval(model_call$data, envir = parent.env(x$call_env)))
   }
 
   if (!is.null(dat) && object_has_names(model_call, "subset")) {
-    dat <- subset(dat, subset = eval(model_call$subset))
+    subset_data <- .safe(subset(dat, subset = eval(model_call$subset)))
+    if (!is.null(subset_data)) {
+      dat <- subset_data
+    } else if (verbose) {
+      format_warning("Looks like the original data was subset, however `get_data()` could not retrieve the subset of the data. The full data set is returned.") # nolint
+    }
   }
 
   dat
 }
 
 
-
 # default method ------------------------------------------------------
 
 #' @rdname get_data
@@ -267,16 +292,12 @@ get_data.default <- function(x, source = "environment", verbose = TRUE, ...) {
   # fall back to extract data from model frame
   if (is.null(model_data)) {
     mf <- tryCatch(
-      {
-        if (inherits(x, "Zelig-relogit")) {
-          .get_zelig_relogit_frame(x)
-        } else {
-          stats::model.frame(x)
-        }
+      if (inherits(x, "Zelig-relogit")) {
+        .get_zelig_relogit_frame(x)
+      } else {
+        stats::model.frame(x)
       },
-      error = function(x) {
-        NULL
-      }
+      error = function(x) NULL
     )
     # process arguments, check whether data should be recovered from
     # environment or model frame
@@ -286,7 +307,7 @@ get_data.default <- function(x, source = "environment", verbose = TRUE, ...) {
     if ((is.null(mf) || nrow(mf) == 0) && source != "environment") {
       mf <- tryCatch(
         {
-          dat <- .recover_data_from_environment(x)
+          dat <- .recover_data_from_environment(x, verbose = verbose)
           vars <- find_variables(x, flatten = TRUE, verbose = FALSE)
           dat[, intersect(vars, colnames(dat)), drop = FALSE]
         },
@@ -319,7 +340,7 @@ get_data.maxim <- get_data.default
 #' @export
 get_data.summary.lm <- function(x, verbose = TRUE, ...) {
   mf <- tryCatch(
-    .recover_data_from_environment(x)[, all.vars(x$terms), drop = FALSE],
+    .recover_data_from_environment(x, verbose = verbose)[, all.vars(x$terms), drop = FALSE],
     error = function(x) NULL
   )
   .prepare_get_data(x, mf, verbose = verbose)
@@ -338,7 +359,6 @@ get_data.mhurdle <- function(x, verbose = TRUE, ...) {
 }
 
 
-
 # classical and survival models -----------------------------------------------
 
 
@@ -409,6 +429,9 @@ get_data.geeglm <- function(x,
   .prepare_get_data(x, mf, effects = effects, verbose = verbose)
 }
 
+#' @export
+get_data.glmgee <- get_data.geeglm
+
 
 #' @export
 get_data.gee <- function(x,
@@ -432,7 +455,7 @@ get_data.gee <- function(x,
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
   mf <- tryCatch(
     {
-      dat <- .recover_data_from_environment(x)
+      dat <- .recover_data_from_environment(x, verbose = verbose)
       vars <- switch(effects,
         all = find_variables(x, flatten = TRUE, verbose = FALSE),
         fixed = find_variables(x, effects = "fixed", flatten = TRUE, verbose = FALSE),
@@ -471,7 +494,7 @@ get_data.rqss <- function(x,
 
   mf <- tryCatch(
     {
-      dat <- .recover_data_from_environment(x)
+      dat <- .recover_data_from_environment(x, verbose = verbose)
       vars <- find_variables(
         x,
         effects = "all",
@@ -501,7 +524,7 @@ get_data.gls <- function(x, source = "environment", verbose = TRUE, ...) {
   # fall back to extract data from model frame
   mf <- tryCatch(
     {
-      dat <- .recover_data_from_environment(x)
+      dat <- .recover_data_from_environment(x, verbose = verbose)
       data_columns <- intersect(
         colnames(dat),
         find_variables(x, flatten = TRUE, verbose = FALSE)
@@ -624,10 +647,10 @@ get_data.zcpglm <- function(x,
   }
 
   mf <- switch(component,
-    "all" = do.call(cbind, compact_list(list(mf_tweedie, mf_zero))),
-    "conditional" = mf_tweedie,
-    "zi" = ,
-    "zero_inflated" = mf_zero
+    all = do.call(cbind, compact_list(list(mf_tweedie, mf_zero))),
+    conditional = mf_tweedie,
+    zi = ,
+    zero_inflated = mf_zero
   )
   .prepare_get_data(x, stats::na.omit(mf), verbose = verbose)
 }
@@ -704,18 +727,13 @@ get_data.merMod <- function(x,
   # fall back to extract data from model frame
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
 
-  mf <- tryCatch(
-    {
-      switch(effects,
-        fixed = stats::model.frame(x, fixed.only = TRUE),
-        all = stats::model.frame(x, fixed.only = FALSE),
-        random = stats::model.frame(x, fixed.only = FALSE)[, find_random(x, split_nested = TRUE, flatten = TRUE), drop = FALSE]
-      )
-    },
-    error = function(x) {
-      NULL
-    }
-  )
+  mf <- .safe({
+    switch(effects,
+      fixed = stats::model.frame(x, fixed.only = TRUE),
+      all = stats::model.frame(x, fixed.only = FALSE),
+      random = stats::model.frame(x, fixed.only = FALSE)[, find_random(x, split_nested = TRUE, flatten = TRUE), drop = FALSE] # nolint
+    )
+  })
   .prepare_get_data(x, mf, effects, verbose = verbose)
 }
 
@@ -731,18 +749,14 @@ get_data.mmrm <- function(x,
   fixed_vars <- find_variables(x, effects = "fixed", flatten = TRUE)
   random_vars <- find_random(x, split_nested = TRUE, flatten = TRUE)
   # data from model frame
-  mf <- .prepare_get_data(x, stats::model.frame(x, full = TRUE), effects, verbose = verbose)
+  mf <- .prepare_get_data(x, stats::model.frame(x), effects, verbose = verbose)
   tryCatch(
-    {
-      switch(effects,
-        fixed = mf[intersect(colnames(mf), fixed_vars)],
-        all = mf[intersect(colnames(mf), unique(c(fixed_vars, random_vars)))],
-        random = mf[intersect(colnames(mf), random_vars)]
-      )
-    },
-    error = function(x) {
-      NULL
-    }
+    switch(effects,
+      fixed = mf[intersect(colnames(mf), fixed_vars)],
+      all = mf[intersect(colnames(mf), unique(c(fixed_vars, random_vars)))],
+      random = mf[intersect(colnames(mf), random_vars)]
+    ),
+    error = function(x) NULL
   )
 }
 
@@ -755,7 +769,7 @@ get_data.mmrm_tmb <- get_data.mmrm
 
 #' @export
 get_data.merModList <- function(x, effects = "all", ...) {
-  warning("Can't access data for `merModList` objects.", call. = FALSE)
+  format_warning("Can't access data for `merModList` objects.")
   return(NULL)
 }
 
@@ -776,18 +790,13 @@ get_data.MANOVA <- function(x,
   # fall back to extract data from model frame
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
 
-  mf <- tryCatch(
-    {
-      switch(effects,
-        fixed = .remove_column(x$input$data, x$input$subject),
-        all = x$input$data,
-        random = x$input$data[, x$input$subject, drop = FALSE]
-      )
-    },
-    error = function(x) {
-      NULL
-    }
-  )
+  mf <- .safe({
+    switch(effects,
+      fixed = .remove_column(x$input$data, x$input$subject),
+      all = x$input$data,
+      random = x$input$data[, x$input$subject, drop = FALSE]
+    )
+  })
   .prepare_get_data(x, mf, effects, verbose = verbose)
 }
 
@@ -813,16 +822,12 @@ get_data.cpglmm <- function(x,
   dat <- stats::model.frame(x)
 
   mf <- tryCatch(
-    {
-      switch(effects,
-        fixed = dat[, find_predictors(x, effects = "fixed", flatten = TRUE, verbose = FALSE), drop = FALSE],
-        all = dat,
-        random = dat[, find_random(x, split_nested = TRUE, flatten = TRUE), drop = FALSE]
-      )
-    },
-    error = function(x) {
-      NULL
-    }
+    switch(effects,
+      fixed = dat[, find_predictors(x, effects = "fixed", flatten = TRUE, verbose = FALSE), drop = FALSE],
+      all = dat,
+      random = dat[, find_random(x, split_nested = TRUE, flatten = TRUE), drop = FALSE]
+    ),
+    error = function(x) NULL
   )
   .prepare_get_data(x, mf, effects, verbose = verbose)
 }
@@ -853,28 +858,22 @@ get_data.glmm <- function(x,
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
   dat <- get_data.default(x, verbose = verbose)
 
-  mf <- tryCatch(
-    {
-      switch(effects,
-        fixed = dat[, find_predictors(
-          x,
-          effects = "fixed",
-          flatten = TRUE,
-          verbose = FALSE
-        ), drop = FALSE],
-        all = dat,
-        random = dat[, find_random(x, split_nested = TRUE, flatten = TRUE), drop = FALSE]
-      )
-    },
-    error = function(x) {
-      NULL
-    }
-  )
+  mf <- .safe({
+    switch(effects,
+      fixed = dat[, find_predictors(
+        x,
+        effects = "fixed",
+        flatten = TRUE,
+        verbose = FALSE
+      ), drop = FALSE],
+      all = dat,
+      random = dat[, find_random(x, split_nested = TRUE, flatten = TRUE), drop = FALSE]
+    )
+  })
   .prepare_get_data(x, mf, effects, verbose = verbose)
 }
 
 
-
 #' @export
 get_data.mixor <- function(x,
                            effects = "all",
@@ -897,16 +896,12 @@ get_data.mixor <- function(x,
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
 
   mf <- tryCatch(
-    {
-      switch(effects,
-        fixed = stats::model.frame(x),
-        all = cbind(stats::model.frame(x), x$id),
-        random = data.frame(x$id)
-      )
-    },
-    error = function(x) {
-      NULL
-    }
+    switch(effects,
+      fixed = stats::model.frame(x),
+      all = cbind(stats::model.frame(x), x$id),
+      random = data.frame(x$id)
+    ),
+    error = function(x) NULL
   )
   fix_cn <- which(colnames(mf) %in% c("x.id", "x$id"))
   colnames(mf)[fix_cn] <- safe_deparse(x$call$id)
@@ -937,25 +932,19 @@ get_data.glmmadmb <- function(x,
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
 
   fixed_data <- x$frame
-  random_data <- .recover_data_from_environment(x)[, find_random(x, split_nested = TRUE, flatten = TRUE), drop = FALSE]
+  random_data <- .recover_data_from_environment(x, verbose = verbose)[, find_random(x, split_nested = TRUE, flatten = TRUE), drop = FALSE]
 
-  mf <- tryCatch(
-    {
-      switch(effects,
-        fixed = fixed_data,
-        all = cbind(fixed_data, random_data),
-        random = random_data
-      )
-    },
-    error = function(x) {
-      NULL
-    }
-  )
+  mf <- .safe({
+    switch(effects,
+      fixed = fixed_data,
+      all = cbind(fixed_data, random_data),
+      random = random_data
+    )
+  })
   .prepare_get_data(x, mf, effects, verbose = verbose)
 }
 
 
-
 #' @export
 get_data.rlmerMod <- function(x, effects = "all", source = "environment", verbose = TRUE, ...) {
   # try to recover data from environment
@@ -1002,10 +991,10 @@ get_data.mixed <- function(x,
 #' @param shape Return long or wide data? Only applicable in repeated measures
 #'   designs.
 get_data.afex_aov <- function(x, shape = c("long", "wide"), ...) {
-  if (!length(attr(x, "within"))) {
-    shape <- "long"
-  } else {
+  if (length(attr(x, "within"))) {
     shape <- match.arg(shape)
+  } else {
+    shape <- "long"
   }
   x$data[[shape]]
 }
@@ -1033,7 +1022,7 @@ get_data.sem <- function(x,
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
   mf <- tryCatch(
     {
-      dat <- .recover_data_from_environment(x)
+      dat <- .recover_data_from_environment(x, verbose = verbose)
       vars <- switch(effects,
         all = find_variables(x, flatten = TRUE, verbose = FALSE),
         fixed = find_variables(x, effects = "fixed", flatten = TRUE, verbose = FALSE),
@@ -1060,7 +1049,7 @@ get_data.lme <- function(x, effects = "all", source = "environment", verbose = T
 
   # fall back to extract data from model frame
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
-  dat <- tryCatch(x$data, error = function(x) NULL)
+  dat <- .safe(x$data)
 
   stats::na.omit(.get_data_from_modelframe(x, dat, effects))
 }
@@ -1148,7 +1137,7 @@ get_data.BBmm <- function(x, effects = "all", source = "environment", verbose =
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
   mf <- tryCatch(
     {
-      dat <- .recover_data_from_environment(x)[, find_variables(x, flatten = TRUE), drop = FALSE]
+      dat <- .recover_data_from_environment(x, verbose = verbose)[, find_variables(x, flatten = TRUE), drop = FALSE]
       switch(effects,
         all = dat[, find_variables(x, flatten = TRUE), drop = FALSE],
         fixed = dat[, find_variables(x, effects = "fixed", flatten = TRUE), drop = FALSE],
@@ -1191,18 +1180,17 @@ get_data.glimML <- function(x, effects = "all", source = "environment", verbose
 #' @export
 get_data.lavaan <- function(x, source = "environment", verbose = TRUE, ...) {
   # try to recover data from environment
-  model_data <- .get_data_from_environment(x, source = source, verbose = verbose, ...)
+  if (identical(source, "environment")) {
+    model_data <- .safe(.recover_data_from_environment(x, verbose = verbose), NULL)
 
-  if (!is.null(model_data)) {
-    return(model_data)
+    if (!is.null(model_data)) {
+      return(model_data)
+    }
   }
 
   # fall back to extract data from model frame
-  mf <- tryCatch(.recover_data_from_environment(x),
-    error = function(x) NULL
-  )
-
-  .prepare_get_data(x, stats::na.omit(mf), verbose = verbose)
+  check_if_installed("lavaan")
+  as.data.frame(lavaan::lavInspect(x, what = "data"))
 }
 
 #' @export
@@ -1292,7 +1280,7 @@ get_data.gamlss <- function(x, source = "environment", verbose = TRUE, ...) {
 
       mf_data <- mf_list[[1]]
 
-      if (length(mf_list) > 1) {
+      if (length(mf_list) > 1L) {
         for (i in 2:length(mf_list)) {
           cn <- setdiff(colnames(mf_list[[i]]), colnames(mf_data))
           if (length(cn)) mf_data <- cbind(mf_data, mf_list[[i]][, cn, drop = FALSE])
@@ -1340,7 +1328,7 @@ get_data.feis <- function(x, effects = "all", source = "environment", verbose =
   # fall back to extract data from model frame
   # original data does not appear to be stored in the model object
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
-  mf <- tryCatch(.recover_data_from_environment(x),
+  mf <- tryCatch(.recover_data_from_environment(x, verbose = verbose),
     error = function(x) stats::model.frame(x)
   )
   .get_data_from_modelframe(x, mf, effects, verbose = verbose)
@@ -1361,7 +1349,7 @@ get_data.fixest <- function(x, source = "environment", verbose = TRUE, ...) {
   # see https://github.com/lrberge/fixest/issues/340 and #629
   model_call <- get_call(x)
   mf <- eval(model_call$data, envir = parent.env(x$call_env))
-  # mf <- .recover_data_from_environment(x)
+  # mf <- .recover_data_from_environment(x, verbose = verbose)
   .get_data_from_modelframe(x, mf, effects = "all", verbose = verbose)
 }
 
@@ -1392,7 +1380,7 @@ get_data.pgmm <- function(x, source = "environment", verbose = TRUE, ...) {
 
   # fall back to extract data from model frame
   model_terms <- find_variables(x, effects = "all", component = "all", flatten = TRUE)
-  mf <- tryCatch(.recover_data_from_environment(x)[, model_terms, drop = FALSE],
+  mf <- tryCatch(.recover_data_from_environment(x, verbose = verbose)[, model_terms, drop = FALSE],
     error = function(x) NULL
   )
   .prepare_get_data(x, mf, verbose = verbose)
@@ -1441,7 +1429,7 @@ get_data.plm <- function(x, source = "environment", verbose = TRUE, ...) {
 
   # try to get index variables from orignal data
   if (!is.null(index)) {
-    original_data <- .recover_data_from_environment(x)
+    original_data <- .recover_data_from_environment(x, verbose = verbose)
     keep <- intersect(index, colnames(original_data))
     if (length(keep)) {
       mf <- cbind(mf, original_data[, keep, drop = FALSE])
@@ -1485,35 +1473,25 @@ get_data.ivreg <- function(x, source = "environment", verbose = TRUE, ...) {
   }
 
   # fall back to extract data from model frame
-  mf <- tryCatch(stats::model.frame(x), error = function(e) NULL)
+  mf <- .safe(stats::model.frame(x))
   ft <- find_variables(x, flatten = TRUE)
 
-  if (!insight::is_empty_object(mf)) {
+  if (is_empty_object(mf)) {
+    final_mf <- .safe({
+      dat <- .recover_data_from_environment(x, verbose = verbose)
+      dat[, ft, drop = FALSE]
+    })
+  } else {
     cn <- clean_names(colnames(mf))
     remain <- setdiff(ft, cn)
     if (is_empty_object(remain)) {
       final_mf <- mf
     } else {
-      final_mf <- tryCatch(
-        {
-          dat <- .recover_data_from_environment(x)
-          cbind(mf, dat[, remain, drop = FALSE])
-        },
-        error = function(x) {
-          NULL
-        }
-      )
+      final_mf <- .safe({
+        dat <- .recover_data_from_environment(x, verbose = verbose)
+        cbind(mf, dat[, remain, drop = FALSE])
+      })
     }
-  } else {
-    final_mf <- tryCatch(
-      {
-        dat <- .recover_data_from_environment(x)
-        dat[, ft, drop = FALSE]
-      },
-      error = function(x) {
-        NULL
-      }
-    )
   }
 
   .prepare_get_data(x, stats::na.omit(final_mf), verbose = verbose)
@@ -1561,9 +1539,6 @@ get_data.bife <- function(x, effects = "all", source = "environment", verbose =
 }
 
 
-
-
-
 # Bayesian regression ---------------------------------------------------
 
 
@@ -1573,7 +1548,15 @@ get_data.brmsfit <- function(x, effects = "all", component = "all", source = "en
   # verbose is FALSE by default because `get_call()` often does not work on
   # `brmsfit` objects, so we typically default to the `data` held in the object.
   data_name <- attr(x$data, "data_name")
-  model_data <- .get_data_from_environment(x, effects = effects, component = component, source = source, verbose = verbose, data_name = data_name, ...)
+  model_data <- .get_data_from_environment(
+    x,
+    effects = effects,
+    component = component,
+    source = source,
+    verbose = verbose,
+    data_name = data_name,
+    ...
+  )
 
   if (!is.null(model_data)) {
     return(model_data)
@@ -1588,7 +1571,10 @@ get_data.brmsfit <- function(x, effects = "all", component = "all", source = "en
 
   if (.is_multi_membership(x)) {
     model.terms <- lapply(model.terms, .clean_brms_mm)
-    rs <- setdiff(unname(unlist(find_random_slopes(x))), unname(unlist(model.terms)))
+    rs <- setdiff(
+      unlist(find_random_slopes(x), use.names = FALSE),
+      unlist(model.terms, use.names = FALSE)
+    )
     if (!is_empty_object(rs)) model.terms$random <- c(rs, model.terms$random)
   }
 
@@ -1662,15 +1648,15 @@ get_data.MCMCglmm <- function(x, effects = "all", source = "environment", verbos
         all(pv %in% colnames(dat))
       }))
       mf <- env_dataframes[matchframe][1]
-      if (!is.na(mf)) {
+      if (is.na(mf)) {
+        NULL
+      } else {
         dat <- get(mf)
         switch(effects,
           fixed = dat[, setdiff(colnames(dat), find_random(x, flatten = TRUE)), drop = FALSE],
           all = dat,
           random = dat[, find_random(x, flatten = TRUE), drop = FALSE]
         )
-      } else {
-        NULL
       }
     },
     error = function(x) {
@@ -1742,7 +1728,6 @@ get_data.probitmfx <- get_data.betamfx
 get_data.negbinmfx <- get_data.betamfx
 
 
-
 # other models ------------------------------------------------------
 
 
@@ -1778,6 +1763,15 @@ get_data.mle2 <- function(x, ...) {
 get_data.mle <- get_data.mle2
 
 
+#' @export
+get_data.nestedLogit <- function(x, ...) {
+  d <- x$data
+  if (!is.null(x$subset)) {
+    d <- subset(d, eval(parse(text = x$subset), envir = d))
+  }
+  d
+}
+
 
 #' @export
 get_data.glht <- function(x, source = "environment", verbose = TRUE, ...) {
@@ -1836,7 +1830,7 @@ get_data.coxph <- function(x, source = "environment", verbose = TRUE, ...) {
   # first try, parent frame
   dat <- tryCatch(
     {
-      mf <- .recover_data_from_environment(x)
+      mf <- .recover_data_from_environment(x, verbose = verbose)
       mf <- .prepare_get_data(x, stats::na.omit(mf), verbose = FALSE)
     },
     error = function(x) NULL
@@ -1851,6 +1845,9 @@ get_data.coxph <- function(x, source = "environment", verbose = TRUE, ...) {
   dat
 }
 
+#' @export
+get_data.coxme <- get_data.coxph
+
 
 #' @export
 get_data.BGGM <- function(x, ...) {
@@ -1891,21 +1888,17 @@ get_data.vglm <- function(x, source = "environment", verbose = TRUE, ...) {
 
   # fall back to extract data from model frame
   mf <- tryCatch(
-    {
-      if (!length(x@model)) {
-        env <- environment(x@terms$terms)
-        if (is.null(env)) env <- parent.frame()
-        fcall <- x@call
-        fcall$method <- "model.frame"
-        fcall$smart <- FALSE
-        eval(fcall, env, parent.frame())
-      } else {
-        x@model
-      }
+    if (length(x@model)) {
+      x@model
+    } else {
+      env <- environment(x@terms$terms)
+      if (is.null(env)) env <- parent.frame()
+      fcall <- x@call
+      fcall$method <- "model.frame"
+      fcall$smart <- FALSE
+      eval(fcall, env, parent.frame())
     },
-    error = function(x) {
-      NULL
-    }
+    error = function(x) NULL
   )
 
   .prepare_get_data(x, mf)
@@ -1943,7 +1936,7 @@ get_data.LORgee <- function(x, source = "environment", effects = "all", verbose
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
   mf <- tryCatch(
     {
-      dat <- .recover_data_from_environment(x)[, find_variables(x, flatten = TRUE), drop = FALSE]
+      dat <- .recover_data_from_environment(x, verbose = verbose)[, find_variables(x, flatten = TRUE), drop = FALSE]
       switch(effects,
         all = dat[, find_variables(x, flatten = TRUE), drop = FALSE],
         fixed = dat[, find_variables(x, effects = "fixed", flatten = TRUE), drop = FALSE],
@@ -2003,7 +1996,7 @@ get_data.tobit <- function(x, source = "environment", verbose = TRUE, ...) {
   }
 
   # fall back to extract data from model frame
-  dat <- .recover_data_from_environment(x)
+  dat <- .recover_data_from_environment(x, verbose = verbose)
   ft <- find_variables(x, flatten = TRUE, verbose = FALSE)
   remain <- intersect(ft, colnames(dat))
 
@@ -2032,7 +2025,7 @@ get_data.clmm2 <- function(x, source = "environment", verbose = TRUE, ...) {
       }
 
       data_complete <- cbind(data_complete, x$grFac)
-      colnames(data_complete)[ncol(data_complete)] <- unlist(.find_random_effects(x, f = find_formula(x, verbose = FALSE), split_nested = TRUE))
+      colnames(data_complete)[ncol(data_complete)] <- unlist(.find_random_effects(x, f = find_formula(x, verbose = FALSE), split_nested = TRUE)) # nolint
 
       data_complete
     },
@@ -2107,7 +2100,105 @@ get_data.mlogit <- function(x, source = "environment", verbose = TRUE, ...) {
 
 
 #' @export
-get_data.rma <- function(x, source = "environment", verbose = TRUE, ...) {
+get_data.phylolm <- function(x, source = "environment", verbose = TRUE, ...) {
+  # DO NOT TOUCH THE SOURCE ARGUMENT!
+  # phylo models have no model.frame() method, so we can only recover from
+  # environment. We still need the "source" argument, even if it's not used here,
+  #  to avoid the "multiple argument match" error for those instances, where
+  # `get_data()` is called # with `source = "frame"`.
+  .get_data_from_environment(x, source = "environment", verbose = verbose, ...)
+}
+
+#' @export
+get_data.phyloglm <- get_data.phylolm
+
+
+#' @export
+#' @rdname get_data
+#' @param include_interval For meta-analysis models, should normal-approximation
+#'   confidence intervals be added for each response effect size?
+#' @param transf For meta-analysis models, if intervals are included, a function
+#'   applied to each response effect size and its interval.
+#' @param transf_args For meta-analysis models, an optional list of arguments
+#'   passed to the `transf` function.
+#' @param ci For meta-analysis models, the Confidence Interval (CI) level if
+#'   `include_interval = TRUE`. Default to 0.95 (95%).
+get_data.rma <- function(x,
+                         source = "environment",
+                         verbose = TRUE,
+                         include_interval = FALSE,
+                         transf = NULL,
+                         transf_args = NULL,
+                         ci = 0.95,
+                         ...) {
+  # standard errors and moderators are not found by find_predictors(),
+  # so we need them as additional variables
+  model_call <- get_call(x)
+  additional_variables <- c(
+    safe_deparse(model_call$vi),
+    safe_deparse(model_call$sei),
+    safe_deparse(model_call$mods)
+  )
+  # try to recover data from environment
+  model_data <- .get_data_from_environment(
+    x,
+    source = source,
+    additional_variables = additional_variables,
+    verbose = verbose,
+    ...
+  )
+
+  if (!is.null(model_data)) {
+    return(model_data)
+  }
+
+  # fall back to extract data from model frame
+  mf <- tryCatch(.recover_data_from_environment(x, verbose = verbose), error = function(x) NULL)
+  mf_attr <- attributes(mf)
+  mf <- merge(mf, data.frame(Weights = get_weights(x)), by = "row.names", all = TRUE, sort = FALSE)
+  rownames(mf) <- mf$Row.names
+  mf$Row.names <- NULL
+  mostattributes(mf) <- c(
+    attributes(mf)[c("names", "row.names")],
+    mf_attr[c("yi.names", "vi.names", "digits", "class")]
+  )
+  if (isTRUE(include_interval)) {
+    model_response <- .safe(mf[[find_response(x)]])
+    sei <- .safe(mf[[model_call$sei]])
+    if (is.null(sei)) {
+      sei <- .safe(sqrt(mf[[model_call$vi]]))
+    }
+    if (is.null(sei)) {
+      format_error("Could not find `sei` or `vi` for this model.")
+    }
+    mf$ci <- ci
+    mf$CI_low <- model_response - stats::qnorm((1 - ci) / 2, lower.tail = FALSE) * sei
+    mf$CI_high <- model_response + stats::qnorm((1 - ci) / 2, lower.tail = FALSE) * sei
+    if (!is.null(transf)) {
+      if (!is.function(transf)) {
+        format_error("`transf` must be a function.")
+      }
+      if (is.null(transf_args)) {
+        mf[[find_response(x)]] <- sapply(mf[[find_response(x)]], transf)
+        mf$CI_low <- sapply(mf$CI_low, transf)
+        mf$CI_high <- sapply(mf$CI_high, transf)
+      } else {
+        mf[[find_response(x)]] <- sapply(mf[[find_response(x)]], transf, transf_args)
+        mf$CI_low <- sapply(mf$CI_low, transf, transf_args)
+        mf$CI_high <- sapply(mf$CI_high, transf, transf_args)
+      }
+    }
+  }
+  original_rownames <- rownames(x$X)
+  if (is.null(original_rownames)) {
+    original_rownames <- seq_len(nrow(mf))
+  }
+  .prepare_get_data(x, mf[original_rownames, , drop = FALSE], verbose = verbose)
+}
+
+
+#' @export
+get_data.metaplus <- function(x, source = "environment", verbose = TRUE, ...) {
   # try to recover data from environment
   model_data <- .get_data_from_environment(x, source = source, verbose = verbose, ...)
 
@@ -2116,13 +2207,12 @@ get_data.rma <- function(x, source = "environment", verbose = TRUE, ...) {
   }
 
   # fall back to extract data from model frame
-  mf <- tryCatch(.recover_data_from_environment(x), error = function(x) NULL)
+  mf <- .safe(.recover_data_from_environment(x, verbose = verbose))
   .prepare_get_data(x, stats::na.omit(mf), verbose = verbose)
 }
 
-
 #' @export
-get_data.metaplus <- get_data.rma
+get_data.ivFixed <- get_data.metaplus
 
 
 #' @export
@@ -2135,10 +2225,13 @@ get_data.meta_random <- function(x, source = "environment", verbose = TRUE, ...)
   }
 
   # fall back to extract data from model frame
-  mf <- tryCatch(x$data$data, error = function(x) NULL)
+  mf <- .safe(x$data$data)
   .prepare_get_data(x, stats::na.omit(mf), verbose = verbose)
 }
 
+#' @export
+get_data.meta_fixed <- get_data.meta_random
+
 
 #' @export
 get_data.meta_bma <- function(x, source = "environment", verbose = TRUE, ...) {
@@ -2155,14 +2248,6 @@ get_data.meta_bma <- function(x, source = "environment", verbose = TRUE, ...) {
 }
 
 
-#' @export
-get_data.meta_fixed <- get_data.meta_random
-
-
-#' @export
-get_data.ivFixed <- get_data.rma
-
-
 #' @export
 get_data.bfsl <- function(x, ...) {
   as.data.frame(x$data[c("x", "y", "sd_x", "sd_y")])
@@ -2171,15 +2256,10 @@ get_data.bfsl <- function(x, ...) {
 
 #' @export
 get_data.mipo <- function(x, ...) {
-  tryCatch(
-    {
-      models <- eval(x$call$object)
-      get_data(models$analyses[[1]], ...)
-    },
-    error = function(e) {
-      NULL
-    }
-  )
+  .safe({
+    models <- eval(x$call$object)
+    get_data(models$analyses[[1]], ...)
+  })
 }
 
 
@@ -2198,7 +2278,7 @@ get_data.htest <- function(x, ...) {
 .check_data_source_arg <- function(source) {
   source <- match.arg(source, choices = c("environment", "mf", "modelframe", "frame"))
   switch(source,
-    "environment" = "environment",
+    environment = "environment",
     "frame"
   )
 }
