@@ -5,8 +5,8 @@
 #'   from regression models.
 #'
 #' @param x A statistical model.
-#' @param type Can be `"residual"`, `"wald"`, `"normal"`, or
-#'   `"model"`. `"analytical"` is an alias for `"residual"`.
+#' @param type Type of approximation for the degrees of freedom. Can be one of
+#' the following:
 #'
 #'   + `"residual"` (aka `"analytical"`) returns the residual degrees of
 #'     freedom, which usually is what [`stats::df.residual()`] returns. If a
@@ -21,10 +21,11 @@
 #'   + `"normal"` always returns `Inf`.
 #'   + `"model"` returns model-based degrees of freedom, i.e. the number of
 #'     (estimated) parameters.
-#'   + For mixed models, can also be `"ml1"` (approximation of degrees of freedom
-#'     based on a "m-l-1" heuristic as suggested by _Elff et al. 2019_) or
-#'     `"betwithin"`, and for models of class `merMod`, `type` can also be
-#'     `"satterthwaite"` or `"kenward-roger"`. See 'Details'.
+#'   + For mixed models, can also be `"ml1"` (or `"m-l-1"`, approximation of
+#'     degrees of freedom based on a "m-l-1" heuristic as suggested by _Elff et
+#'     al. 2019_) or `"between-within"` (or `"betwithin"`).
+#'   + For mixed models of class `merMod`, `type` can also be `"satterthwaite"`
+#'     or `"kenward-roger"` (or `"kenward"`). See 'Details'.
 #'
 #' Usually, when degrees of freedom are required to calculate p-values or
 #' confidence intervals, `type = "wald"` is likely to be the best choice in
@@ -100,10 +101,20 @@ get_df <- function(x, ...) {
 #' @rdname get_df
 #' @export
 get_df.default <- function(x, type = "residual", verbose = TRUE, ...) {
+  # check for valid model-object
+  if (missing(x) || is.null(x)) {
+    format_error(
+      "You must provide a model-object. Argument cannot be missing or `NULL`."
+    )
+  }
+
   # check valid options
   type <- match.arg(
     tolower(type),
-    choices = c("residual", "model", "analytical", "wald", "normal", "ml1", "betwithin")
+    choices = c(
+      "residual", "model", "analytical", "wald", "normal", "ml1", "betwithin",
+      "between-within", "profile", "boot", "uniroot", "likelihood", "m-l-1", "any"
+    )
   )
 
   # check if user already passed "statistic" argument, to
@@ -114,11 +125,8 @@ get_df.default <- function(x, type = "residual", verbose = TRUE, ...) {
     statistic <- find_statistic(x)
   }
 
-  # handle aliases
-  if (type == "analytical") {
-    type <- "residual"
-  }
-
+  # handle aliases, resp. mixing type and ci_method
+  type <- .check_df_type(type)
 
   if (type == "normal") { # nolint
     # Wald normal approximation - always Inf -----
@@ -141,11 +149,11 @@ get_df.default <- function(x, type = "residual", verbose = TRUE, ...) {
     dof <- .get_residual_df(x, verbose)
 
     # ml1 - only for certain mixed models -----
-  } else if (type == "ml1") {
+  } else if (type %in% c("ml1", "m-l-1")) {
     dof <- .degrees_of_freedom_ml1(x)
 
     # between-within - only for certain mixed models -----
-  } else if (type == "betwithin") {
+  } else if (type %in% c("betwithin", "between-within")) {
     dof <- .degrees_of_freedom_betwithin(x)
 
     # remaining option is model-based df, i.e. number of estimated parameters
@@ -165,151 +173,17 @@ get_df.default <- function(x, type = "residual", verbose = TRUE, ...) {
 }
 
 
+# models that rely on the default method ---------------
+# ------------------------------------------------------
+
 #' @export
 get_df.model_fit <- function(x, type = "residual", verbose = TRUE, ...) {
   get_df(x$fit, type = type, verbose = verbose, ...)
 }
 
-
-#' @export
-get_df.svy2lme <- function(x, type = "residual", verbose = TRUE, ...) {
-  type <- match.arg(tolower(type), choices = c("residual", "model", "normal"))
-  if (type == "model") {
-    .model_df(x)
-  } else {
-    Inf
-  }
-}
-
-
-#' @export
-get_df.mmrm <- function(x, type = "residual", verbose = TRUE, ...) {
-  type <- match.arg(tolower(type), choices = c("residual", "model", "normal"))
-  if (type == "model") {
-    .model_df(x)
-  } else {
-    summary_table <- stats::coef(summary(x))
-    unname(summary_table[, "df"])
-  }
-}
-
-#' @export
-get_df.mmrm_fit <- get_df.mmrm
-
-#' @export
-get_df.mmrm_tmb <- get_df.mmrm
-
-
-#' @export
-get_df.emmGrid <- function(x, ...) {
-  if (!is.null(x@misc$is_boot) && x@misc$is_boot) {
-    return(.boot_em_df(x))
-  }
-  unique(summary(x)$df)
-}
-
-
-#' @export
-get_df.emm_list <- function(x, ...) {
-  if (!is.null(x[[1]]@misc$is_boot) && x[[1]]@misc$is_boot) {
-    return(.boot_em_df(x))
-  }
-  s <- summary(x)
-  unlist(lapply(s, function(i) {
-    if (is.null(i$df)) {
-      rep(Inf, nrow(i))
-    } else {
-      i$df
-    }
-  }), use.names = FALSE)
-}
-
-
-#' @export
-get_df.coeftest <- function(x, ...) {
-  attributes(x)$df
-}
-
-
-#' @export
-get_df.phylolm <- function(x, type = "residual", ...) {
-  type <- match.arg(
-    tolower(type),
-    choices = c("wald", "residual", "normal", "model")
-  )
-  type <- switch(type,
-    model = stats::logLik(x)$df,
-    get_df.default(x, type = "residual")
-  )
-}
-
-#' @export
-get_df.phyloglm <- get_df.phylolm
-
-
-#' @export
-get_df.fixest <- function(x, type = "residual", ...) {
-  # fixest degrees of freedom can be tricky. best to use the function by the
-  # package.
-  check_if_installed("fixest")
-  if (is.null(type)) {
-    type <- "residual"
-  }
-  type <- match.arg(
-    tolower(type),
-    choices = c("wald", "residual", "normal")
-  )
-  type <- switch(type,
-    wald = "t",
-    residual = "resid",
-    type
-  )
-  if (type == "normal") {
-    return(Inf)
-  }
-  fixest::degrees_freedom(x, type = type)
-}
-
-
-
-# Mixed models - special treatment --------------
-
-#' @export
-get_df.lmerMod <- function(x, type = "residual", ...) {
-  type <- match.arg(
-    tolower(type),
-    choices = c(
-      "residual", "model", "analytical", "satterthwaite", "kenward",
-      "kenward-roger", "kr", "normal", "wald", "ml1", "betwithin"
-    )
-  )
-
-  dots <- list(...)
-
-  if (type %in% c("satterthwaite", "kr", "kenward", "kenward-roger") && isTRUE(dots$df_per_obs)) {
-    .satterthwaite_kr_df_per_obs(x, type, dots$data)
-  } else if (type == "satterthwaite") {
-    .degrees_of_freedom_satterthwaite(x)
-  } else if (type %in% c("kr", "kenward", "kenward-roger")) {
-    .degrees_of_freedom_kr(x)
-  } else {
-    get_df.default(x, type = type, ...)
-  }
-}
-
-#' @export
-get_df.lmerModTest <- get_df.lmerMod
-
-#' @export
-get_df.lme <- get_df.lmerMod
-
-
-
-# Other models ------------------
-
 #' @export
 get_df.logitor <- function(x, type = "residual", verbose = TRUE, ...) {
-  type <- match.arg(tolower(type), choices = c("residual", "model", "normal", "wald", "analytical"))
+  type <- match.arg(tolower(type), choices = c("residual", "model", "normal", "wald", "analytical", "any"))
   get_df.default(x$fit, type = type, verbose = verbose, ...)
 }
 
@@ -338,30 +212,263 @@ get_df.betaor <- get_df.logitor
 get_df.betamfx <- get_df.logitor
 
 
+# models, where we want residual df, even for "wald" and "z-statistic" ---------
+# ------------------------------------------------------------------------------
+
+#' @export
+get_df.rlm <- function(x, type = "residual", verbose = TRUE, ...) {
+  if (identical(type, "model")) {
+    .model_df(x)
+  } else if (identical(type, "normal")) {
+    Inf
+  } else {
+    .degrees_of_freedom_residual(x)
+  }
+}
+
+#' @export
+get_df.mipo <- get_df.rlm
+
+#' @export
+get_df.mhurdle <- get_df.rlm
+
+#' @export
+get_df.nlrq <- get_df.rlm
+
+#' @export
+get_df.complmrob <- get_df.rlm
+
+#' @export
+get_df.plm <- get_df.rlm
+
+#' @export
+get_df.multinom <- get_df.rlm
+
+#' @export
+get_df.garch <- get_df.rlm
+
+#' @export
+get_df.vgam <- get_df.rlm
+
+#' @export
+get_df.truncreg <- get_df.rlm
+
+#' @export
+get_df.systemfit <- get_df.rlm
+
+
+# models, where we only have one type of residuals ---------
+# ----------------------------------------------------------
+
+#' @export
+get_df.svy2lme <- function(x, type = "residual", verbose = TRUE, ...) {
+  if (identical(type, "model")) {
+    .model_df(x)
+  } else {
+    Inf
+  }
+}
+
+#' @export
+get_df.mmrm <- function(x, type = "residual", verbose = TRUE, ...) {
+  if (identical(type, "model")) {
+    .model_df(x)
+  } else {
+    summary_table <- stats::coef(summary(x))
+    unname(summary_table[, "df"])
+  }
+}
+
+#' @export
+get_df.mmrm_fit <- get_df.mmrm
+
+#' @export
+get_df.mmrm_tmb <- get_df.mmrm
+
+
+# special "model" classes ---------
+# ---------------------------------
+
+#' @export
+get_df.emmGrid <- function(x, ...) {
+  if (!is.null(x@misc$is_boot) && x@misc$is_boot) {
+    return(.boot_em_df(x))
+  }
+  unique(summary(x)$df)
+}
+
+#' @export
+get_df.emm_list <- function(x, ...) {
+  if (!is.null(x[[1]]@misc$is_boot) && x[[1]]@misc$is_boot) {
+    return(.boot_em_df(x))
+  }
+  s <- summary(x)
+  unlist(lapply(s, function(i) {
+    if (is.null(i$df)) {
+      rep(Inf, nrow(i))
+    } else {
+      i$df
+    }
+  }), use.names = FALSE)
+}
+
 #' @export
 get_df.mira <- function(x, type = "residual", verbose = TRUE, ...) {
-  # installed?
   check_if_installed("mice")
-  type <- match.arg(tolower(type), choices = c("residual", "model", "normal"))
+  type <- match.arg(tolower(type), choices = c("residual", "model", "normal", "wald", "any", "analytical"))
   get_df(mice::pool(x), type, verbose = verbose, ...)
 }
 
+#' @export
+get_df.coeftest <- function(x, ...) {
+  attributes(x)$df
+}
 
 #' @export
-get_df.mipo <- function(x, type = "residual", ...) {
-  type <- match.arg(tolower(type), choices = c("residual", "model", "normal"))
-  if (type == "model") {
+get_df.glht <- function(x, ...) {
+  x$df
+}
+
+#' @export
+get_df.selection <- function(x, ...) {
+  s <- summary(x)
+  s$param$df
+}
+
+#' @export
+get_df.serp <- function(x, type = "normal", ...) {
+  if (identical(type, "model")) {
     .model_df(x)
-  } else if (type == "normal") {
-    return(Inf)
+  } else if (identical(type, "residual")) {
+    x$rdf
   } else {
-    as.vector(summary(x)$df)
+    Inf
   }
 }
 
 
+# Mixed models - special treatment --------------
+# -----------------------------------------------
+
+#' @export
+get_df.lmerMod <- function(x, type = "residual", ...) {
+  type <- match.arg(
+    tolower(type),
+    choices = c(
+      "residual", "model", "analytical", "satterthwaite", "kenward",
+      "kenward-roger", "kr", "normal", "wald", "ml1", "m-l-1", "betwithin",
+      "between-within", "any"
+    )
+  )
+
+  # hidden gem - required for get_predicted_ci(), where we have per-observation DF
+  dots <- list(...)
+
+  if (type %in% c("satterthwaite", "kr", "kenward", "kenward-roger") && isTRUE(dots$df_per_obs)) {
+    .satterthwaite_kr_df_per_obs(x, type, dots$data)
+  } else if (type == "satterthwaite") {
+    .degrees_of_freedom_satterthwaite(x)
+  } else if (type %in% c("kr", "kenward", "kenward-roger")) {
+    .degrees_of_freedom_kr(x)
+  } else {
+    get_df.default(x, type = type, ...)
+  }
+}
+
+#' @export
+get_df.lmerModTest <- get_df.lmerMod
+
+#' @export
+get_df.lme <- get_df.lmerMod
+
+
+# Other models ------------------
+# -------------------------------
+
+#' @export
+get_df.phylolm <- function(x, type = "residual", ...) {
+  if (identical(type, "model")) {
+    stats::logLik(x)$df
+  } else {
+    get_df.default(x, type = type)
+  }
+}
+
+#' @export
+get_df.phyloglm <- get_df.phylolm
+
+#' @export
+get_df.fixest <- function(x, type = "residual", ...) {
+  # fixest degrees of freedom can be tricky. best to use the function by the
+  # package.
+  check_if_installed("fixest")
+  if (is.null(type)) {
+    type <- "residual"
+  }
+  type <- match.arg(
+    tolower(type),
+    choices = c("wald", "residual", "normal", "any", "analytical")
+  )
+  type <- switch(type,
+    any = ,
+    wald = "t",
+    analytical = ,
+    residual = "resid",
+    type
+  )
+  if (type == "normal") {
+    return(Inf)
+  }
+  fixest::degrees_freedom(x, type = type)
+}
+
+#' @export
+get_df.fixest_multi <- function(x, ...) {
+  out <- do.call(rbind, lapply(x, get_df, ...))
+
+  # add response and group columns
+  id_columns <- .get_fixest_multi_columns(x)
+
+  # add response column
+  out$Response <- id_columns$Response
+  out$Group <- id_columns$Group
+
+  row.names(out) <- NULL
+  out
+}
+
+#' @export
+get_df.nestedLogit <- function(x, type = NULL, component = "all", verbose = TRUE, ...) {
+  if (is.null(type)) {
+    type <- "wald"
+  }
+  if (tolower(type) == "residual") {
+    cf <- as.data.frame(stats::coef(x))
+    dof <- rep(vapply(x$models, stats::df.residual, numeric(1)), each = nrow(cf))
+    if (!is.null(component) && !identical(component, "all")) {
+      comp <- intersect(names(dof), component)
+      if (length(comp)) {
+        dof <- dof[comp]
+      } else {
+        if (verbose) {
+          format_alert(paste0(
+            "No matching model found. Possible values for `component` are ",
+            toString(paste0("'", names(x$models), "'")),
+            "."
+          ))
+        }
+        dof <- Inf
+      }
+    }
+  } else {
+    dof <- Inf
+  }
+  dof
+}
+
 
 # not yet supported --------------------
+# --------------------------------------
 
 #' @export
 get_df.mediate <- function(x, ...) {
@@ -369,8 +476,8 @@ get_df.mediate <- function(x, ...) {
 }
 
 
-
 # Analytical approach ------------------------------
+# --------------------------------------------------
 
 .get_residual_df <- function(x, verbose = TRUE) {
   dof <- .degrees_of_freedom_residual(x, verbose = verbose)
@@ -380,22 +487,31 @@ get_df.mediate <- function(x, ...) {
   dof
 }
 
-
 #' @keywords internal
-.degrees_of_freedom_analytical <- function(model) {
-  nparam <- .model_df(model)
-  n <- n_obs(model)
+.degrees_of_freedom_analytical <- function(x, kenward = TRUE, model_n_params = TRUE) {
+  if (isTRUE(model_n_params)) {
+    nparam <- .model_df(x)
+  } else {
+    nparam <- n_parameters(x)
+  }
 
+  n <- n_obs(x)
   if (is.null(n)) {
     return(Inf)
   }
 
-  n - nparam
+  if (isTRUE(kenward) && inherits(x, "lmerMod")) {
+    dof <- as.numeric(.degrees_of_freedom_kr(x))
+  } else {
+    dof <- n - nparam
+  }
+
+  dof
 }
 
 
-
 # Model approach (model-based / logLik df) ------------------------------
+# -----------------------------------------------------------------------
 
 .model_df <- function(x) {
   # logLik() for plm calls get_df(), so we would have a recursion here.
@@ -427,19 +543,49 @@ get_df.mediate <- function(x, ...) {
 }
 
 
+# tools ----------------
+# ----------------------
+
 .boot_em_df <- function(model) {
   est <- get_parameters(model, summary = FALSE)
   rep(NA, ncol(est))
 }
 
-
-
-# tools ----------------
-
 .check_df_type <- function(type) {
   # handle mixing of ci_method and type arguments
-  if (tolower(type) %in% c("profile", "uniroot", "quantile", "eti", "hdi", "bci", "boot", "spi")) {
+  if (tolower(type) %in% c("profile", "uniroot", "quantile", "likelihood", "eti", "hdi", "bci", "boot", "spi", "nokr", "any")) {
+    type <- "wald"
+  } else if (tolower(type) == "analytical") {
     type <- "residual"
   }
   type
 }
+
+.get_fixest_multi_columns <- function(model) {
+  # add response and group columns
+  s <- summary(model)
+  l <- lengths(lapply(s, stats::coef))
+  parts <- strsplit(names(l), ";", fixed = TRUE)
+
+  id_columns <- Map(function(i, j) {
+    if (length(j) == 1 && startsWith(j, "rhs")) {
+      data.frame(
+        Group = rep(trim_ws(sub("rhs:", "", j, fixed = TRUE)), i),
+        stringsAsFactors = FALSE
+      )
+    } else if (length(j) == 1 && startsWith(j, "lhs")) {
+      data.frame(
+        Response = rep(trim_ws(sub("lhs:", "", j, fixed = TRUE)), i),
+        stringsAsFactors = FALSE
+      )
+    } else {
+      data.frame(
+        Response = rep(trim_ws(sub("lhs:", "", j[1], fixed = TRUE)), i),
+        Group = rep(trim_ws(sub("rhs:", "", j[2], fixed = TRUE)), i),
+        stringsAsFactors = FALSE
+      )
+    }
+  }, unname(l), parts)
+
+  do.call(rbind, id_columns)
+}
