@@ -2,17 +2,16 @@
 #' @name get_parameters
 #'
 #' @description Returns the coefficients (or posterior samples for Bayesian
-#'    models) from a model. See the documentation for your object's class:
-#'    \itemize{
-#'      \item{[Bayesian models][get_parameters.BGGM] (\pkg{rstanarm}, \pkg{brms}, \pkg{MCMCglmm}, ...)}
-#'      \item{[Estimated marginal means][get_parameters.emmGrid] (\pkg{emmeans})}
-#'      \item{[Generalized additive models][get_parameters.gamm] (\pkg{mgcv}, \pkg{VGAM}, ...)}
-#'      \item{[Marginal effects models][get_parameters.betamfx] (\pkg{mfx})}
-#'      \item{[Mixed models][get_parameters.glmm] (\pkg{lme4}, \pkg{glmmTMB}, \pkg{GLMMadaptive}, ...)}
-#'      \item{[Zero-inflated and hurdle models][get_parameters.zeroinfl] (\pkg{pscl}, ...)}
-#'      \item{[Models with special components][get_parameters.betareg] (\pkg{betareg}, \pkg{MuMIn}, ...)}
-#'      \item{[Hypothesis tests][get_parameters.htest] (`htest`)}
-#'    }
+#' models) from a model. See the documentation for your object's class:
+#'
+#' - [Bayesian models][get_parameters.BGGM] (**rstanarm**, **brms**, **MCMCglmm**, ...)
+#' - [Estimated marginal means][get_parameters.emmGrid] (**emmeans**)
+#' - [Generalized additive models][get_parameters.gamm] (**mgcv**, **VGAM**, ...)
+#' - [Marginal effects models][get_parameters.betamfx] (**mfx**)
+#' - [Mixed models][get_parameters.glmmTMB] (**lme4**, **glmmTMB**, **GLMMadaptive**, ...)
+#' - [Zero-inflated and hurdle models][get_parameters.zeroinfl] (**pscl**, ...)
+#' - [Models with special components][get_parameters.betareg] (**betareg**, **MuMIn**, ...)
+#' - [Hypothesis tests][get_parameters.htest] (`htest`)
 #'
 #' @param verbose Toggle messages and warnings.
 #' @param ... Currently not used.
@@ -22,15 +21,16 @@
 #'
 #' @inheritSection find_predictors Model components
 #'
-#' @return \itemize{
-#'   \item for non-Bayesian models, a data frame with two columns: the parameter names and the related point estimates.
-#'   \item for Anova (`aov()`) with error term, a list of parameters for the conditional and the random effects parameters
-#' }
+#' @return
+#' - for non-Bayesian models, a data frame with two columns: the parameter names
+#'   and the related point estimates.
+#' - for Anova (`aov()`) with error term, a list of parameters for the
+#'   conditional and the random effects parameters
 #'
 #' @details In most cases when models either return different "effects" (fixed,
 #' random) or "components" (conditional, zero-inflated, ...), the arguments
 #' `effects` and `component` can be used.
-#' \cr \cr
+#'
 #' `get_parameters()` is comparable to `coef()`, however, the coefficients
 #' are returned as data frame (with columns for names and point estimates of
 #' coefficients). For Bayesian models, the posterior samples of parameters are
@@ -46,7 +46,6 @@ get_parameters <- function(x, ...) {
 }
 
 
-
 # Default models ---------------------------------------------
 
 
@@ -82,7 +81,7 @@ get_parameters.default <- function(x, verbose = TRUE, ...) {
           sprintf("Parameters can't be retrieved for objects of class `%s`.", class(x)[1])
         )
       }
-      return(NULL)
+      NULL
     }
   )
 }
@@ -105,12 +104,10 @@ get_parameters.summary.lm <- function(x, ...) {
 
 #' @export
 get_parameters.data.frame <- function(x, ...) {
-  stop("A data frame is no valid object for this function")
+  format_error("A data frame is no valid object for this function.")
 }
 
 
-
-
 # Special models ---------------------------------------------
 
 
@@ -128,6 +125,14 @@ get_parameters.model_fit <- function(x, ...) {
 }
 
 
+#' @export
+get_parameters.ordinal_weightit <- function(x, ...) {
+  out <- get_parameters.default(x, ...)
+  out$Component <- "conditional"
+  out
+}
+
+
 #' @export
 get_parameters.bfsl <- function(x, ...) {
   cf <- stats::coef(x)
@@ -144,8 +149,8 @@ get_parameters.bfsl <- function(x, ...) {
 
 
 #' @export
-get_parameters.selection <- function(x, component = c("all", "selection", "outcome", "auxiliary"), ...) {
-  component <- match.arg(component)
+get_parameters.selection <- function(x, component = "all", ...) {
+  component <- validate_argument(component, c("all", "selection", "outcome", "auxiliary"))
   s <- summary(x)
   rn <- row.names(s$estimate)
   estimates <- as.data.frame(s$estimate, row.names = FALSE)
@@ -175,7 +180,7 @@ get_parameters.epi.2by2 <- function(x, ...) {
 
   params <- data.frame(
     Parameter = names(cf),
-    Estimate = unname(unlist(lapply(cf, function(i) i["est"]))),
+    Estimate = unlist(lapply(cf, function(i) i["est"]), use.names = FALSE),
     stringsAsFactors = FALSE,
     row.names = NULL
   )
@@ -293,18 +298,22 @@ get_parameters.riskRegression <- function(x, ...) {
 
 #' @export
 get_parameters.mipo <- function(x, ...) {
+  s <- summary(x)
   out <- data.frame(
-    Parameter = as.vector(summary(x)$term),
-    Estimate = as.vector(summary(x)$estimate),
+    Parameter = as.vector(s$term),
+    Estimate = as.vector(s$estimate),
     stringsAsFactors = FALSE
   )
+  # check for ordinal-alike models
+  if (!is.null(x$pooled) && "y.level" %in% colnames(x$pooled)) {
+    out$Response <- as.vector(x$pooled$y.level)
+  }
   text_remove_backticks(out)
 }
 
 
 #' @export
 get_parameters.mira <- function(x, ...) {
-  # installed?
   check_if_installed("mice")
   get_parameters(mice::pool(x), ...)
 }
@@ -316,7 +325,7 @@ get_parameters.margins <- function(x, ...) {
   param <- as.vector(s$factor)
   estimate_pos <- which(colnames(s) == "AME")
 
-  if (estimate_pos > 2) {
+  if (estimate_pos > 2L) {
     out <- s[1:(estimate_pos - 1)]
     r <- apply(out, 1, function(i) paste0(colnames(out), " [", i, "]"))
     param <- unname(sapply(as.data.frame(r), paste, collapse = ", "))
@@ -350,7 +359,6 @@ get_parameters.glht <- function(x, ...) {
 
 #' @export
 get_parameters.mle2 <- function(x, ...) {
-  # installed?
   check_if_installed("bbmle")
   s <- bbmle::summary(x)
 
@@ -368,7 +376,6 @@ get_parameters.mle2 <- function(x, ...) {
 get_parameters.mle <- get_parameters.mle2
 
 
-
 #' @export
 get_parameters.lrm <- function(x, ...) {
   tryCatch(
@@ -423,6 +430,22 @@ get_parameters.multinom <- function(x, ...) {
 }
 
 
+#' @export
+get_parameters.multinom_weightit <- function(x, ...) {
+  params <- stats::coef(x)
+
+  out <- data.frame(
+    Parameter = gsub("(.*)~(.*)", "\\2", names(params)),
+    Estimate = unname(params),
+    Response = gsub("(.*)~(.*)", "\\1", names(params)),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  text_remove_backticks(out)
+}
+
+
 #' @export
 get_parameters.brmultinom <- get_parameters.multinom
 
@@ -442,8 +465,20 @@ get_parameters.mblogit <- function(x, ...) {
   text_remove_backticks(out)
 }
 
+
 #' @export
-get_parameters.mclogit <- get_parameters.mblogit
+get_parameters.mclogit <- function(x, ...) {
+  params <- stats::coef(x)
+
+  out <- data.frame(
+    Parameter = names(params),
+    Estimate = unname(params),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  text_remove_backticks(out)
+}
 
 
 #' @export
@@ -481,7 +516,6 @@ get_parameters.gbm <- function(x, ...) {
 }
 
 
-
 #' @export
 get_parameters.BBreg <- function(x, ...) {
   pars <- summary(x)$coefficients
@@ -564,10 +598,6 @@ get_parameters.metaplus <- function(x, ...) {
 }
 
 
-
-
-
-
 # SEM models ---------------------------------------------
 
 
@@ -576,7 +606,7 @@ get_parameters.blavaan <- function(x, summary = FALSE, standardize = FALSE, ...)
   if (isTRUE(summary)) {
     return(get_parameters.lavaan(x, standardize = standardize, ...))
   }
-  # installed?
+
   check_if_installed("lavaan")
   check_if_installed("blavaan")
 
@@ -592,7 +622,7 @@ get_parameters.blavaan <- function(x, summary = FALSE, standardize = FALSE, ...)
 
   coef_labels <- names(lavaan::coef(x))
 
-  if ("group" %in% colnames(param_tab) && n_unique(param_tab$group) > 1) {
+  if ("group" %in% colnames(param_tab) && n_unique(param_tab$group) > 1L) {
     params <- paste0(params, " (group ", param_tab$group, ")")
     groups <- grepl("(.*)\\.g(.*)", coef_labels)
     coef_labels[!groups] <- paste0(coef_labels[!groups], " (group 1)")
@@ -614,10 +644,8 @@ get_parameters.blavaan <- function(x, summary = FALSE, standardize = FALSE, ...)
 }
 
 
-
 #' @export
 get_parameters.lavaan <- function(x, standardize = FALSE, ...) {
-  # installed?
   check_if_installed("lavaan")
 
   if (standardize) {
@@ -645,8 +673,6 @@ get_parameters.lavaan <- function(x, standardize = FALSE, ...) {
 }
 
 
-
-
 # Ordinal models ---------------------------------------------
 
 
@@ -681,13 +707,6 @@ get_parameters.bracl <- function(x, ...) {
 }
 
 
-
-
-
-
-
-
-
 # Anova and Standard models --------------------------------------------------
 
 
@@ -706,7 +725,6 @@ get_parameters.aov <- function(x, ...) {
 }
 
 
-
 #' @export
 get_parameters.aovlist <- function(x, ...) {
   cs <- stats::coef(x)
@@ -724,7 +742,6 @@ get_parameters.aovlist <- function(x, ...) {
 }
 
 
-
 #' @export
 get_parameters.manova <- function(x, ...) {
   params <- stats::na.omit(stats::coef(x))
@@ -734,7 +751,7 @@ get_parameters.manova <- function(x, ...) {
   out <- out[c("Parameter", "Estimate", "Response")]
   rownames(out) <- NULL
 
-  pattern <- paste0("(", paste0(paste0(".", unique(out$Response)), collapse = "|"), ")$")
+  pattern <- paste0("(", paste(paste0(".", unique(out$Response)), collapse = "|"), ")$")
   out$Parameter <- gsub(pattern, "", out$Parameter)
 
   text_remove_backticks(out)
@@ -744,13 +761,12 @@ get_parameters.manova <- function(x, ...) {
 get_parameters.maov <- get_parameters.manova
 
 
-
 #' @export
 get_parameters.afex_aov <- function(x, ...) {
-  if (!is.null(x$aov)) {
-    get_parameters(x$aov, ...)
-  } else {
+  if (is.null(x$aov)) {
     get_parameters(x$lm, ...)
+  } else {
+    get_parameters(x$aov, ...)
   }
 }
 
@@ -778,8 +794,6 @@ get_parameters.pgmm <- function(x, component = c("conditional", "all"), ...) {
 }
 
 
-
-
 # utility functions ---------------------------------
 
 
@@ -789,7 +803,6 @@ get_parameters.pgmm <- function(x, component = c("conditional", "all"), ...) {
 }
 
 
-
 .get_armsim_ranef_parms <- function(x) {
   dat <- NULL
   if (methods::.hasSlot(x, "ranef")) {
