@@ -40,6 +40,10 @@
 #'   type (for instance, to a factor).
 #' * Other strings are passed directly to the `type` argument of the `predict()`
 #'   method supplied by the modelling package.
+#' * Specifically for models of class `brmsfit` (package *brms*), the `predict`
+#'   argument can be any valid option for the `dpar` argument, to predict
+#'   distributional parameters (such as `"sigma"`, `"beta"`, `"kappa"`, `"phi"`
+#'   and so on, see `?brms::brmsfamily`).
 #' * When `predict = NULL`, alternative arguments such as `type` will be captured
 #'   by the `...` ellipsis and passed directly to the `predict()` method supplied
 #'   by the modelling package. Note that this might result in conflicts with
@@ -221,7 +225,7 @@ get_predicted.default <- function(x,
                                   verbose = TRUE,
                                   ...) {
   # evaluate arguments
-  args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
+  my_args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
 
   # evaluate dots, remove some arguments that might be duplicated else
   dot_args <- list(...)
@@ -230,13 +234,13 @@ get_predicted.default <- function(x,
 
 
   # 1. step: predictions
-  predict_args <- compact_list(list(x, newdata = args$data, type = args$type, dot_args))
+  predict_args <- compact_list(list(x, newdata = my_args$data, type = my_args$type, dot_args))
   predictions <- .safe(do.call("predict", predict_args))
 
   # may fail due to invalid "dot_args", so try shorter argument list
   if (is.null(predictions)) {
     predictions <- .safe(
-      do.call("predict", compact_list(list(x, newdata = args$data, type = args$type)))
+      do.call("predict", compact_list(list(x, newdata = my_args$data, type = my_args$type)))
     )
   }
 
@@ -257,8 +261,8 @@ get_predicted.default <- function(x,
     get_predicted_ci(
       x,
       predictions,
-      data = args$data,
-      ci_type = args$ci_type,
+      data = my_args$data,
+      ci_type = my_args$ci_type,
       ci_method = ci_method,
       vcov = vcov,
       vcov_args = vcov_args,
@@ -270,12 +274,12 @@ get_predicted.default <- function(x,
   if (is.null(predictions)) {
     out <- NULL
   } else {
-    out <- .get_predicted_transform(x, predictions, args, ci_data, verbose = verbose)
+    out <- .get_predicted_transform(x, predictions, my_args = my_args, ci_data, verbose = verbose, ...)
   }
 
   # 4. step: final preparation
   if (!is.null(out)) {
-    out <- .get_predicted_out(out$predictions, args = args, ci_data = out$ci_data)
+    out <- .get_predicted_out(out$predictions, my_args = my_args, ci_data = out$ci_data)
   }
 
   out
@@ -292,7 +296,6 @@ get_predicted.data.frame <- function(x, data = NULL, verbose = TRUE, ...) {
 }
 
 
-
 # LM and GLM --------------------------------------------------------------
 # =========================================================================
 
@@ -309,11 +312,11 @@ get_predicted.lm <- function(x,
   predict_function <- function(x, data, ...) {
     stats::predict(x,
       newdata = data, interval = "none",
-      type = args$type, se.fit = FALSE, ...
+      type = my_args$type, se.fit = FALSE, ...
     )
   }
 
-  args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
+  my_args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
 
   # 0. step: convert matrix variable types attributes to numeric, if necessary.
   # see https://github.com/easystats/insight/pull/671
@@ -322,7 +325,7 @@ get_predicted.lm <- function(x,
     dataClasses[dataClasses == "nmatrix.1"] <- "numeric"
     attributes(x$terms)$dataClasses <- dataClasses
     attributes(attributes(x$model)$terms)$dataClasses <- dataClasses
-    args$data[] <- lapply(args$data, function(x) {
+    my_args$data[] <- lapply(my_args$data, function(x) {
       if (all(class(x) == c("matrix", "array"))) { # nolint
         as.numeric(x)
       } else {
@@ -333,11 +336,11 @@ get_predicted.lm <- function(x,
 
   # 1. step: predictions
   if (is.null(iterations)) {
-    predictions <- predict_function(x, data = args$data)
+    predictions <- predict_function(x, data = my_args$data)
   } else {
     predictions <- .get_predicted_boot(
       x,
-      data = args$data,
+      data = my_args$data,
       predict_function = predict_function,
       iterations = iterations,
       verbose = verbose,
@@ -349,26 +352,24 @@ get_predicted.lm <- function(x,
   ci_data <- get_predicted_ci(
     x,
     predictions,
-    data = args$data,
+    data = my_args$data,
     ci = ci,
-    ci_type = args$ci_type,
+    ci_type = my_args$ci_type,
     verbose = verbose,
     ...
   )
 
   # 3. step: back-transform
-  out <- .get_predicted_transform(x, predictions, args, ci_data, verbose = verbose)
+  out <- .get_predicted_transform(x, predictions, my_args, ci_data, verbose = verbose, ...)
 
   # 4. step: final preparation
-  .get_predicted_out(out$predictions, args = args, ci_data = out$ci_data)
+  .get_predicted_out(out$predictions, my_args = my_args, ci_data = out$ci_data)
 }
 
 #' @export
 get_predicted.glm <- get_predicted.lm
 
 
-
-
 # rms -------------------------------------------------------------------
 # =======================================================================
 
@@ -380,7 +381,6 @@ get_predicted.glm <- get_predicted.lm
 get_predicted.lrm <- get_predicted.default
 
 
-
 # MASS: rlm -----------------------------------------------------
 # =======================================================================
 
@@ -398,8 +398,6 @@ get_predicted.rlm <- get_predicted.default
 get_predicted.survreg <- get_predicted.lm
 
 
-
-
 # survival: coxph -------------------------------------------------------
 # =======================================================================
 
@@ -411,16 +409,16 @@ get_predicted.coxph <- function(x,
                                 iterations = NULL,
                                 verbose = TRUE,
                                 ...) {
-  args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
+  my_args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
   se <- NULL
 
   predict_function <- function(x, data, ...) {
-    stats::predict(x, newdata = data, type = args$type, ...)
+    stats::predict(x, newdata = data, type = my_args$type, ...)
   }
 
   # 1. step: predictions
   if (is.null(iterations)) {
-    predictions <- predict_function(x, data = args$data, se.fit = TRUE)
+    predictions <- predict_function(x, data = my_args$data, se.fit = TRUE)
     if (is.list(predictions)) {
       se <- as.vector(predictions$se.fit)
       predictions <- as.vector(predictions$fit)
@@ -428,7 +426,7 @@ get_predicted.coxph <- function(x,
   } else {
     predictions <- .get_predicted_boot(
       x,
-      data = args$data,
+      data = my_args$data,
       predict_function = predict_function,
       iterations = iterations,
       verbose = verbose,
@@ -440,23 +438,21 @@ get_predicted.coxph <- function(x,
   ci_data <- get_predicted_ci(
     x,
     predictions,
-    data = args$data,
+    data = my_args$data,
     ci = ci,
-    ci_type = args$ci_type,
+    ci_type = my_args$ci_type,
     se = se,
     ...
   )
 
   # 3. step: back-transform
-  out <- .get_predicted_transform(x, predictions, args, ci_data, link_inv = exp, verbose = verbose)
+  out <- .get_predicted_transform(x, predictions, my_args, ci_data, link_inv = exp, verbose = verbose)
 
   # 4. step: final preparation
-  .get_predicted_out(out$predictions, args = args, ci_data = out$ci_data)
+  .get_predicted_out(out$predictions, my_args = my_args, ci_data = out$ci_data)
 }
 
 
-
-
 # bife ------------------------------------------------------------------
 # =======================================================================
 
@@ -466,17 +462,17 @@ get_predicted.bife <- function(x,
                                data = NULL,
                                verbose = TRUE,
                                ...) {
-  args <- .get_predicted_args(x,
+  my_args <- .get_predicted_args(x,
     data = data,
     predict = predict,
     verbose = TRUE,
     ...
   )
 
-  out <- .safe(stats::predict(x, type = args$scale, X_new = args$data))
+  out <- .safe(stats::predict(x, type = my_args$scale, X_new = my_args$data))
 
   if (!is.null(out)) {
-    out <- .get_predicted_out(out, args = list(data = data))
+    out <- .get_predicted_out(out, my_args = list(data = data))
   }
 
   out
@@ -494,7 +490,7 @@ get_predicted.rma <- function(x,
                               transf = NULL,
                               transf_args = NULL,
                               ...) {
-  args <- .get_predicted_args(x,
+  my_args <- .get_predicted_args(x,
     data = data,
     predict = predict,
     verbose = TRUE,
@@ -567,42 +563,38 @@ get_predicted.rma <- function(x,
     if (nrow(out) == 1) {
       out <- do.call(rbind, lapply(seq_along(x$slab), function(i) out))
     }
-    out <- .get_predicted_out(out, args = list(data = data))
+    out <- .get_predicted_out(out, my_args = list(data = data))
   }
 
   out
 }
 
 
-
-
 # afex ------------------------------------------------------------------
 # =======================================================================
 
 #' @export
 get_predicted.afex_aov <- function(x, data = NULL, ...) {
   if (is.null(data)) {
-    args <- c(list(x), list(...))
+    my_args <- c(list(x), list(...))
   } else {
-    args <- c(list(x, newdata = data), list(...))
+    my_args <- c(list(x, newdata = data), list(...))
   }
 
-  out <- .safe(do.call("predict", args))
+  out <- .safe(do.call("predict", my_args))
 
   if (is.null(out)) {
-    out <- .safe(do.call("fitted", args))
+    out <- .safe(do.call("fitted", my_args))
   }
 
   if (!is.null(out)) {
-    out <- .get_predicted_out(out, args = list(data = data))
+    out <- .get_predicted_out(out, my_args = list(data = data))
   }
 
   out
 }
 
 
-
-
 # phylolm ---------------------------------------------------------------
 # =======================================================================
 
@@ -613,7 +605,7 @@ get_predicted.phylolm <- function(x,
                                   verbose = TRUE,
                                   ...) {
   # evaluate arguments
-  args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
+  my_args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
 
   # evaluate dots, remove some arguments that might be duplicated else
   dot_args <- list(...)
@@ -622,13 +614,13 @@ get_predicted.phylolm <- function(x,
 
 
   # 1. step: predictions
-  predict_args <- compact_list(list(x, newdata = args$data, type = args$type, dot_args))
+  predict_args <- compact_list(list(x, newdata = my_args$data, type = my_args$type, dot_args))
   predictions <- .safe(do.call("predict", predict_args))
 
   # may fail due to invalid "dot_args", so try shorter argument list
   if (is.null(predictions)) {
     predictions <- .safe(
-      do.call("predict", compact_list(list(x, newdata = args$data, type = args$type)))
+      do.call("predict", compact_list(list(x, newdata = my_args$data, type = my_args$type)))
     )
   }
 
@@ -645,14 +637,13 @@ get_predicted.phylolm <- function(x,
   }
   # 2. step: final preparation
   if (!is.null(out)) {
-    out <- .get_predicted_out(predictions, args = args, ci_data = NULL)
+    out <- .get_predicted_out(predictions, my_args = my_args, ci_data = NULL)
   }
 
   out
 }
 
 
-
 # ====================================================================
 # Utils --------------------------------------------------------------
 # ====================================================================
@@ -673,8 +664,6 @@ get_predicted.phylolm <- function(x,
 }
 
 
-
-
 # back-transformation ------------------------------------------------------
 
 .get_predict_transform_response <- function(predictions, response) {
@@ -694,16 +683,16 @@ get_predicted.phylolm <- function(x,
 
 .get_predicted_transform <- function(x,
                                      predictions,
-                                     args = NULL,
+                                     my_args = NULL,
                                      ci_data = NULL,
                                      link_inv = NULL,
                                      verbose = FALSE,
                                      ...) {
   # Transform to response scale
-  if (isTRUE(args$transform)) {
+  if (isTRUE(my_args$transform)) {
     # retrieve link-inverse, for back transformation...
     if (is.null(link_inv)) {
-      link_inv <- link_inverse(x)
+      link_inv <- .link_inverse(model = x, verbose = verbose, ...)
     }
 
     if (!is.null(ci_data)) {
@@ -741,7 +730,7 @@ get_predicted.phylolm <- function(x,
     }
 
     # Transform to response "type"
-    if (args$predict == "classification" && model_info(x, verbose = FALSE)$is_binomial) {
+    if (my_args$predict == "classification" && model_info(x, verbose = FALSE)$is_binomial) {
       response <- get_response(x, as_proportion = TRUE)
       ci_data[!se_col] <- lapply(ci_data[!se_col], .get_predict_transform_response, response = response)
       predictions <- .get_predict_transform_response(predictions, response = response)
@@ -761,18 +750,99 @@ get_predicted.phylolm <- function(x,
 }
 
 
+# internal to return possibly bias correct link-function
+.link_inverse <- function(model = NULL,
+                          bias_correction = FALSE,
+                          sigma = NULL,
+                          verbose = TRUE,
+                          ...) {
+  if (isTRUE(bias_correction)) {
+    dots <- list(...)
+    if (!is.null(sigma) && !is.na(sigma)) {
+      residual_variance <- sigma^2
+    } else {
+      residual_variance <- NULL
+    }
+    l <- .bias_correction(model, residual_variance, verbose)$linkinv
+    if (is.null(l)) {
+      l <- link_inverse(model)
+    }
+  } else {
+    l <- link_inverse(model)
+  }
+  l
+}
+
+
+# apply bias-correction for back-transformation of predictions on the link-scale
+# we want sigma^2 (residual_variance) here to calculate the correction
+.bias_correction <- function(model = NULL, residual_variance = NULL, verbose = TRUE) {
+  # we need a model object
+  if (is.null(model)) {
+    return(NULL)
+  }
+  # extract residual variance, if not provided
+  if (is.null(residual_variance)) {
+    residual_variance <- .get_residual_variance(model) # returns sigma^2
+  }
+  # we need residual variance
+  if (is.null(residual_variance)) {
+    if (verbose) {
+      format_alert("Could not extract residual variance to apply bias correction. No bias adjustment carried out.") # nolint
+    }
+    return(NULL)
+  }
+
+  # extract current link function
+  link <- .safe(get_family(model))
+  # we need a link function
+  if (is.null(link)) {
+    if (verbose) {
+      format_alert("Could not extract information about the model's link-function to apply bias correction. No bias adjustment carried out.") # nolint
+    }
+    return(NULL)
+  }
+
+  link$inv <- link$linkinv
+  link$der <- link$mu.eta
+  link$residual_variance <- residual_variance / 2
+
+  link$der2 <- function(eta) {
+    with(link, 1000 * (der(eta + 5e-4) - der(eta - 5e-4)))
+  }
+  link$linkinv <- function(eta) {
+    with(link, inv(eta) + residual_variance * der2(eta))
+  }
+  link$mu.eta <- function(eta) {
+    with(link, der(eta) + 1000 * residual_variance * (der2(eta + 5e-4) - der2(eta - 5e-4)))
+  }
+  link
+}
+
+
+.get_residual_variance <- function(x) {
+  if (is_mixed_model(x)) {
+    out <- .safe(get_variance_residual(x))
+  } else {
+    out <- .safe(.get_sigma(x, no_recursion = TRUE, verbose = FALSE)^2, 0)
+    if (!length(out)) {
+      out <- 0
+    }
+  }
+  out
+}
 
 
 # -------------------------------------------------------------------------
 
-.get_predicted_out <- function(predictions, args = NULL, ci_data = NULL, ...) {
+.get_predicted_out <- function(predictions, my_args = NULL, ci_data = NULL, ...) {
   if (!is.null(ci_data)) {
     attr(predictions, "ci_data") <- ci_data
   }
-  if (!is.null(args)) {
-    attr(predictions, "data") <- args$data
-    attr(predictions, "ci") <- args$ci
-    attr(predictions, "predict") <- args$predict
+  if (!is.null(my_args)) {
+    attr(predictions, "data") <- my_args$data
+    attr(predictions, "ci") <- my_args$ci
+    attr(predictions, "predict") <- my_args$predict
   }
 
   # multidimensional or "grouped" predictions (e.g., nnet::multinom with `predict(type="probs")`)
@@ -782,10 +852,10 @@ get_predicted.phylolm <- function(x,
     predictions$Row <- seq_len(nrow(predictions))
     # if we have any focal predictors, add those as well, so we have
     # the associated levels/values for "Row"
-    if (!is.null(args$data)) {
-      focal_predictors <- .safe(names(which(n_unique(args$data) > 1L)))
+    if (!is.null(my_args$data)) {
+      focal_predictors <- .safe(names(which(n_unique(my_args$data) > 1L)))
       if (!is.null(focal_predictors)) {
-        predictions <- cbind(predictions, args$data[focal_predictors])
+        predictions <- cbind(predictions, my_args$data[focal_predictors])
       }
     }
     predictions <- stats::reshape(predictions,
@@ -804,8 +874,6 @@ get_predicted.phylolm <- function(x,
 }
 
 
-
-
 # Bootstrap ==============================================================
 
 .get_predicted_boot <- function(x,
@@ -848,13 +916,12 @@ get_predicted.phylolm <- function(x,
 }
 
 
-
-
 # -------------------------------------------------------------------------
 
 .get_predicted_centrality_from_draws <- function(x,
                                                  iter,
                                                  centrality_function = base::mean,
+                                                 datagrid = NULL,
                                                  ...) {
   # outcome: ordinal/multinomial/multivariate produce a 3D array of predictions,
   # which we stack in "long" format
@@ -870,6 +937,16 @@ get_predicted.phylolm <- function(x,
       Predicted = apply(iter_stacked, 1, centrality_function),
       stringsAsFactors = FALSE
     )
+    # for ordinal etc. outcomes, we need to include the data from the grid, too
+    if (!is.null(datagrid)) {
+      # due to reshaping predictions into long format, we to repeat the
+      # datagrid multiple times, to have same number of rows
+      times <- nrow(predictions) / nrow(datagrid)
+      if (nrow(predictions) %% times == 0) {
+        datagrid <- do.call(rbind, replicate(times, datagrid, simplify = FALSE))
+        predictions <- cbind(predictions[1:2], datagrid, predictions[3])
+      }
+    }
     iter <- as.data.frame(iter_stacked)
     # outcome with a single level
   } else {
@@ -887,16 +964,11 @@ get_predicted.phylolm <- function(x,
 }
 
 
-
 # -------------------------------------------------------------------------
 
-.create_newmods_rma <- function(x, data, ...) {
+.create_newmods_rma <- function(x, data, ...) {}
 
-}
-
-.create_newscale_rma <- function(x, data, ...) {
-
-}
+.create_newscale_rma <- function(x, data, ...) {}
 
 .get_blup_rma <- function(x, data, ci = NULL, ...) {
   if (is.element(x$test, c("knha", "adhoc", "t"))) {
