@@ -66,7 +66,7 @@ get_predicted.lmerMod <- function(x,
   )
 
   # 3. step: back-transform
-  out <- .get_predicted_transform(x, predictions, my_args, ci_data, verbose = verbose)
+  out <- .get_predicted_transform(x, predictions, my_args, ci_data, verbose = verbose, ...)
 
   # 4. step: final preparation
   .get_predicted_out(out$predictions, my_args = my_args, ci_data = out$ci_data)
@@ -76,8 +76,6 @@ get_predicted.lmerMod <- function(x,
 get_predicted.merMod <- get_predicted.lmerMod
 
 
-
-
 # glmmTMB ---------------------------------------------------------------
 # =======================================================================
 
@@ -183,7 +181,7 @@ get_predicted.glmmTMB <- function(x,
     )
 
     # 3. step: back-transform
-    out <- .get_predicted_transform(x, predictions, my_args, ci_data, verbose = verbose)
+    out <- .get_predicted_transform(x, predictions, my_args, ci_data, verbose = verbose, ...)
   }
 
   # 4. step: final preparation
@@ -191,8 +189,6 @@ get_predicted.glmmTMB <- function(x,
 }
 
 
-
-
 # GLMMadaptive: mixed_model (class MixMod) ------------------------------
 # =======================================================================
 
@@ -273,7 +269,7 @@ get_predicted.MixMod <- function(x,
     )
 
     # 3. step: back-transform
-    out <- .get_predicted_transform(x, predictions, my_args, ci_data)
+    out <- .get_predicted_transform(x, predictions, my_args, ci_data, verbose = verbose, ...)
   }
 
   # 4. step: final preparation
@@ -281,7 +277,6 @@ get_predicted.MixMod <- function(x,
 }
 
 
-
 # HGLM: mixed_model (class hglm) ------------------------------
 # =============================================================
 
