@@ -11,14 +11,30 @@
 #'   where the index of the column that is being pulled is `column_index`.
 #'   Defaults to 3, which is the default statistic column for most models'
 #'   summary-output.
-#' @param component Should all parameters, parameters for the conditional model,
-#'   or for the zero-inflated part of the model be returned? Applies to models
-#'   with zero-inflated component. `component` may be one of
-#'   `"conditional"`, `"zi"`, `"zero-inflated"` or `"all"`
-#'   (default). For models with smooth terms, `component = "smooth_terms"`
-#'   is also possible. May be abbreviated. Note that the *conditional*
-#'   component is also called *count* or *mean* component, depending
-#'   on the model.
+#' @param component String, indicating the model component for which parameters
+#'   should be returned. The default for all models is `"all"`, which returns
+#'   the requested information for all available model components. Furthermore,
+#'   there are specific options depending on the model class. `component` then
+#'   may be one of:
+#'
+#'   - For zero-inflated models (`gmmTMB`, `hurdle`, `zeroinfl`, ...) can also
+#'     be `"conditional"` or `"zero-inflated"`. Note that the *conditional*
+#'     component is also called *count* or *mean* component, depending on the
+#'     model. `glmmTMB` also has a `"dispersion"` component.
+#'   - For models with smooth terms, `component = "smooth_terms"` returns the
+#'     test statistic for the smooth terms.
+#'   - For models of class `mhurdle`, may also be one of  `"conditional"`,
+#'     `"zero_inflated"`, `"infrequent_purchase"` or `"auxiliary"`.
+#'   - For models of class `clm2` or `clmm2`, may also be `"scale"`.
+#'   - For models of class `betareg`, `betaor` or `betamfx`, may also be
+#'     `"precision"`. For other `*mfx` models (`logitmfx`, `betamfx`, ...),
+#'     may also be `"marginal"`.
+#'   - For models of class `mvord`, may also be `"thresholds"` or
+#'     `"correlation"`.
+#'   - For models of class `selection`, may also be `"selection"`, `"outcome"`
+#'     or `"auxiliary"`.
+#'   - For models of class `glmx`, may also be `"extra"`.
+#'   - For models of class `averaging`, may also be `"full"`.
 #' @param robust Logical, if `TRUE`, test statistic based on robust
 #'   standard errors is returned.
 #' @param adjust Character value naming the method used to adjust p-values or
@@ -42,7 +58,6 @@ get_statistic <- function(x, ...) {
 }
 
 
-
 # Default models ----------------------------------------------------------
 
 
@@ -53,7 +68,7 @@ get_statistic.default <- function(x, column_index = 3, verbose = TRUE, ...) {
 
   if (column_index > ncol(cs)) {
     if (isTRUE(verbose)) {
-      warning("Could not access test statistic of model parameters.", call. = FALSE)
+      format_warning("Could not access test statistic of model parameters.")
     }
     return(NULL)
   }
@@ -76,6 +91,7 @@ get_statistic.default <- function(x, column_index = 3, verbose = TRUE, ...) {
   out
 }
 
+
 #' @export
 get_statistic.htest <- function(x, ...) {
   if (x$method == "Fisher's Exact Test for Count Data") {
@@ -149,6 +165,7 @@ get_statistic.lme <- function(x, ...) {
 #' @export
 get_statistic.lmerModLmerTest <- get_statistic.lme
 
+
 #' @export
 get_statistic.mmrm <- function(x, ...) {
   get_statistic.default(x, column_index = 4)
@@ -160,6 +177,7 @@ get_statistic.mmrm_fit <- get_statistic.mmrm
 #' @export
 get_statistic.mmrm_tmb <- get_statistic.mmrm
 
+
 #' @export
 get_statistic.merModList <- function(x, ...) {
   s <- suppressWarnings(summary(x))
@@ -174,11 +192,44 @@ get_statistic.merModList <- function(x, ...) {
   out
 }
 
+
+#' @export
+get_statistic.asym <- function(x, ...) {
+  cftable <- summary(x)$coef_table
+  out <- data.frame(
+    Parameter = find_parameters(x)$conditional,
+    Statistic = cftable[, "t val."],
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  out <- text_remove_backticks(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
+#' @export
+get_statistic.oohbchoice <- function(x, ...) {
+  cftable <- summary(x)$coef
+  out <- data.frame(
+    Parameter = find_parameters(x)$conditional,
+    Statistic = cftable[, "z value"],
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  out <- text_remove_backticks(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
 #' @export
 get_statistic.afex_aov <- function(x, ...) {
   out <- data.frame(
     Parameter = rownames(x$anova_table),
-    Statistic = x$anova_table$"F",
+    Statistic = x$anova_table[["F"]],
     stringsAsFactors = FALSE,
     row.names = NULL
   )
@@ -203,56 +254,49 @@ get_statistic.anova.rms <- function(x, ...) {
   out
 }
 
-
 #' @export
 get_statistic.plm <- get_statistic.default
 
-
 #' @export
 get_statistic.maxLik <- get_statistic.default
 
-
 #' @export
 get_statistic.glmmadmb <- get_statistic.default
 
-
 #' @export
 get_statistic.lm_robust <- get_statistic.default
 
-
 #' @export
 get_statistic.geeglm <- get_statistic.default
 
-
 #' @export
 get_statistic.truncreg <- get_statistic.default
 
-
 #' @export
 get_statistic.tobit <- get_statistic.default
 
-
 #' @export
 get_statistic.censReg <- get_statistic.default
 
-
 #' @export
 get_statistic.negbin <- get_statistic.default
 
-
 #' @export
 get_statistic.feis <- get_statistic.default
 
 
-
 # Models with zero-inflation component --------------------------------------
 
 
 #' @export
-get_statistic.mhurdle <- function(x,
-                                  component = c("all", "conditional", "zi", "zero_inflated", "infrequent_purchase", "ip", "auxiliary"),
-                                  ...) {
-  component <- match.arg(component)
+get_statistic.mhurdle <- function(x, component = "all", ...) {
+  component <- match.arg(
+    component,
+    choices = c(
+      "all", "conditional", "zi", "zero_inflated", "infrequent_purchase",
+      "ip", "auxiliary"
+    )
+  )
 
   s <- summary(x)
   params <- get_parameters(x, component = "all")
@@ -285,10 +329,11 @@ get_statistic.mhurdle <- function(x,
 
 #' @rdname get_statistic
 #' @export
-get_statistic.glmmTMB <- function(x,
-                                  component = c("all", "conditional", "zi", "zero_inflated", "dispersion"),
-                                  ...) {
-  component <- match.arg(component)
+get_statistic.glmmTMB <- function(x, component = "all", ...) {
+  component <- match.arg(
+    component,
+    choices = c("all", "conditional", "zi", "zero_inflated", "dispersion")
+  )
 
   cs <- compact_list(stats::coef(summary(x)))
   out <- lapply(names(cs), function(i) {
@@ -315,10 +360,11 @@ get_statistic.glmmTMB <- function(x,
 
 
 #' @export
-get_statistic.zeroinfl <- function(x,
-                                   component = c("all", "conditional", "zi", "zero_inflated"),
-                                   ...) {
-  component <- match.arg(component)
+get_statistic.zeroinfl <- function(x, component = "all", ...) {
+  component <- match.arg(
+    component,
+    choices = c("all", "conditional", "zi", "zero_inflated")
+  )
 
   cs <- compact_list(stats::coef(summary(x)))
   out <- lapply(names(cs), function(i) {
@@ -363,10 +409,12 @@ get_statistic.zerocount <- get_statistic.zeroinfl
 
 
 #' @export
-get_statistic.MixMod <- function(x,
-                                 component = c("all", "conditional", "zi", "zero_inflated"),
-                                 ...) {
-  component <- match.arg(component)
+get_statistic.MixMod <- function(x, component = "all", ...) {
+  component <- match.arg(
+    component,
+    choices = c("all", "conditional", "zi", "zero_inflated")
+  )
+
   s <- summary(x)
   cs <- list(s$coef_table, s$coef_table_zi)
   names(cs) <- c("conditional", "zero_inflated")
@@ -450,7 +498,6 @@ get_statistic.gam <- function(x, ...) {
 get_statistic.scam <- get_statistic.gam
 
 
-
 #' @export
 get_statistic.SemiParBIV <- function(x, ...) {
   s <- summary(x)
@@ -472,7 +519,6 @@ get_statistic.SemiParBIV <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.gamm <- function(x, ...) {
   x <- x$gam
@@ -494,7 +540,9 @@ get_statistic.list <- function(x, ...) {
 #' @export
 get_statistic.gamlss <- function(x, ...) {
   parms <- get_parameters(x)
-  utils::capture.output(cs <- summary(x)) # nolint
+  utils::capture.output({
+    cs <- summary(x)
+  })
 
   out <- data.frame(
     Parameter = parms$Parameter,
@@ -509,7 +557,6 @@ get_statistic.gamlss <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.vglm <- function(x, ...) {
   check_if_installed("VGAM")
@@ -528,7 +575,6 @@ get_statistic.vglm <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.vgam <- function(x, ...) {
   params <- get_parameters(x)
@@ -548,12 +594,12 @@ get_statistic.vgam <- function(x, ...) {
 }
 
 
-
 #' @export
-get_statistic.cgam <- function(x,
-                               component = c("all", "conditional", "smooth_terms"),
-                               ...) {
-  component <- match.arg(component)
+get_statistic.cgam <- function(x, component = "all", ...) {
+  component <- match.arg(
+    component,
+    choices = c("all", "conditional", "smooth_terms")
+  )
 
   sc <- summary(x)
   stat <- as.vector(sc$coefficients[, 3])
@@ -578,7 +624,6 @@ get_statistic.cgam <- function(x,
 }
 
 
-
 # Survival models ------------------------------------------
 
 
@@ -641,13 +686,13 @@ get_statistic.crr <- get_statistic.coxr
 
 #' @export
 get_statistic.coxme <- function(x, ...) {
-  beta <- x$coefficients
+  betas <- x$coefficients
   out <- NULL
 
-  if (length(beta) > 0) {
+  if (length(betas) > 0) {
     out <- data.frame(
-      Parameter = names(beta),
-      Statistic = as.vector(beta / sqrt(diag(stats::vcov(x)))),
+      Parameter = names(betas),
+      Statistic = as.vector(betas / sqrt(diag(stats::vcov(x)))),
       stringsAsFactors = FALSE,
       row.names = NULL
     )
@@ -660,7 +705,6 @@ get_statistic.coxme <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.riskRegression <- function(x, ...) {
   junk <- utils::capture.output(cs <- stats::coef(x)) # nolint
@@ -695,7 +739,6 @@ get_statistic.survreg <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.BBmm <- function(x, ...) {
   parms <- get_parameters(x)
@@ -713,7 +756,6 @@ get_statistic.BBmm <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.flexsurvreg <- function(x, ...) {
   parms <- get_parameters(x)
@@ -748,16 +790,12 @@ get_statistic.aareg <- function(x, ...) {
 }
 
 
-
 # Ordinal models --------------------------------------------------
 
 
-#' @rdname get_statistic
 #' @export
-get_statistic.clm2 <- function(x,
-                               component = c("all", "conditional", "scale"),
-                               ...) {
-  component <- match.arg(component)
+get_statistic.clm2 <- function(x, component = "all", ...) {
+  component <- match.arg(component, choices = c("all", "conditional", "scale"))
 
   stats <- stats::coef(summary(x))
   n_intercepts <- length(x$xi)
@@ -786,32 +824,43 @@ get_statistic.clmm2 <- get_statistic.clm2
 
 
 #' @export
-get_statistic.mvord <- function(x,
-                                component = c("all", "conditional", "thresholds", "correlation"),
-                                ...) {
-  component <- match.arg(component)
-  junk <- utils::capture.output(s <- summary(x)) # nolint
+get_statistic.ordinal_weightit <- function(x, ...) {
+  out <- get_statistic.default(x, ...)
+  out$Component <- "conditional"
+  out
+}
+
+
+#' @export
+get_statistic.mvord <- function(x, component = "all", ...) {
+  component <- match.arg(
+    component,
+    choices = c("all", "conditional", "thresholds", "correlation")
+  )
+  junk <- utils::capture.output({
+    s <- summary(x)
+  })
   # intercepts thresholds
   thresholds <- as.data.frame(s$thresholds)
   thresholds$Parameter <- rownames(thresholds)
   thresholds$Response <- gsub("(.*)\\s(.*)", "\\1", thresholds$Parameter)
   # coefficients
-  coefficients <- as.data.frame(s$coefficients)
-  coefficients$Parameter <- rownames(coefficients)
-  coefficients$Response <- gsub("(.*)\\s(.*)", "\\2", coefficients$Parameter)
+  model_coef <- as.data.frame(s$coefficients)
+  model_coef$Parameter <- rownames(model_coef)
+  model_coef$Response <- gsub("(.*)\\s(.*)", "\\2", model_coef$Parameter)
 
-  if (!all(coefficients$Response %in% thresholds$Response)) {
+  if (!all(model_coef$Response %in% thresholds$Response)) {
     resp <- unique(thresholds$Response)
-    for (i in coefficients$Response) {
-      coefficients$Response[coefficients$Response == i] <- resp[grepl(paste0(i, "$"), resp)]
+    for (i in model_coef$Response) {
+      model_coef$Response[model_coef$Response == i] <- resp[grepl(paste0(i, "$"), resp)]
     }
   }
 
   params <- data.frame(
-    Parameter = c(thresholds$Parameter, coefficients$Parameter),
-    Statistic = c(unname(thresholds[, "z value"]), unname(coefficients[, "z value"])),
-    Component = c(rep("thresholds", nrow(thresholds)), rep("conditional", nrow(coefficients))),
-    Response = c(thresholds$Response, coefficients$Response),
+    Parameter = c(thresholds$Parameter, model_coef$Parameter),
+    Statistic = c(unname(thresholds[, "z value"]), unname(model_coef[, "z value"])),
+    Component = c(rep("thresholds", nrow(thresholds)), rep("conditional", nrow(model_coef))),
+    Response = c(thresholds$Response, model_coef$Response),
     stringsAsFactors = FALSE,
     row.names = NULL
   )
@@ -841,10 +890,8 @@ get_statistic.mvord <- function(x,
 
 
 #' @export
-get_statistic.glmm <- function(x,
-                               effects = c("all", "fixed", "random"),
-                               ...) {
-  effects <- match.arg(effects)
+get_statistic.glmm <- function(x, effects = "all", ...) {
+  effects <- match.arg(effects, choices = c("all", "fixed", "random"))
   s <- summary(x)
 
   out <- get_parameters(x, effects = "all")
@@ -862,11 +909,9 @@ get_statistic.glmm <- function(x,
 
 
 #' @export
-get_statistic.mixor <- function(x,
-                                effects = c("all", "fixed", "random"),
-                                ...) {
+get_statistic.mixor <- function(x, effects = "all", ...) {
   stats <- x$Model[, "z value"]
-  effects <- match.arg(effects)
+  effects <- match.arg(effects, choices = c("all", "fixed", "random"))
 
   parms <- get_parameters(x, effects = effects)
 
@@ -882,18 +927,19 @@ get_statistic.mixor <- function(x,
   out
 }
 
+
 #' @export
 get_statistic.multinom <- function(x, ...) {
   parms <- get_parameters(x)
-  stderr <- summary(x)$standard.errors
+  std_err <- summary(x)$standard.errors
 
-  if (is.matrix(stderr)) {
+  if (is.matrix(std_err)) {
     se <- NULL
-    for (i in seq_len(nrow(stderr))) {
-      se <- c(se, as.vector(stderr[i, ]))
+    for (i in seq_len(nrow(std_err))) {
+      se <- c(se, as.vector(std_err[i, ]))
     }
   } else {
-    se <- as.vector(stderr)
+    se <- as.vector(std_err)
   }
 
   out <- data.frame(
@@ -914,6 +960,26 @@ get_statistic.multinom <- function(x, ...) {
 #' @export
 get_statistic.brmultinom <- get_statistic.multinom
 
+#' @export
+get_statistic.multinom_weightit <- function(x, ...) {
+  parms <- get_parameters(x)
+  cs <- suppressWarnings(stats::coef(summary(x)))
+
+  out <- data.frame(
+    Parameter = parms$Parameter,
+    Statistic = as.vector(cs[, 3]),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  if ("Response" %in% colnames(parms)) {
+    out$Response <- parms$Response
+  }
+
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
 
 #' @export
 get_statistic.bracl <- function(x, ...) {
@@ -931,6 +997,7 @@ get_statistic.bracl <- function(x, ...) {
   out
 }
 
+
 #' @export
 get_statistic.deltaMethod <- function(x, ...) {
   stat <- standardize_names(x)
@@ -952,6 +1019,7 @@ get_statistic.deltaMethod <- function(x, ...) {
   out
 }
 
+
 #' @export
 get_statistic.mlogit <- function(x, ...) {
   if (requireNamespace("mlogit", quietly = TRUE)) {
@@ -973,15 +1041,57 @@ get_statistic.mlogit <- function(x, ...) {
 }
 
 
+#' @export
+get_statistic.mclogit <- function(x, ...) {
+  if (requireNamespace("mclogit", quietly = TRUE)) {
+    cs <- stats::coef(summary(x))
+
+    out <- data.frame(
+      Parameter = rownames(cs),
+      Statistic = as.vector(cs[, 3]),
+      stringsAsFactors = FALSE,
+      row.names = NULL
+    )
+
+    out <- text_remove_backticks(out)
+    attr(out, "statistic") <- find_statistic(x)
+    out
+  } else {
+    NULL
+  }
+}
+
+
+#' @export
+get_statistic.mblogit <- function(x, ...) {
+  if (requireNamespace("mclogit", quietly = TRUE)) {
+    cs <- stats::coef(summary(x))
+
+    out <- data.frame(
+      Parameter = gsub("(.*)~(.*)", "\\2", rownames(cs)),
+      Statistic = as.vector(cs[, 3]),
+      Response = gsub("(.*)~(.*)", "\\1", rownames(cs)),
+      stringsAsFactors = FALSE,
+      row.names = NULL
+    )
+
+    out <- text_remove_backticks(out)
+    attr(out, "statistic") <- find_statistic(x)
+    out
+  } else {
+    NULL
+  }
+}
+
 
 # mfx models -------------------------------------------------------
 
-#' @rdname get_statistic
 #' @export
-get_statistic.betamfx <- function(x,
-                                  component = c("all", "conditional", "precision", "marginal"),
-                                  ...) {
-  component <- match.arg(component)
+get_statistic.betamfx <- function(x, component = "all", ...) {
+  component <- match.arg(
+    component,
+    choices = c("all", "conditional", "precision", "marginal")
+  )
   parms <- get_parameters(x, component = "all", ...)
   cs <- do.call(rbind, stats::coef(summary(x$fit)))
   stat <- c(as.vector(x$mfxest[, 3]), as.vector(cs[, 3]))
@@ -1004,10 +1114,8 @@ get_statistic.betamfx <- function(x,
 
 
 #' @export
-get_statistic.betaor <- function(x,
-                                 component = c("all", "conditional", "precision"),
-                                 ...) {
-  component <- match.arg(component)
+get_statistic.betaor <- function(x, component = "all", ...) {
+  component <- match.arg(component, choices = c("all", "conditional", "precision"))
   parms <- get_parameters(x, component = "all", ...)
   cs <- do.call(rbind, stats::coef(summary(x$fit)))
 
@@ -1028,11 +1136,9 @@ get_statistic.betaor <- function(x,
 }
 
 
-#' @rdname get_statistic
 #' @export
-get_statistic.logitmfx <- function(x,
-                                   component = c("all", "conditional", "marginal"),
-                                   ...) {
+get_statistic.logitmfx <- function(x, component = "all", ...) {
+  component <- match.arg(component, choices = c("all", "conditional", "marginal"))
   parms <- get_parameters(x, component = "all", ...)
   cs <- stats::coef(summary(x$fit))
   stat <- c(as.vector(x$mfxest[, 3]), as.vector(cs[, 3]))
@@ -1078,11 +1184,62 @@ get_statistic.negbinirr <- get_statistic.logitor
 
 
 #' @export
-get_statistic.pgmm <- function(x,
-                               component = c("conditional", "all"),
-                               verbose = TRUE,
-                               ...) {
-  component <- match.arg(component)
+get_statistic.glmgee <- function(x, ...) {
+  junk <- utils::capture.output({
+    cs <- suppressWarnings(stats::coef(summary(x, corr = FALSE)))
+  })
+  stat <- stats::na.omit(cs[, "z-value"])
+
+  out <- data.frame(
+    Parameter = names(stat),
+    Statistic = as.vector(stat),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  out <- text_remove_backticks(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
+#' @export
+get_statistic.nestedLogit <- function(x, component = "all", verbose = TRUE, ...) {
+  cf <- as.data.frame(stats::coef(x))
+  out <- as.data.frame(do.call(rbind, lapply(x$models, function(i) stats::coef(summary(i)))))
+  colnames(out)[3] <- "Statistic"
+  response_levels <- unlist(lapply(x$dichotomies, function(i) {
+    paste0("{", toString(i[[1]]), "} vs. {", toString(i[[2]]), "}")
+  }))
+  out$Response <- rep(response_levels, each = nrow(cf))
+  out$Component <- rep(names(x$models), each = nrow(cf))
+  out$Parameter <- rep(row.names(cf), times = ncol(cf))
+
+  if (!is.null(component) && !identical(component, "all")) {
+    comp <- intersect(names(x$models), component)
+    if (!length(comp) && verbose) {
+      format_alert(
+        paste0(
+          "No matching model found. Possible values for `component` are ",
+          toString(paste0("\"", names(x$models), "\"")),
+          "."
+        )
+      )
+    } else {
+      out <- out[out$Component %in% component, ]
+    }
+  }
+
+  out <- text_remove_backticks(out[c("Parameter", "Statistic", "Response", "Component")])
+  row.names(out) <- NULL
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
+#' @export
+get_statistic.pgmm <- function(x, component = "conditional", verbose = TRUE, ...) {
+  component <- match.arg(component, choices = c("conditional", "all"))
   cs <- stats::coef(summary(x, time.dummies = TRUE, robust = FALSE))
 
   out <- data.frame(
@@ -1107,10 +1264,11 @@ get_statistic.pgmm <- function(x,
 
 
 #' @export
-get_statistic.selection <- function(x,
-                                    component = c("all", "selection", "outcome", "auxiliary"),
-                                    ...) {
-  component <- match.arg(component)
+get_statistic.selection <- function(x, component = "all", ...) {
+  component <- match.arg(
+    component,
+    choices = c("all", "selection", "outcome", "auxiliary")
+  )
   s <- summary(x)
   rn <- row.names(s$estimate)
   estimates <- as.data.frame(s$estimate, row.names = FALSE)
@@ -1136,7 +1294,6 @@ get_statistic.selection <- function(x,
 
 #' @export
 get_statistic.lavaan <- function(x, ...) {
-  # installed?
   check_if_installed("lavaan")
 
   params <- lavaan::parameterEstimates(x)
@@ -1172,10 +1329,10 @@ get_statistic.model_fit <- function(x, ...) {
 get_statistic.Sarlm <- function(x, ...) {
   s <- summary(x)
   # add rho, if present
-  if (!is.null(s$rho)) {
-    rho <- as.numeric(s$rho) / as.numeric(s$rho.se)
-  } else {
+  if (is.null(s$rho)) {
     rho <- NULL
+  } else {
+    rho <- as.numeric(s$rho) / as.numeric(s$rho.se)
   }
   stat <- data.frame(
     Parameter = find_parameters(x, flatten = TRUE),
@@ -1191,12 +1348,9 @@ get_statistic.Sarlm <- function(x, ...) {
 }
 
 
-#' @rdname get_statistic
 #' @export
-get_statistic.mjoint <- function(x,
-                                 component = c("all", "conditional", "survival"),
-                                 ...) {
-  component <- match.arg(component)
+get_statistic.mjoint <- function(x, component = "all", ...) {
+  component <- match.arg(component, choices = c("all", "conditional", "survival"))
   s <- summary(x)
 
   params <- rbind(
@@ -1267,10 +1421,10 @@ get_statistic.btergm <- function(x, verbose = TRUE, ...) {
   bootstraps <- x@boot$t
 
   # standard error
-  sdev <- sapply(seq_len(ncol(bootstraps)), function(i) {
+  sdev <- vapply(seq_len(ncol(bootstraps)), function(i) {
     cur <- (bootstraps[, i] - params[i])^2
     sqrt(sum(cur) / length(cur))
-  })
+  }, numeric(1))
   stat <- (0 - colMeans(bootstraps)) / sdev
 
   out <- data.frame(
@@ -1314,6 +1468,19 @@ get_statistic.ivprobit <- function(x, ...) {
 }
 
 
+#' @export
+get_statistic.svy2lme <- function(x, ...) {
+  out <- data.frame(
+    Parameter = rownames(x$beta),
+    Statistic = as.vector(x$beta / sqrt(diag(x$Vbeta))),
+    stringsAsFactors = FALSE
+  )
+  out <- text_remove_backticks(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
 #' @export
 get_statistic.HLfit <- function(x, ...) {
   utils::capture.output(s <- summary(x)) # nolint
@@ -1386,11 +1553,16 @@ get_statistic.lqm <- get_statistic.lqmm
 
 #' @export
 get_statistic.mipo <- function(x, ...) {
+  s <- summary(x)
   params <- data.frame(
-    Parameter = as.vector(summary(x)$term),
-    Statistic = as.vector(summary(x)$statistic),
+    Parameter = as.vector(s$term),
+    Statistic = as.vector(s$statistic),
     stringsAsFactors = FALSE
   )
+  # check for ordinal-alike models
+  if (!is.null(x$pooled) && "y.level" %in% colnames(x$pooled)) {
+    params$Response <- as.vector(x$pooled$y.level)
+  }
   out <- text_remove_backticks(params)
   attr(out, "statistic") <- find_statistic(x)
   out
@@ -1497,11 +1669,11 @@ get_statistic.emm_list <- function(x, ci = 0.95, adjust = "none", ...) {
     return(NULL)
   }
 
-  stat <- unlist(stat)
+  stat <- unlist(stat, use.names = FALSE)
 
   out <- data.frame(
     Parameter = params$Parameter,
-    Statistic = as.vector(stat),
+    Statistic = stat,
     Component = params$Component,
     stringsAsFactors = FALSE,
     row.names = NULL
@@ -1513,6 +1685,32 @@ get_statistic.emm_list <- function(x, ci = 0.95, adjust = "none", ...) {
 }
 
 
+#' @export
+get_statistic.ggcomparisons <- function(x, merge_parameters = FALSE, ...) {
+  if (isTRUE(merge_parameters)) {
+    params <- get_parameters(x, merge_parameters = TRUE)["Parameter"]
+  } else {
+    params <- get_parameters(x, merge_parameters = FALSE)[c("Level1", "Level2")]
+  }
+
+  stat_column <- intersect(colnames(x), c("t", "z", "Statistic"))[1]
+  stat <- x[[stat_column]]
+  if (is.null(stat)) {
+    return(NULL)
+  }
+
+  out <- data.frame(
+    params,
+    Statistic = as.vector(stat),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  out <- text_remove_backticks(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
 
 #' @export
 get_statistic.robmixglm <- function(x, ...) {
@@ -1533,8 +1731,26 @@ get_statistic.robmixglm <- function(x, ...) {
 
 
 #' @export
-get_statistic.averaging <- function(x, component = c("conditional", "full"), ...) {
-  component <- match.arg(component)
+get_statistic.hglm <- function(x, ...) {
+  s <- summary(x)$FixCoefMat
+
+  out <- data.frame(
+    Parameter = rownames(s),
+    Statistic = as.vector(s[, 3]),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  out <- out[!is.na(out$Statistic), ]
+  out <- text_remove_backticks(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
+#' @export
+get_statistic.averaging <- function(x, component = "conditional", ...) {
+  component <- match.arg(component, choices = c("conditional", "full"))
   params <- get_parameters(x, component = component)
   if (component == "full") {
     s <- summary(x)$coefmat.full
@@ -1555,7 +1771,6 @@ get_statistic.averaging <- function(x, component = c("conditional", "full"), ...
 }
 
 
-
 #' @export
 get_statistic.bayesx <- function(x, ...) {
   out <- data.frame(
@@ -1586,7 +1801,6 @@ get_statistic.Arima <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.wbm <- function(x, ...) {
   s <- summary(x)
@@ -1625,10 +1839,8 @@ get_statistic.wbm <- function(x, ...) {
 get_statistic.wbgee <- get_statistic.wbm
 
 
-
 #' @export
 get_statistic.cpglmm <- function(x, ...) {
-  # installed?
   check_if_installed("cplm")
 
   stats <- cplm::summary(x)$coefs
@@ -1655,7 +1867,7 @@ get_statistic.sem <- function(x, ...) {
   params <- get_parameters(x, effects = "fixed")
 
   if (is.null(x$se)) {
-    warning(format_message("Model has no standard errors. Please fit model again with bootstrapped standard errors."), call. = FALSE)
+    format_warning("Model has no standard errors. Please fit model again with bootstrapped standard errors.")
     return(NULL)
   }
 
@@ -1673,7 +1885,6 @@ get_statistic.sem <- function(x, ...) {
 
 #' @export
 get_statistic.cpglm <- function(x, ...) {
-  # installed?
   check_if_installed("cplm")
 
   junk <- utils::capture.output(stats <- cplm::summary(x)$coefficients) # nolint
@@ -1691,15 +1902,11 @@ get_statistic.cpglm <- function(x, ...) {
 }
 
 
-
 #' @export
-get_statistic.zcpglm <- function(x,
-                                 component = c("all", "conditional", "zi", "zero_inflated"),
-                                 ...) {
-  # installed?
+get_statistic.zcpglm <- function(x, component = "all", ...) {
   check_if_installed("cplm")
 
-  component <- match.arg(component)
+  component <- match.arg(component, choices = c("all", "conditional", "zi", "zero_inflated"))
   junk <- utils::capture.output(stats <- cplm::summary(x)$coefficients) # nolint
   params <- get_parameters(x)
 
@@ -1727,7 +1934,6 @@ get_statistic.zcpglm <- function(x,
 }
 
 
-
 #' @export
 get_statistic.manova <- function(x, ...) {
   stats <- as.data.frame(summary(x)$stats)
@@ -1744,16 +1950,15 @@ get_statistic.manova <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.maov <- function(x, ...) {
   s <- summary(x)
   out <- do.call(rbind, lapply(names(s), function(i) {
     stats <- s[[i]]
-    missing <- is.na(stats[["F value"]])
+    missing_values <- is.na(stats[["F value"]])
     data.frame(
-      Parameter = rownames(stats)[!missing],
-      Statistic = as.vector(stats[["F value"]][!missing]),
+      Parameter = rownames(stats)[!missing_values],
+      Statistic = as.vector(stats[["F value"]][!missing_values]),
       Response = gsub("\\s*Response ", "", i),
       stringsAsFactors = FALSE,
       row.names = NULL
@@ -1765,7 +1970,6 @@ get_statistic.maov <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.MANOVA <- function(x, ...) {
   stats <- as.data.frame(x$WTS)
@@ -1785,7 +1989,6 @@ get_statistic.MANOVA <- function(x, ...) {
 get_statistic.RM <- get_statistic.MANOVA
 
 
-
 #' @export
 get_statistic.rq <- function(x, ...) {
   stat <- tryCatch(
@@ -1815,16 +2018,11 @@ get_statistic.rq <- function(x, ...) {
 
 #' @export
 get_statistic.rqs <- function(x, ...) {
-  stat <- tryCatch(
-    {
-      s <- suppressWarnings(summary(x, covariance = TRUE))
-      cs <- do.call(rbind, lapply(s, stats::coef))
-      cs[, "t value"]
-    },
-    error = function(e) {
-      NULL
-    }
-  )
+  stat <- .safe({
+    s <- suppressWarnings(summary(x, covariance = TRUE))
+    cs <- do.call(rbind, lapply(s, stats::coef))
+    cs[, "t value"]
+  })
 
   params <- get_parameters(x)
 
@@ -1880,7 +2078,6 @@ get_statistic.crqs <- get_statistic.crq
 get_statistic.nlrq <- get_statistic.rq
 
 
-
 #' @export
 get_statistic.rqss <- function(x,
                                component = c("all", "conditional", "smooth_terms"),
@@ -1909,11 +2106,10 @@ get_statistic.rqss <- function(x,
 }
 
 
-
 #' @export
 get_statistic.systemfit <- function(x, ...) {
   cf <- stats::coef(summary(x))
-  f <- find_formula(x)
+  f <- find_formula(x, verbose = FALSE)
 
   system_names <- names(f)
   parameter_names <- row.names(cf)
@@ -1936,7 +2132,6 @@ get_statistic.systemfit <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.bigglm <- function(x, ...) {
   parms <- get_parameters(x)
@@ -1955,7 +2150,6 @@ get_statistic.bigglm <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.biglm <- function(x, ...) {
   parms <- get_parameters(x)
@@ -1974,7 +2168,6 @@ get_statistic.biglm <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.LORgee <- function(x, ...) {
   out <- get_statistic.default(x)
@@ -1983,7 +2176,6 @@ get_statistic.LORgee <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.crch <- function(x, ...) {
   cs <- do.call(rbind, stats::coef(summary(x), model = "full"))
@@ -2001,12 +2193,20 @@ get_statistic.crch <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.fixest <- function(x, ...) {
   cs <- summary(x)$coeftable
   params <- get_parameters(x)
 
+  # remove .theta row
+  rn <- rownames(cs)
+  if (!is.null(rn)) {
+    theta_row <- which(rn == ".theta")
+    if (length(theta_row)) {
+      cs <- cs[-theta_row, ]
+    }
+  }
+
   out <- data.frame(
     Parameter = params$Parameter,
     Statistic = as.vector(cs[, 3]),
@@ -2019,12 +2219,9 @@ get_statistic.fixest <- function(x, ...) {
 }
 
 
-
 #' @export
-get_statistic.glmx <- function(x,
-                               component = c("all", "conditional", "extra"),
-                               ...) {
-  component <- match.arg(component)
+get_statistic.glmx <- function(x, component = "all", ...) {
+  component <- match.arg(component, choices = c("all", "conditional", "extra"))
   cf <- stats::coef(summary(x))
   parms <- get_parameters(x)
 
@@ -2078,7 +2275,6 @@ get_statistic.gee <- function(x, robust = FALSE, ...) {
 }
 
 
-
 #' @export
 get_statistic.complmrob <- function(x, ...) {
   parms <- get_parameters(x)
@@ -2096,7 +2292,6 @@ get_statistic.complmrob <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.logistf <- function(x, ...) {
   parms <- get_parameters(x)
@@ -2135,7 +2330,6 @@ get_statistic.epi.2by2 <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.svyglm.nb <- function(x, ...) {
   if (!isNamespaceLoaded("survey")) {
@@ -2177,17 +2371,13 @@ get_statistic.svyglm <- function(x, ...) {
   out
 }
 
-
 #' @export
 get_statistic.svyolr <- get_statistic.svyglm
 
 
-#' @rdname get_statistic
 #' @export
-get_statistic.betareg <- function(x,
-                                  component = c("all", "conditional", "precision"),
-                                  ...) {
-  component <- match.arg(component)
+get_statistic.betareg <- function(x, component = "all", ...) {
+  component <- match.arg(component, choices = c("all", "conditional", "precision"))
   parms <- get_parameters(x)
   cs <- do.call(rbind, stats::coef(summary(x)))
   se <- as.vector(cs[, 2])
@@ -2209,13 +2399,9 @@ get_statistic.betareg <- function(x,
 }
 
 
-
-#' @rdname get_statistic
 #' @export
-get_statistic.DirichletRegModel <- function(x,
-                                            component = c("all", "conditional", "precision"),
-                                            ...) {
-  component <- match.arg(component)
+get_statistic.DirichletRegModel <- function(x, component = "all", ...) {
+  component <- match.arg(component, choices = c("all", "conditional", "precision"))
   parms <- get_parameters(x)
   junk <- utils::capture.output(cs <- summary(x)$coef.mat) # nolint
 
@@ -2227,10 +2413,10 @@ get_statistic.DirichletRegModel <- function(x,
     row.names = NULL
   )
 
-  if (!is.null(parms$Component)) {
-    out$Component <- parms$Component
-  } else {
+  if (is.null(parms$Component)) {
     component <- "all"
+  } else {
+    out$Component <- parms$Component
   }
 
   if (component != "all") {
@@ -2242,10 +2428,8 @@ get_statistic.DirichletRegModel <- function(x,
 }
 
 
-
 #' @export
 get_statistic.glimML <- function(x, ...) {
-  # installed?
   check_if_installed("aod")
 
   parms <- get_parameters(x)
@@ -2263,7 +2447,6 @@ get_statistic.glimML <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.lrm <- function(x, ...) {
   parms <- get_parameters(x)
@@ -2325,7 +2508,6 @@ get_statistic.rma <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.metaplus <- function(x, ...) {
   params <- get_parameters(x)
@@ -2347,7 +2529,6 @@ get_statistic.metaplus <- function(x, ...) {
 }
 
 
-
 #' @export
 get_statistic.bife <- function(x, ...) {
   parms <- get_parameters(x)
