@@ -224,12 +224,12 @@
   c(
     "conditional", "conditional1", "conditional2", "conditional3", "precision",
     "nonlinear", "random", "zi", "zero_inflated", "zero_inflated_random", "shape",
-    "dispersion", "instruments", "interactions", "simplex", "smooth_terms",
-    "sigma", "nu", "tau", "correlation", "slopes", "cluster", "extra", "scale",
-    "marginal", "alpha", "beta", "survival", "infrequent_purchase", "auxiliary",
-    "mix", "shiftprop", "phi", "ndt", "hu", "xi", "coi", "zoi", "aux", "dist",
-    "selection", "outcome", "time_dummies", "sigma_random", "beta_random", "car",
-    "nominal"
+    "dispersion", "dispersion_random", "instruments", "interactions", "simplex",
+    "smooth_terms", "sigma", "nu", "tau", "correlation", "slopes", "cluster",
+    "extra", "scale", "marginal", "alpha", "beta", "survival", "infrequent_purchase",
+    "auxiliary", "mix", "shiftprop", "phi", "ndt", "hu", "xi", "coi", "zoi",
+    "aux", "dist", "selection", "outcome", "time_dummies", "sigma_random",
+    "beta_random", "car", "nominal", "bidrange", "mu", "kappa", "bias"
   )
 }
 
@@ -237,14 +237,20 @@
   c(
     "sigma", "alpha", "beta", "dispersion", "precision", "nu", "tau", "shape",
     "phi", "(phi)", "ndt", "hu", "xi", "coi", "zoi", "mix", "shiftprop", "auxiliary",
-    "aux", "dist",
-
+    "aux", "dist", "mu", "kappa", "bias",
     # random parameters
-    "sigma_random", "beta_random"
+    "dispersion_random", "sigma_random", "beta_random"
   )
 }
 
-.get_elements <- function(effects, component) {
+.brms_aux_elements <- function() {
+  c(
+    "sigma", "mu", "nu", "shape", "beta", "phi", "hu", "ndt", "zoi", "coi",
+    "kappa", "bias", "bs", "zi", "alpha", "xi"
+  )
+}
+
+.get_elements <- function(effects, component, model = NULL) {
   # all elements of a model
   elements <- .all_elements()
 
@@ -255,7 +261,7 @@
   auxiliary_parameters <- .aux_elements()
 
   # random parameters
-  random_parameters <- c("random", "zero_inflated_random", "sigma_random", "beta_random", "car")
+  random_parameters <- c("random", "zero_inflated_random", "dispersion_random", "sigma_random", "beta_random", "car")
 
   # conditional component
   conditional_component <- setdiff(
@@ -280,6 +286,14 @@
     return(auxiliary_parameters)
   }
 
+  # if we have brms-models with custom formulas, we have element-names
+  # that are not covered by the standard elements. We then just do not
+  # filter elements.
+  if (inherits(model, "brmsfit") && component == "all") {
+    f <- insight::find_formula(model, verbose = FALSE)
+    elements <- unique(c(elements, names(f)))
+  }
+
   elements <- switch(effects,
     all = elements,
     fixed = elements[!elements %in% random_parameters],
@@ -356,29 +370,13 @@
 
 
 .grep_zi_smoothers <- function(x) {
-  grepl("^(s\\.\\d\\()", x, perl = TRUE) |
-    grepl("^(gam::s\\.\\d\\()", x, perl = TRUE) |
-    grepl("^(mgcv::s\\.\\d\\()", x, perl = TRUE)
+  # this one captures smoothers in zi- or mv-models from gam
+  grepl("^(s\\.\\d\\()", x) | grepl("^(gam::s\\.\\d\\()", x) | grepl("^(mgcv::s\\.\\d\\()", x)
 }
 
 
 .grep_non_smoothers <- function(x) {
-  grepl("^(?!(s\\())", x, perl = TRUE) &
-    # this one captures smoothers in zi- or mv-models from gam
-    grepl("^(?!(s\\.\\d\\())", x, perl = TRUE) &
-    grepl("^(?!(ti\\())", x, perl = TRUE) &
-    grepl("^(?!(te\\())", x, perl = TRUE) &
-    grepl("^(?!(t2\\())", x, perl = TRUE) &
-    grepl("^(?!(gam::s\\())", x, perl = TRUE) &
-    grepl("^(?!(gam::s\\.\\d\\())", x, perl = TRUE) &
-    grepl("^(?!(VGAM::s\\())", x, perl = TRUE) &
-    grepl("^(?!(mgcv::s\\())", x, perl = TRUE) &
-    grepl("^(?!(mgcv::s\\.\\d\\())", x, perl = TRUE) &
-    grepl("^(?!(mgcv::ti\\())", x, perl = TRUE) &
-    grepl("^(?!(mgcv::te\\())", x, perl = TRUE) &
-    grepl("^(?!(brms::s\\())", x, perl = TRUE) &
-    grepl("^(?!(brms::t2\\())", x, perl = TRUE) &
-    grepl("^(?!(smooth_sd\\[))", x, perl = TRUE)
+  !.grep_smoothers(x) & !.grep_zi_smoothers(x)
 }
 
 
@@ -473,14 +471,18 @@
 }
 
 
-.is_bayesian_model <- function(x) {
-  inherits(x, c(
-    "brmsfit", "stanfit", "MCMCglmm", "stanreg",
-    "stanmvreg", "bmerMod", "BFBayesFactor", "bamlss",
-    "bayesx", "mcmc", "bcplm", "bayesQR", "BGGM",
-    "meta_random", "meta_fixed", "meta_bma", "blavaan",
-    "blrm"
-  ))
+.is_bayesian_model <- function(x, exclude = NULL) {
+  bayes_classes <- c(
+    "brmsfit", "stanfit", "MCMCglmm", "stanreg", "stanmvreg", "bmerMod",
+    "BFBayesFactor", "bamlss", "bayesx", "mcmc", "bcplm", "bayesQR", "BGGM",
+    "meta_random", "meta_fixed", "meta_bma", "blavaan", "blrm", "blmerMod",
+    "bglmerMod"
+  )
+  # if exclude is not NULL, remove elements in exclude from bayes_class
+  if (!is.null(exclude)) {
+    bayes_classes <- bayes_classes[!bayes_classes %in% exclude]
+  }
+  inherits(x, bayes_classes)
 }
 
 
