@@ -8,20 +8,19 @@
 #'
 #' @return `TRUE` if `x` is a null-model, `FALSE` otherwise.
 #'
-#' @examples
+#' @examplesIf require("lme4")
 #' model <- lm(mpg ~ 1, data = mtcars)
 #' is_nullmodel(model)
 #'
 #' model <- lm(mpg ~ gear, data = mtcars)
 #' is_nullmodel(model)
 #'
-#' if (require("lme4")) {
-#'   model <- lmer(Reaction ~ 1 + (Days | Subject), data = sleepstudy)
-#'   is_nullmodel(model)
+#' data(sleepstudy, package = "lme4")
+#' model <- lme4::lmer(Reaction ~ 1 + (Days | Subject), data = sleepstudy)
+#' is_nullmodel(model)
 #'
-#'   model <- lmer(Reaction ~ Days + (Days | Subject), data = sleepstudy)
-#'   is_nullmodel(model)
-#' }
+#' model <- lme4::lmer(Reaction ~ Days + (Days | Subject), data = sleepstudy)
+#' is_nullmodel(model)
 #' @export
 is_nullmodel <- function(x) {
   UseMethod("is_nullmodel")
@@ -30,9 +29,12 @@ is_nullmodel <- function(x) {
 #' @export
 is_nullmodel.default <- function(x) {
   if (is_multivariate(x)) {
-    unlist(lapply(find_predictors(x, effects = "fixed", component = "conditional"), .check_for_nullmodel))
+    unlist(lapply(
+      find_predictors(x, effects = "fixed", component = "conditional", verbose = FALSE),
+      .check_for_nullmodel
+    ))
   } else {
-    .check_for_nullmodel(find_predictors(x, effects = "fixed", component = "conditional"))
+    .check_for_nullmodel(find_predictors(x, effects = "fixed", component = "conditional", verbose = FALSE))
   }
 }
 
