@@ -26,7 +26,6 @@ link_function <- function(x, ...) {
 }
 
 
-
 # Default method ---------------------------
 
 
@@ -36,39 +35,50 @@ link_function.default <- function(x, ...) {
     x <- x$gam
     class(x) <- c(class(x), c("glm", "lm"))
   }
-
-  tryCatch(
-    {
-      # get model family
-      ff <- .gam_family(x)
-
-      # return link function, if exists
-      if ("linkfun" %in% names(ff)) {
-        return(ff$linkfun)
-      }
-
-      # else, create link function from link-string
-      if ("link" %in% names(ff)) {
-        return(match.fun(ff$link))
-      }
-
-      NULL
-    },
-    error = function(x) {
-      NULL
-    }
-  )
+  .extract_generic_linkfun(x)
 }
 
 
+.extract_generic_linkfun <- function(x, default_link = NULL) {
+  # general approach
+  out <- .safe(stats::family(x)$linkfun)
+  # if it fails, try to retrieve from model information
+  if (is.null(out)) {
+    # get model family, consider special gam-case
+    ff <- .gam_family(x)
+    if ("linkfun" %in% names(ff)) {
+      # return link function, if exists
+      out <- ff$linkfun
+    } else if ("link" %in% names(ff) && is.character(ff$link)) {
+      # else, create link function from link-string
+      out <- .safe(stats::make.link(link = ff$link)$linkfun)
+      # or match the function - for "exp()", make.link() won't work
+      if (is.null(out)) {
+        out <- .safe(match.fun(ff$link))
+      }
+    }
+  }
+  # if all fails, force default link
+  if (is.null(out) && !is.null(default_link)) {
+    out <- switch(default_link,
+      identity = .safe(stats::gaussian(link = "identity")$linkfun),
+      .safe(stats::make.link(link = default_link)$linkfun)
+    )
+  }
+  out
+}
+
 
 # Gaussian family ------------------------------------------
 
 #' @export
 link_function.lm <- function(x, ...) {
-  stats::gaussian(link = "identity")$linkfun
+  .extract_generic_linkfun(x, "identity")
 }
 
+#' @export
+link_function.asym <- link_function.lm
+
 #' @export
 link_function.phylolm <- link_function.lm
 
@@ -171,6 +181,9 @@ link_function.RM <- link_function.lm
 #' @export
 link_function.afex_aov <- link_function.lm
 
+#' @export
+link_function.svy2lme <- link_function.lm
+
 
 # General family ---------------------------------
 
@@ -199,7 +212,7 @@ link_function.nestedLogit <- function(x, ...) {
 
 #' @export
 link_function.multinom <- function(x, ...) {
-  stats::make.link(link = "logit")$linkfun
+  .extract_generic_linkfun(x, "logit")
 }
 
 #' @export
@@ -262,6 +275,14 @@ link_function.riskRegression <- link_function.multinom
 #' @export
 link_function.comprisk <- link_function.multinom
 
+#' @export
+link_function.multinom_weightit <- function(x, ...) {
+  stats::make.link(link = x$family$link)$linkfun
+}
+
+#' @export
+link_function.ordinal_weightit <- link_function.multinom_weightit
+
 
 # Phylo glm ------------------------
 
@@ -298,7 +319,6 @@ link_function.hurdle <- link_function.zeroinfl
 link_function.zerotrunc <- link_function.zeroinfl
 
 
-
 # Tobit links ---------------------------------
 
 #' @export
@@ -345,8 +365,10 @@ link_function.clm2 <- link_function.clm
 link_function.clmm <- link_function.clm
 
 #' @export
-link_function.mixor <- link_function.clm
+link_function.serp <- link_function.clm
 
+#' @export
+link_function.mixor <- link_function.clm
 
 
 # mfx models ------------------------------------------------------
@@ -398,6 +420,20 @@ link_function.Rchoice <- function(x, ...) {
 }
 
 
+#' @export
+link_function.oohbchoice <- function(x, ...) {
+  link <- switch(x$distribution,
+    normal = "identity",
+    weibull = ,
+    "log-normal" = "log",
+    logistic = ,
+    ## TODO: not sure about log-logistic link-inverse
+    "log-logistic" = "logit"
+  )
+  stats::make.link(link = link)$linkfun
+}
+
+
 #' @export
 link_function.merModList <- function(x, ...) {
   link_function.default(x[[1]], ...)
@@ -413,7 +449,6 @@ link_function.mipo <- function(x, ...) {
 
 #' @export
 link_function.mira <- function(x, ...) {
-  # installed?
   check_if_installed("mice")
   link_function(mice::pool(x), ...)
 }
@@ -468,13 +503,12 @@ link_function.cglm <- function(x, ...) {
   method <- parse(text = safe_deparse(x$call))[[1]]$method
 
   if (!is.null(method) && method == "clm") {
-    link <- "identiy"
+    link <- "identity"
   }
   stats::make.link(link = link)$linkfun
 }
 
 
-
 #' @export
 link_function.fixest <- function(x, ...) {
   if (is.null(x$family)) {
@@ -509,6 +543,9 @@ link_function.bife <- function(x, ...) {
   x$family$linkfun
 }
 
+#' @export
+link_function.glmgee <- link_function.bife
+
 
 #' @export
 link_function.cpglmm <- function(x, ...) {
@@ -528,28 +565,7 @@ link_function.bcplm <- link_function.cpglmm
 
 #' @export
 link_function.gam <- function(x, ...) {
-  lf <- tryCatch(
-    {
-      # get model family
-      ff <- .gam_family(x)
-
-      # return link function, if exists
-      if ("linkfun" %in% names(ff)) {
-        return(ff$linkfun)
-      }
-
-      # else, create link function from link-string
-      if ("link" %in% names(ff)) {
-        return(match.fun(ff$link))
-      }
-
-      NULL
-    },
-    error = function(x) {
-      NULL
-    }
-  )
-
+  lf <- .extract_generic_linkfun(x)
   if (is.null(lf)) {
     mi <- .gam_family(x)
     if (object_has_names(mi, "linfo")) {
@@ -565,21 +581,18 @@ link_function.gam <- function(x, ...) {
 }
 
 
-
 #' @export
 link_function.glimML <- function(x, ...) {
   stats::make.link(link = x@link)$linkfun
 }
 
 
-
 #' @export
 link_function.glmmadmb <- function(x, ...) {
   x$linkfun
 }
 
 
-
 #' @export
 link_function.glmm <- function(x, ...) {
   switch(tolower(x$family.glmm$family.glmm),
@@ -591,23 +604,26 @@ link_function.glmm <- function(x, ...) {
 }
 
 
-
 #' @rdname link_function
 #' @export
 link_function.gamlss <- function(x, what = c("mu", "sigma", "nu", "tau"), ...) {
   what <- match.arg(what)
   faminfo <- get(x$family[1], asNamespace("gamlss"))()
-  switch(what,
-    mu = faminfo$mu.linkfun,
-    sigma = faminfo$sigma.linkfun,
-    nu = faminfo$nu.linkfun,
-    tau = faminfo$tau.linkfun,
-    faminfo$mu.linkfun
-  )
+  # exceptions
+  if (faminfo$family[1] == "LOGNO") {
+    function(mu) log(mu)
+  } else {
+    switch(what,
+      mu = faminfo$mu.linkfun,
+      sigma = faminfo$sigma.linkfun,
+      nu = faminfo$nu.linkfun,
+      tau = faminfo$tau.linkfun,
+      faminfo$mu.linkfun
+    )
+  }
 }
 
 
-
 #' @export
 link_function.gamm <- function(x, ...) {
   x <- x$gam
@@ -616,7 +632,6 @@ link_function.gamm <- function(x, ...) {
 }
 
 
-
 #' @export
 link_function.bamlss <- function(x, ...) {
   flink <- stats::family(x)$links[1]
@@ -627,7 +642,6 @@ link_function.bamlss <- function(x, ...) {
 }
 
 
-
 #' @export
 link_function.LORgee <- function(x, ...) {
   if (grepl(pattern = "logit", x = x$link, fixed = TRUE)) {
@@ -646,7 +660,6 @@ link_function.LORgee <- function(x, ...) {
 }
 
 
-
 #' @export
 link_function.vgam <- function(x, ...) {
   x@family@linkfun
@@ -689,7 +702,6 @@ link_function.svyolr <- function(x, ...) {
 }
 
 
-
 #' @rdname link_function
 #' @export
 link_function.betareg <- function(x, what = c("mean", "precision"), ...) {
@@ -701,7 +713,6 @@ link_function.betareg <- function(x, what = c("mean", "precision"), ...) {
 }
 
 
-
 #' @rdname link_function
 #' @export
 link_function.DirichletRegModel <- function(x, what = c("mean", "precision"), ...) {
@@ -717,7 +728,6 @@ link_function.DirichletRegModel <- function(x, what = c("mean", "precision"), ..
 }
 
 
-
 #' @export
 link_function.gbm <- function(x, ...) {
   switch(x$distribution$name,
@@ -733,7 +743,6 @@ link_function.gbm <- function(x, ...) {
 }
 
 
-
 #' @export
 link_function.stanmvreg <- function(x, ...) {
   fam <- stats::family(x)
@@ -741,7 +750,6 @@ link_function.stanmvreg <- function(x, ...) {
 }
 
 
-
 #' @export
 link_function.brmsfit <- function(x, ...) {
   fam <- stats::family(x)
@@ -760,16 +768,13 @@ link_function.brmsfit <- function(x, ...) {
   # do we have custom families?
   if (!is.null(fam$family) && (is.character(fam$family) && fam$family == "custom")) {
     il <- stats::make.link(fam$link)$linkfun
+  } else if ("linkfun" %in% names(fam)) {
+    il <- fam$linkfun
+  } else if ("link" %in% names(fam) && is.character(fam$link)) {
+    il <- stats::make.link(fam$link)$linkfun
   } else {
-    if ("linkfun" %in% names(fam)) {
-      il <- fam$linkfun
-    } else if ("link" %in% names(fam) && is.character(fam$link)) {
-      il <- stats::make.link(fam$link)$linkfun
-    } else {
-      ff <- get(fam$family, asNamespace("stats"))
-      il <- ff(fam$link)$linkfun
-    }
+    ff <- get(fam$family, asNamespace("stats"))
+    il <- ff(fam$link)$linkfun
   }
-
   il
 }
