@@ -334,7 +334,9 @@
 
   # do we have duplicated names?
   dupes <- which(duplicated(cvn))
-  if (!.is_empty_string(dupes)) cvn[dupes] <- sprintf("%s.%s", cvn[dupes], seq_along(dupes))
+  if (!.is_empty_string(dupes)) {
+    cvn[dupes] <- sprintf("%s.%s", cvn[dupes], seq_along(dupes))
+  }
 
   colnames(mf) <- cvn
 
@@ -382,10 +384,6 @@
 }
 
 
-
-
-
-
 # add remainng variables with special pattern -------------------------------
 
 .add_remaining_missing_variables <- function(model,
@@ -398,10 +396,10 @@
                                              verbose = TRUE) {
   # check if data argument was used
   model_call <- get_call(model)
-  if (!is.null(model_call)) {
-    data_arg <- .safe(parse(text = safe_deparse(model_call))[[1]]$data)
-  } else {
+  if (is.null(model_call)) {
     data_arg <- NULL
+  } else {
+    data_arg <- .safe(parse(text = safe_deparse(model_call))[[1]]$data)
   }
 
   # do we have variable names like "mtcars$mpg"?
@@ -494,10 +492,6 @@
 }
 
 
-
-
-
-
 # combine data from different model components -------------------------------
 
 # This helper functions ensures that data from different model components
@@ -564,14 +558,14 @@
     random.component.data <- .remove_values(random.component.data, c(1, 0))
   }
 
-  weights <- find_weights(x)
-  # if (!is.null(weights) && "(weights)" %in% colnames(mf)) {
-  #   weights <- c(weights, "(weights)")
+  model_weights <- find_weights(x)
+  # if (!is.null(model_weights) && "(weights)" %in% colnames(mf)) {
+  #   model_weights <- c(model_weights, "(weights)")
   # }
 
   vars <- switch(effects,
-    all = unique(c(response, fixed.component.data, random.component.data, weights)),
-    fixed = unique(c(response, fixed.component.data, weights)),
+    all = unique(c(response, fixed.component.data, random.component.data, model_weights)),
+    fixed = unique(c(response, fixed.component.data, model_weights)),
     random = unique(random.component.data)
   )
 
@@ -606,9 +600,6 @@
 }
 
 
-
-
-
 # find zi-data -----------------------------------
 
 # this function tries to get the data from variables from the zero-inflated
@@ -628,8 +619,6 @@
 }
 
 
-
-
 # special model handling -----------------------------------
 
 .get_zelig_relogit_frame <- function(x) {
@@ -638,8 +627,6 @@
 }
 
 
-
-
 # combine data from count and zi-component -----------------------------------
 
 .return_zeroinf_data <- function(x, component, verbose = TRUE) {
@@ -662,8 +649,6 @@
 }
 
 
-
-
 # "clean" model frame and get data -----------------------------------
 
 # here we have a model frame with many variables, so just extract the important ones...
@@ -687,8 +672,6 @@
 }
 
 
-
-
 # find start vector of nlmer-models from the environment -----------------------------------
 
 # return data from a data frame that is in the environment,
@@ -702,9 +685,6 @@
 }
 
 
-
-
-
 # backtransform variables -------------------------------
 
 .backtransform <- function(mf, x) {
@@ -739,7 +719,7 @@
   cn <- .get_transformed_names(colnames(mf), type)
   if (!.is_empty_string(cn)) {
     for (i in cn) {
-      if (type == "scale\\(log") {
+      if (type == "scale\\(log") { # nolint
         mf[[i]] <- exp(.unscale(mf[[i]]))
       } else if (type == "exp\\(scale") {
         mf[[i]] <- .unscale(log(mf[[i]]))
@@ -786,7 +766,6 @@
 }
 
 
-
 .unscale <- function(x) {
   m <- attr(x, "scaled:center")
   s <- attr(x, "scaled:scale")
@@ -798,7 +777,6 @@
 }
 
 
-
 # find transformed terms, to convert back as raw data --------------------------------
 
 # Find transformed terms inside model formula, and return "clean" term names
@@ -873,15 +851,11 @@
           (startsWith(x$method, "McNemar") || (length(columns) == 1 && is.matrix(columns[[1]])))) {
           # McNemar: preserve table data for McNemar ----
           return(as.table(columns[[1]]))
-
-          # Kruskal Wallis ====================================================
         } else if (startsWith(x$method, "Kruskal-Wallis") && length(columns) == 1 && is.list(columns[[1]])) {
           # Kruskal-Wallis: check if data is a list for kruskal-wallis ----
           l <- columns[[1]]
           names(l) <- paste0("x", seq_along(l))
           return(l)
-
-          # t-tests ===========================================================
         } else if (grepl("t-test", x$method, fixed = TRUE)) {
           # t-Test: (Welch) Two Sample t-test ----
           if (grepl("Two", x$method, fixed = TRUE)) {
@@ -908,9 +882,8 @@
           } else {
             d <- .htest_other_format(columns)
           }
-
-          # Wilcoxon ========================================================
         } else if (startsWith(x$method, "Wilcoxon rank sum")) {
+          # Wilcoxon ========================================================
           if (grepl(" by ", x$data.name, fixed = TRUE)) {
             # Wilcoxon: Paired Wilcoxon, formula (no reshape required) ----
             return(.htest_no_reshape(columns))
@@ -932,7 +905,6 @@
           }
         } else {
           # Other htests ======================================================
-
           d <- .htest_other_format(columns)
         }
 
