@@ -28,7 +28,7 @@
   # poisson family --------
 
   poisson_fam <-
-    fitfam %in% c("poisson", "quasipoisson", "genpois", "ziplss") |
+    fitfam %in% c("poisson", "quasipoisson", "genpois", "ziplss", "bell") |
       grepl("poisson", fitfam_lower, fixed = TRUE)
 
 
@@ -49,23 +49,37 @@
 
   is_bernoulli <- FALSE
 
-  if (binom_fam && inherits(x, "glm") && !neg_bin_fam && !poisson_fam) {
+  # These models can be logistic regresion models with bernoulli outcome
+  potential_bernoulli <- inherits(
+    x,
+    c(
+      "glm", "gee", "glmmTMB", "glmerMod", "merMod", "stanreg", "MixMod",
+      "logistf", "bigglm", "brglm", "feglm", "geeglm", "glmm", "glmmadmb",
+      "glmmPQL", "glmrob", "glmRob", "logitmfx", "logitor", "logitr",
+      "mixed", "mixor", "svyglm", "glmgee"
+    )
+  )
+
+  if (binom_fam && potential_bernoulli && !neg_bin_fam && !poisson_fam) {
     if (inherits(x, "gee")) {
       resp <- .safe(get_response(x))
     } else {
       resp <- .safe(stats::model.response(stats::model.frame(x)))
     }
-    if (!is.null(resp)) {
+    if (is.null(resp)) {
+      is_bernoulli <- TRUE
+    } else {
       if ((is.data.frame(resp) || is.matrix(resp)) && ncol(resp) == 1) {
         resp <- as.vector(resp[[1]])
       }
-      if (!is.data.frame(resp) && !is.matrix(resp) && all(.is.int(.factor_to_numeric(resp[[1]])))) {
-        is_bernoulli <- TRUE
+      if (!is.data.frame(resp) && !is.matrix(resp)) {
+        if (is.list(resp)) {
+          resp <- resp[[1]]
+        }
+        is_bernoulli <- all(.is_integer(.factor_to_numeric(resp)))
       }
-    } else {
-      is_bernoulli <- TRUE
     }
-  } else if (fitfam %in% "bernoulli") {
+  } else if (all(fitfam == "bernoulli")) {
     is_bernoulli <- TRUE
   }
 
@@ -73,7 +87,7 @@
   # beta family --------
 
   beta_fam <-
-    inherits(x, c("betareg", "betamfx")) |
+    inherits(x, c("betareg", "betamfx", "ordbetareg")) |
       fitfam %in% c(
         "beta",
         "Beta",
@@ -81,14 +95,16 @@
         "Beta Inflated",
         "Zero Inflated Beta",
         "Beta Inflated zero",
-        "Beta Inflated one"
+        "Beta Inflated one",
+        "ordbeta"
       )
 
 
-  # special families (beta-binomial, dirichlet) --------
+  # special families (beta-binomial, dirichlet, ordered beta) --------
 
-  betabin_fam <- inherits(x, "BBreg") | fitfam %in% "betabinomial"
-  dirichlet_fam <- inherits(x, "DirichletRegModel") | fitfam %in% "dirichlet"
+  betabin_fam <- inherits(x, "BBreg") | any(fitfam == "betabinomial")
+  orderedbeta_fam <- any(fitfam == "ordbeta") | inherits(x, "ordbetareg")
+  dirichlet_fam <- inherits(x, "DirichletRegModel") | any(fitfam == "dirichlet")
 
   ## TODO beta-binomial = binomial?
   if (betabin_fam) binom_fam <- TRUE
@@ -128,14 +144,14 @@
   # ordinal family --------
 
   is.ordinal <-
-    inherits(x, c("svyolr", "polr", "clm", "clm2", "clmm", "mixor", "LORgee", "mvord")) |
+    inherits(x, c("svyolr", "polr", "serp", "clm", "clm2", "clmm", "mixor", "LORgee", "mvord", "ordinal_weightit")) |
       fitfam %in% c("cumulative", "ordinal")
 
 
   # multinomial family --------
 
   is.multinomial <-
-    inherits(x, c("gmnl", "mclogit", "mblogit", "mmclogit", "mlogit", "DirichletRegModel", "multinom", "brmultinom")) |
+    inherits(x, c("gmnl", "mclogit", "mblogit", "mmclogit", "mlogit", "DirichletRegModel", "multinom", "brmultinom", "multinom_weightit")) |
       fitfam %in% c("cratio", "sratio", "acat", "multinom", "multinomial", "multinomial2", "dirichlet")
 
 
@@ -152,6 +168,7 @@
       binom_fam <- TRUE
     } else {
       is.ordinal <- TRUE
+      is_bernoulli <- FALSE
     }
   }
 
@@ -211,35 +228,6 @@
     )
   }
 
-
-  # save model terms --------
-
-  # drop this for now...
-
-  # if (isTRUE(dots$no_terms)) {
-  #   model_terms <- NULL
-  # } else {
-  #   if (inherits(x, "mcmc")) {
-  #     model_terms <- find_parameters(x)
-  #   } else {
-  #     model_terms <- tryCatch(
-  #       {
-  #         find_variables(
-  #           x,
-  #           effects = "all",
-  #           component = "all",
-  #           flatten = FALSE,
-  #           verbose = FALSE
-  #         )
-  #       },
-  #       error = function(x) {
-  #         NULL
-  #       }
-  #     )
-  #   }
-  # }
-
-
   # significance tests --------
 
   is_ftest <- FALSE
@@ -357,7 +345,7 @@
     dirichlet_fam || is.ordinal || zero.inf || is.censored || is.survival || is_binomtest ||
     is.categorical || hurdle || is.multinomial || is_chi2test || is_proptest || is_xtab) {
     linear_model <- FALSE
-  } else if (!(fitfam %in% c("Student's-t", "t Family", "gaussian", "Gaussian")) && !grepl("(\\st)$", fitfam)) {
+  } else if (!(fitfam %in% c("Student's-t", "t Family", "gaussian", "Gaussian", "lognormal", "skewnormal")) && !grepl("(\\st)$", fitfam)) {
     linear_model <- FALSE
   }
   if (!linear_model && is.survival && fitfam == "gaussian") {
@@ -393,6 +381,7 @@
     is_negbin = neg_bin_fam,
     is_beta = beta_fam,
     is_betabinomial = betabin_fam,
+    is_orderedbeta = orderedbeta_fam,
     is_dirichlet = dirichlet_fam,
     is_exponential = exponential_fam,
     is_logit = logit.link,
@@ -436,6 +425,7 @@
   )
 }
 
+
 .get_ordinal_link <- function(x) {
   switch(x$link,
     logistic = "logit",
@@ -445,15 +435,15 @@
 }
 
 
-.make_tobit_family <- function(x, dist = NULL) {
-  if (is.null(dist)) {
+.make_tobit_family <- function(x, distribution = NULL) {
+  if (is.null(distribution)) {
     if (inherits(x, "flexsurvreg")) {
-      dist <- parse(text = safe_deparse(x$call))[[1]]$dist
+      distribution <- parse(text = safe_deparse(x$call))[[1]]$dist
     } else {
-      dist <- x$dist
+      distribution <- x$dist
     }
   }
-  f <- switch(dist,
+  f <- switch(distribution,
     gaussian = stats::gaussian("identity"),
     logistic = stats::binomial("logit"),
     llogis = ,
@@ -470,13 +460,12 @@
     stats::gaussian("identity")
   )
 
-  if (dist == "weibull") f$family <- "weibull"
+  if (distribution == "weibull") f$family <- "weibull"
   f
 }
 
 
 .classify_BFBayesFactor <- function(x) {
-  # installed?
   check_if_installed("BayesFactor")
 
   if (inherits(x@denominator, "BFcorrelation")) {
@@ -499,7 +488,6 @@
 }
 
 
-
 .is_semLme <- function(x) {
   all(inherits(x, c("sem", "lme")))
 }
