@@ -1,6 +1,7 @@
 skip_if_offline()
 skip_if_not_installed("GLMMadaptive")
 skip_if_not_installed("lme4")
+skip_if_not_installed("httr2")
 
 m <- download_model("GLMMadaptive_zi_2")
 m2 <- download_model("GLMMadaptive_zi_1")
@@ -28,7 +29,7 @@ test_that("model_info", {
 test_that("get_deviance + logLik", {
   expect_equal(get_deviance(m3), 183.96674, tolerance = 1e-3)
   expect_equal(get_loglikelihood(m3), logLik(m3), tolerance = 1e-3, ignore_attr = TRUE)
-  expect_equal(get_df(m3, type = "model"), 5)
+  expect_identical(get_df(m3, type = "model"), 5L)
 })
 
 test_that("get_df", {
@@ -50,10 +51,10 @@ test_that("get_df", {
 })
 
 test_that("n_parameters", {
-  expect_equal(n_parameters(m), 6)
-  expect_equal(n_parameters(m2), 6)
-  expect_equal(n_parameters(m, effects = "random"), 2)
-  expect_equal(n_parameters(m2, effects = "random"), 1)
+  expect_identical(n_parameters(m), 6L)
+  expect_identical(n_parameters(m2), 6L)
+  expect_identical(n_parameters(m, effects = "random"), 2L)
+  expect_identical(n_parameters(m2, effects = "random"), 1L)
 })
 
 test_that("find_predictors", {
@@ -273,7 +274,7 @@ test_that("get_data", {
 })
 
 test_that("find_parameter", {
-  expect_equal(
+  expect_identical(
     find_parameters(m),
     list(
       conditional = c("(Intercept)", "child", "camper1"),
@@ -282,7 +283,7 @@ test_that("find_parameter", {
       zero_inflated_random = "zi_(Intercept)"
     )
   )
-  expect_equal(
+  expect_identical(
     find_parameters(m2),
     list(
       conditional = c("(Intercept)", "child", "camper1"),
@@ -290,7 +291,7 @@ test_that("find_parameter", {
       zero_inflated = c("(Intercept)", "child", "livebait1")
     )
   )
-  expect_equal(
+  expect_identical(
     find_parameters(m3),
     list(
       conditional = c("(Intercept)", "period2", "period3", "period4"),
@@ -298,7 +299,7 @@ test_that("find_parameter", {
     )
   )
 
-  expect_equal(nrow(get_parameters(m)), 6)
+  expect_identical(nrow(get_parameters(m)), 6L)
   expect_equal(
     get_parameters(m, effects = "random"),
     list(
@@ -307,14 +308,14 @@ test_that("find_parameter", {
     ),
     tolerance = 1e-5
   )
-  expect_equal(nrow(get_parameters(m2)), 6)
+  expect_identical(nrow(get_parameters(m2)), 6L)
   expect_equal(get_parameters(m2, effects = "random"),
     list(random = c(
       -1.3262364, -0.2048055, 1.3852572, 0.5282277
     )),
     tolerance = 1e-5
   )
-  expect_equal(
+  expect_identical(
     get_parameters(m3)$Component,
     c(
       "conditional",
@@ -337,8 +338,118 @@ test_that("is_multivariate", {
 })
 
 test_that("find_algorithm", {
-  expect_equal(
+  expect_identical(
     find_algorithm(m),
     list(algorithm = "quasi-Newton", optimizer = "optim")
   )
 })
+
+test_that("detect custom families", {
+  skip_on_cran()
+  set.seed(1234)
+  n <- 100 # number of subjects
+  K <- 8 # number of measurements per subject
+  t_max <- 5 # maximum follow-up time
+
+  # we construct a data frame with the design:
+  # everyone has a baseline measurement, and then measurements at random follow-up times
+  DF <- data.frame(
+    id = rep(seq_len(n), each = K),
+    time = as.vector(replicate(n, c(0, sort(runif(K - 1, 0, t_max))))),
+    sex = rep(gl(2, n / 2, labels = c("male", "female")), each = K)
+  )
+
+  # design matrices for the fixed and random effects non-zero part
+  X <- model.matrix(~ sex * time, data = DF)
+  Z <- model.matrix(~time, data = DF)
+  # design matrices for the fixed and random effects zero part
+  X_zi <- model.matrix(~sex, data = DF)
+  Z_zi <- model.matrix(~1, data = DF)
+
+  betas <- c(-2.13, -0.25, 0.24, -0.05) # fixed effects coefficients non-zero part
+  sigma <- 0.5 # standard deviation error terms non-zero part
+  gammas <- c(-1.5, 0.5) # fixed effects coefficients zero part
+  D11 <- 0.5 # variance of random intercepts non-zero part
+  D22 <- 0.1 # variance of random slopes non-zero part
+  D33 <- 0.4 # variance of random intercepts zero part
+
+  # we simulate random effects
+  b <- cbind(rnorm(n, sd = sqrt(D11)), rnorm(n, sd = sqrt(D22)), rnorm(n, sd = sqrt(D33)))
+  # linear predictor non-zero part
+  eta_y <- as.vector(X %*% betas + rowSums(Z * b[DF$id, 1:2, drop = FALSE]))
+  # linear predictor zero part
+  eta_zi <- as.vector(X_zi %*% gammas + rowSums(Z_zi * b[DF$id, 3, drop = FALSE]))
+  # we simulate log-normal longitudinal data
+  DF$y <- exp(rnorm(n * K, mean = eta_y, sd = sigma))
+  # we set the zeros from the logistic regression
+  DF$y[as.logical(rbinom(n * K, size = 1, prob = plogis(eta_zi)))] <- 0
+
+  hurdle.lognormal <- function() {
+    stats <- make.link("identity")
+    log_dens <- function(y, eta, mu_fun, phis, eta_zi) {
+      scaleParameter <- exp(phis)
+      # binary indicator for y > 0
+      ind <- y > 0
+      # non-zero part
+      eta <- as.matrix(eta)
+      eta_zi <- as.matrix(eta_zi)
+      out <- eta
+      out[ind, ] <- plogis(eta_zi[ind, ], lower.tail = FALSE, log.p = TRUE) +
+        dnorm(x = log(y[ind]), mean = eta[ind, ], sd = scaleParameter, log = TRUE)
+      # zero part
+      out[!ind, ] <- plogis(eta_zi[!ind, ], log.p = TRUE)
+      attr(out, "mu_y") <- eta
+      out
+    }
+    score_eta_fun <- function(y, mu, phis, eta_zi) {
+      scaleParameter <- exp(phis)
+      # binary indicator for y > 0
+      ind <- y > 0
+      # non-zero part
+      eta <- as.matrix(mu)
+      out <- eta
+      out[!ind, ] <- 0
+      out[ind, ] <- (log(y[ind]) - eta[ind, ]) / scaleParameter^2
+      out
+    }
+    score_eta_zi_fun <- function(y, mu, phis, eta_zi) {
+      ind <- y > 0
+      probs <- plogis(as.matrix(eta_zi))
+      out <- 1 - probs
+      out[ind, ] <- -probs[ind, ]
+      out
+    }
+    score_phis_fun <- function(y, mu, phis, eta_zi) {
+      scaleParameter <- exp(phis)
+      # binary indicator for y > 0
+      ind <- y > 0
+      # non-zero part
+      eta <- as.matrix(mu)
+      out <- eta
+      out[!ind, ] <- 0
+      out[ind, ] <- -1 + (log(y[ind]) - eta[ind, ])^2 / scaleParameter^2
+      out
+    }
+    simulateResponses <- function(n, mu, phis, eta_zi) {
+      y <- rlnorm(n = n, meanlog = mu, sdlog = exp(phis))
+      y[as.logical(rbinom(n, 1, plogis(eta_zi)))] <- 0
+      y
+    }
+    structure(
+      list(
+        family = "two-part log-normal", link = stats$name,
+        linkfun = stats$linkfun, linkinv = stats$linkinv, log_dens = log_dens,
+        score_eta_fun = score_eta_fun, score_eta_zi_fun = score_eta_zi_fun,
+        score_phis_fun = score_phis_fun, simulate = simulateResponses
+      ),
+      class = "family"
+    )
+  }
+  km1 <- GLMMadaptive::mixed_model(y ~ sex * time,
+    random = ~ 1 | id, data = DF,
+    family = hurdle.lognormal(), n_phis = 1,
+    zi_fixed = ~sex
+  )
+  out <- model_info(km1)
+  expect_true(out$is_zero_inflated)
+})
