@@ -69,12 +69,10 @@ test_that("afex_aov: afex", {
   expect_true(unique(sapply(mods, is_model)))
   expect_true(unique(sapply(mods, is_model_supported)))
   expect_false(unique(sapply(mods, is_gam_model)))
-  # expect_false(unique(sapply(mods, is_multivariate)))
   expect_false(unique(sapply(mods, is_nullmodel)))
 
-  # expect_equal(get_family(Mc2), gaussian())
-  expect_equal(link_function(Mc2), gaussian()$linkfun)
-  expect_equal(link_inverse(Mc2), gaussian()$linkinv)
+  expect_equal(link_function(Mc2), gaussian()$linkfun, ignore_attr = TRUE)
+  expect_equal(link_inverse(Mc2), gaussian()$linkinv, ignore_attr = TRUE)
 })
 
 test_that("afex_aov: model values", {
@@ -90,7 +88,7 @@ test_that("afex_aov: model values", {
   )
   expect_equal(
     sapply(mods, get_loglikelihood),
-    c(-411.04, -414.088, -431.688, -22.295, -517.397),
+    c(-405.34037, -408.37849, -420.51277, -22.29462, -508.05184),
     tolerance = 0.01
   )
   expect_equal(
