@@ -2,6 +2,7 @@ skip_on_cran()
 skip_if_offline()
 skip_on_os("mac")
 skip_if_not_installed("brms")
+skip_if_not_installed("httr2")
 
 # Model fitting -----------------------------------------------------------
 
@@ -512,7 +513,6 @@ test_that("find_algorithm", {
   )
 })
 
-
 test_that("get_priors", {
   expect_equal(
     get_priors(m7),
@@ -880,3 +880,83 @@ test_that("clean_parameters", {
     ignore_attr = TRUE
   )
 })
+
+test_that("get_modelmatrix", {
+  out <- get_modelmatrix(m1)
+  expect_identical(dim(out), c(236L, 4L))
+  m9 <- suppressWarnings(insight::download_model("brms_mo2"))
+  skip_if(is.null(m9))
+  out <- get_modelmatrix(m9)
+  expect_identical(dim(out), c(32L, 2L))
+})
+
+test_that("get_modelmatrix", {
+  m10 <- suppressWarnings(insight::download_model("brms_lf_1"))
+  expect_identical(
+    find_variables(m10),
+    list(
+      response = "carb",
+      conditional = c("gear", "vs"), disc = c("disc", "cyl")
+    )
+  )
+})
+
+# get variance
+test_that("get_variance works", {
+  mdl <- suppressWarnings(insight::download_model("brms_mixed_9"))
+  out <- get_variance(mdl)
+  expect_equal(
+    out,
+    list(
+      var.fixed = 4.91103174480995,
+      var.random = 22.4069708072874,
+      var.residual = 10.9304525807216,
+      var.distribution = 10.9304525807216,
+      var.dispersion = 0,
+      var.intercept = c(cyl = 22.4069708072874)
+    ),
+    tolerance = 1e-3,
+    ignore_attr = TRUE
+  )
+  # make sure it's a matrix
+  # expect_true(is.matrix(get_modelmatrix(null_model(mdl))))
+})
+
+
+# get variance
+test_that("get_variance aligns with get_sigma", {
+  skip_if_not_installed("lme4")
+  data(mtcars)
+  set.seed(123)
+  mdl <- suppressWarnings(insight::download_model("brms_mixed_9"))
+  VC <- lme4::VarCorr(mdl)
+  out1 <- VC$residual__$sd[1, 1]^2 # Residual variance
+  out2 <- get_variance(mdl)$var.residual
+  out3 <- get_sigma(mdl)^2
+  expect_equal(out1, out2, tolerance = 1e-3, ignore_attr = TRUE)
+  expect_equal(out1, out3, tolerance = 1e-3, ignore_attr = TRUE)
+  expect_equal(out2, out3, tolerance = 1e-3, ignore_attr = TRUE)
+})
+
+
+# get variance
+test_that("get_variance works when sigma is modeled", {
+  data(mtcars)
+  set.seed(123)
+  m <- insight::download_model("brms_sigma_1")
+  expect_message(
+    {
+      out <- get_variance(m)
+    },
+    regex = "modeled directly"
+  )
+  expect_equal(
+    out,
+    list(
+      var.fixed = 2.712739833628, var.random = 25.6254745619452,
+      var.dispersion = 0, var.intercept = c(cyl = 25.6254745619452)
+    ),
+    ignore_attr = TRUE,
+    tolerance = 1e-3
+  )
+})
