@@ -1,5 +1,4 @@
 skip_on_os("mac") # error: FreeADFunObject
-skip_if_not(getRversion() >= "4.0.0")
 skip_if_not_installed("TMB")
 skip_if_not_installed("glmmTMB")
 
@@ -617,7 +616,7 @@ test_that("get_data", {
   expect_null(get_data(m4, component = "disp", effects = "random", verbose = FALSE))
 })
 
-test_that("find_paramaters", {
+test_that("find_parameters", {
   expect_identical(
     find_parameters(m4),
     list(
@@ -685,7 +684,7 @@ test_that("find_paramaters", {
 })
 
 
-test_that("get_paramaters", {
+test_that("get_parameters", {
   expect_identical(nrow(get_parameters(m4)), 6L)
   expect_identical(
     colnames(get_parameters(m4)),
@@ -880,7 +879,9 @@ d2$sd <- "five"
 dat <- rbind(d1, d2)
 m0 <- glmmTMB::glmmTMB(x ~ sd + (1 | t), dispformula = ~sd, data = dat)
 
-test_that("get_paramaters", {
+
+test_that("get_parameters", {
+  skip_if_not_installed("glmmTMB", minimum_version = "1.1.9")
   expect_identical(nrow(get_parameters(m0)), 4L)
   expect_identical(
     colnames(get_parameters(m0)),
@@ -897,7 +898,7 @@ test_that("get_paramaters", {
   )
   expect_equal(
     get_parameters(m0)$Estimate,
-    c(200.03431, -99.71491, 3.20287, 1.38648),
+    c(200.03431, -99.71491, 1.6014, 0.69323),
     tolerance = 1e-3
   )
   expect_identical(
@@ -972,7 +973,6 @@ test_that("model_info, ordered beta", {
 
 
 test_that("model_info, recognize ZI even without ziformula", {
-  skip_if_not_installed("glmmTMB")
   data("fish", package = "insight")
   fish$count <- fish$count + 1
   m1 <- glmmTMB::glmmTMB(
@@ -1007,3 +1007,72 @@ test_that("model_info, recognize ZI even without ziformula", {
 #     expect_equal(out$var.distribution, 1.44250604187634, tolerance = 1e-4)
 #   })
 # )
+
+test_that("get/find_parameters with dispersion-random", {
+  skip_if_not_installed("glmmTMB", minimum_version = "1.1.10")
+  data(Salamanders, package = "glmmTMB")
+  m <- glmmTMB::glmmTMB(
+    count ~ spp + cover + mined + (1 | site),
+    ziformula = ~ spp + mined,
+    dispformula = ~ DOY + (1 | site),
+    data = Salamanders,
+    family = glmmTMB::nbinom2
+  )
+  out <- get_parameters(m)
+  expect_identical(nrow(out), 19L)
+  out <- get_parameters(m, effects = "random")
+  expect_length(out, 2)
+  expect_named(out, c("random", "dispersion_random"))
+
+  expect_equal(
+    find_parameters(m),
+    list(
+      conditional = c(
+        "(Intercept)", "sppPR", "sppDM", "sppEC-A",
+        "sppEC-L", "sppDES-L", "sppDF", "cover", "minedno"
+      ),
+      random = list(site = "(Intercept)"),
+      zero_inflated = c(
+        "(Intercept)", "sppPR",
+        "sppDM", "sppEC-A", "sppEC-L", "sppDES-L", "sppDF", "minedno"
+      ),
+      dispersion = c("(Intercept)", "DOY"),
+      dispersion_random = "site"
+    ),
+    ignore_attr = TRUE
+  )
+  expect_equal(
+    find_parameters(m, effects = "fixed"),
+    list(
+      conditional = c(
+        "(Intercept)", "sppPR", "sppDM", "sppEC-A",
+        "sppEC-L", "sppDES-L", "sppDF", "cover", "minedno"
+      ),
+      zero_inflated = c(
+        "(Intercept)", "sppPR",
+        "sppDM", "sppEC-A", "sppEC-L", "sppDES-L", "sppDF", "minedno"
+      ),
+      dispersion = c("(Intercept)", "DOY")
+    ),
+    ignore_attr = TRUE
+  )
+  expect_equal(
+    find_parameters(m, effects = "random"),
+    list(
+      random = list(site = "(Intercept)"),
+      dispersion_random = "site"
+    ),
+    ignore_attr = TRUE
+  )
+  expect_equal(
+    find_parameters(m, component = "conditional"),
+    list(
+      conditional = c(
+        "(Intercept)", "sppPR", "sppDM", "sppEC-A",
+        "sppEC-L", "sppDES-L", "sppDF", "cover", "minedno"
+      ),
+      random = list(site = "(Intercept)")
+    ),
+    ignore_attr = TRUE
+  )
+})
