@@ -1,6 +1,7 @@
-requiet("logitr")
 skip_if_not_installed("logitr", minimum_version = "0.8.0")
 
+data(yogurt, package = "logitr")
+
 mod <- suppressMessages(logitr::logitr(
   data    = yogurt,
   outcome = "choice",
