@@ -7,7 +7,7 @@ test_that("marginaleffects", {
 
   x <- marginaleffects::slopes(m,
     variables = "Petal.Length",
-    newdata = insight::get_datagrid(m, at = "Species")
+    newdata = insight::get_datagrid(m, by = "Species")
   )
   # Equivalent in emmeans
   x2 <- emmeans::emtrends(m, var = "Petal.Length", specs = ~ Species + Petal.Length)
@@ -26,4 +26,17 @@ test_that("marginaleffects", {
 
   # Find statistic
   expect_identical(insight::find_statistic(x), "z-statistic")
+
+  # standardize names - "s.value" becomes "S"
+  skip_if_not_installed("parameters", minimum_version = "0.24.0")
+  skip_if_not_installed("marginaleffects", minimum_version = "0.24.0.6")
+
+  expect_named(
+    parameters::model_parameters(x),
+    c(
+      "rowid", "Parameter", "Comparison", "Coefficient", "SE", "Statistic", "p",
+      "S", "CI", "CI_low", "CI_high", "Predicted", "Species",
+      "Petal.Length", "Sepal.Width"
+    )
+  )
 })
